@@ -3,9 +3,10 @@ package dialog_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v18/internal/cli/dialog"
-	"github.com/git-town/git-town/v18/internal/cli/dialog/components/list"
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/cli/dialog"
+	"github.com/git-town/git-town/v22/internal/cli/dialog/dialogcomponents/list"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/messages"
 	"github.com/shoenig/test/must"
 )
 
@@ -54,7 +55,7 @@ func TestAliases(t *testing.T) {
 			t.Parallel()
 			give := configdomain.AliasableCommands{}
 			have := dialog.DetermineAliasSelectionText(give)
-			want := "(none)"
+			want := messages.DialogResultNone
 			must.EqOp(t, want, have)
 		})
 		t.Run("some commands selected", func(t *testing.T) {
