@@ -18,8 +18,9 @@ import (
 // Lineage validates that the given lineage contains the ancestry for all given branches.
 // Prompts missing lineage information from the user.
 // Returns the new lineage and perennial branches to add to the config storage.
-func Lineage(args LineageArgs) (additionalLineage configdomain.Lineage, additionalPerennials gitdomain.LocalBranchNames, exit dialogdomain.Exit, err error) {
-	additionalLineage = configdomain.NewLineage()
+func Lineage(args LineageArgs) (LineageResult, dialogdomain.Exit, error) {
+	additionalLineage := configdomain.NewLineage()
+	additionalPerennials := gitdomain.LocalBranchNames{}
 	branchesToVerify := args.BranchesToVerify
 	for i := 0; i < len(branchesToVerify); i++ {
 		branchToVerify := branchesToVerify[i]
@@ -44,8 +45,9 @@ func Lineage(args LineageArgs) (additionalLineage configdomain.Lineage, addition
 		// look for parent in proposals
 		if connector, hasConnector := args.Connector.Get(); hasConnector {
 			if proposalSearcher, canSearchProposals := connector.(forgedomain.ProposalSearcher); canSearchProposals {
-				proposalOpt, _ := proposalSearcher.SearchProposal(branchToVerify)
-				if proposal, hasProposal := proposalOpt.Get(); hasProposal {
+				proposals, _ := proposalSearcher.SearchProposals(branchToVerify)
+				if len(proposals) == 1 {
+					proposal := proposals[0]
 					parent := proposal.Data.Data().Target
 					additionalLineage = additionalLineage.Set(branchToVerify, parent)
 					branchesToVerify = append(branchesToVerify, parent)
@@ -94,7 +96,10 @@ func Lineage(args LineageArgs) (additionalLineage configdomain.Lineage, addition
 			UncommittedChanges: false,
 		})
 		if err != nil || exit {
-			return additionalLineage, additionalPerennials, exit, err
+			return LineageResult{
+				AdditionalLineage:    additionalLineage,
+				AdditionalPerennials: additionalPerennials,
+			}, exit, err
 		}
 		if newParent == messages.SetParentNoneOption {
 			additionalPerennials = append(additionalPerennials, branchToVerify)
@@ -103,7 +108,10 @@ func Lineage(args LineageArgs) (additionalLineage configdomain.Lineage, addition
 			branchesToVerify = append(branchesToVerify, newParent)
 		}
 	}
-	return additionalLineage, additionalPerennials, false, nil
+	return LineageResult{
+		AdditionalLineage:    additionalLineage,
+		AdditionalPerennials: additionalPerennials,
+	}, false, nil
 }
 
 type LineageArgs struct {
@@ -117,3 +125,8 @@ type LineageArgs struct {
 	LocalBranches    gitdomain.LocalBranchNames
 	MainBranch       gitdomain.LocalBranchName
 }
+
+type LineageResult struct {
+	AdditionalLineage    configdomain.Lineage
+	AdditionalPerennials gitdomain.LocalBranchNames
+}
