@@ -1,8 +1,8 @@
 package flags
 
 import (
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
@@ -17,14 +17,7 @@ func CommitMessage(desc string) (AddFunc, ReadCommitMessageFlagFunc) {
 		cmd.Flags().StringP(commitMessageLong, commitMessageShort, "", desc)
 	}
 	readFlag := func(cmd *cobra.Command) (Option[gitdomain.CommitMessage], error) {
-		value, err := cmd.Flags().GetString(commitMessageLong)
-		if err != nil {
-			return None[gitdomain.CommitMessage](), err
-		}
-		if value == "" {
-			return None[gitdomain.CommitMessage](), nil
-		}
-		return Some(gitdomain.CommitMessage(value)), nil
+		return readStringOptFlag[gitdomain.CommitMessage](cmd.Flags(), commitMessageLong)
 	}
 	return addFlag, readFlag
 }
