@@ -1,7 +1,8 @@
 package flags
 
 import (
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
@@ -11,13 +12,13 @@ const detachedLong = "detached"
 func Detached() (AddFunc, ReadDetachedFlagFunc) {
 	addFlag := func(cmd *cobra.Command) {
 		cmd.Flags().BoolP(detachedLong, "d", false, "don't update the perennial root branch")
+		defineNegatedFlag(cmd.Flags(), detachedLong, "disable detached")
 	}
-	readFlag := func(cmd *cobra.Command) (configdomain.Detached, error) {
-		value, err := cmd.Flags().GetBool(detachedLong)
-		return configdomain.Detached(value), err
+	readFlag := func(cmd *cobra.Command) (Option[configdomain.Detached], error) {
+		return readNegatableFlag[configdomain.Detached](cmd.Flags(), detachedLong)
 	}
 	return addFlag, readFlag
 }
 
 // ReadDetachedFlagFunc is the type signature for the function that reads the "detached" flag from the args to the given Cobra command.
-type ReadDetachedFlagFunc func(*cobra.Command) (configdomain.Detached, error)
+type ReadDetachedFlagFunc func(*cobra.Command) (Option[configdomain.Detached], error)
