@@ -1,7 +1,7 @@
 package flags
 
 import (
-	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
 	"github.com/spf13/cobra"
 )
 
@@ -13,8 +13,7 @@ func Prototype() (AddFunc, ReadPrototypeFlagFunc) {
 		cmd.Flags().BoolP(prototypeLong, "p", false, "create a prototype branch")
 	}
 	readFlag := func(cmd *cobra.Command) (configdomain.Prototype, error) {
-		value, err := cmd.Flags().GetBool(prototypeLong)
-		return configdomain.Prototype(value), err
+		return readBoolFlag[configdomain.Prototype](cmd.Flags(), prototypeLong)
 	}
 	return addFlag, readFlag
 }
