@@ -22,40 +22,44 @@ const configDesc = "Display your Git Town configuration"
 func RootCmd() *cobra.Command {
 	addDisplayTypesFlag, readDisplayTypesFlag := flags.Displaytypes()
 	addVerboseFlag, readVerboseFlag := flags.Verbose()
+	addRedactFlag, readRedactFlag := flags.Redact()
 	configCmd := cobra.Command{
 		Use:     "config",
-		GroupID: cmdhelpers.GroupIDSetup,
+		GroupID: cmdhelpers.GroupIDConfig,
 		Args:    cobra.NoArgs,
 		Short:   configDesc,
 		Long:    cmdhelpers.Long(configDesc),
 		RunE: func(cmd *cobra.Command, _ []string) error {
 			displayTypes, errDisplayTypes := readDisplayTypesFlag(cmd)
 			verbose, errVerbose := readVerboseFlag(cmd)
-			if err := cmp.Or(errDisplayTypes, errVerbose); err != nil {
+			redact, errRedact := readRedactFlag(cmd)
+			if err := cmp.Or(errDisplayTypes, errRedact, errVerbose); err != nil {
 				return err
 			}
 			cliConfig := cliconfig.New(cliconfig.NewArgs{
-				AutoResolve:  None[configdomain.AutoResolve](),
-				AutoSync:     None[configdomain.AutoSync](),
-				Detached:     None[configdomain.Detached](),
-				DisplayTypes: displayTypes,
-				DryRun:       None[configdomain.DryRun](),
-				Order:        None[configdomain.Order](),
-				PushBranches: None[configdomain.PushBranches](),
-				Stash:        None[configdomain.Stash](),
-				Verbose:      verbose,
+				AutoResolve:       None[configdomain.AutoResolve](),
+				AutoSync:          None[configdomain.AutoSync](),
+				Detached:          None[configdomain.Detached](),
+				DisplayTypes:      displayTypes,
+				DryRun:            None[configdomain.DryRun](),
+				IgnoreUncommitted: None[configdomain.IgnoreUncommitted](),
+				Order:             None[configdomain.Order](),
+				PushBranches:      None[configdomain.PushBranches](),
+				Stash:             None[configdomain.Stash](),
+				Verbose:           verbose,
 			})
-			return executeDisplayConfig(cliConfig)
+			return executeDisplayConfig(cliConfig, redact)
 		},
 	}
 	addDisplayTypesFlag(&configCmd)
 	addVerboseFlag(&configCmd)
+	addRedactFlag(&configCmd)
 	configCmd.AddCommand(getParentCommand())
 	configCmd.AddCommand(removeConfigCommand())
 	return &configCmd
 }
 
-func executeDisplayConfig(cliConfig configdomain.PartialConfig) error {
+func executeDisplayConfig(cliConfig configdomain.PartialConfig, redact configdomain.Redact) error {
 	repo, err := execute.OpenRepo(execute.OpenRepoArgs{
 		CliConfig:        cliConfig,
 		IgnoreUnknown:    true,
@@ -67,11 +71,11 @@ func executeDisplayConfig(cliConfig configdomain.PartialConfig) error {
 	if err != nil {
 		return err
 	}
-	printConfig(repo.UnvalidatedConfig)
+	printConfig(repo.UnvalidatedConfig, redact)
 	return nil
 }
 
-func printConfig(config config.UnvalidatedConfig) {
+func printConfig(config config.UnvalidatedConfig, redact configdomain.Redact) {
 	fmt.Println()
 	print.Header("Branches")
 	print.Entry("contribution branches", format.BranchNames(config.NormalConfig.PartialBranchesOfType(configdomain.BranchTypeContributionBranch)))
@@ -91,28 +95,34 @@ func printConfig(config config.UnvalidatedConfig) {
 	print.Header("Configuration")
 	print.Entry("offline", format.Bool(config.NormalConfig.Offline.IsOffline()))
 	print.Entry("git user name", format.OptionalStringerSetting(config.NormalConfig.GitUserName))
-	print.Entry("git user email", format.OptionalStringerSetting(config.NormalConfig.GitUserEmail))
+	print.Entry("git user email", formatToken(config.NormalConfig.GitUserEmail, redact))
 	fmt.Println()
 	print.Header("Create")
+	print.Entry("branch prefix", format.OptionalStringerSetting(config.NormalConfig.BranchPrefix))
 	print.Entry("new branch type", format.OptionalStringerSetting(config.NormalConfig.NewBranchType))
 	print.Entry("share new branches", config.NormalConfig.ShareNewBranches.String())
 	print.Entry("stash uncommitted changes", format.Bool(config.NormalConfig.Stash.ShouldStash()))
 	fmt.Println()
 	print.Header("Hosting")
+	print.Entry("browser", format.OptionalStringerSetting(config.NormalConfig.Browser))
 	print.Entry("development remote", config.NormalConfig.DevRemote.String())
 	print.Entry("forge type", format.OptionalStringerSetting(config.NormalConfig.ForgeType))
 	print.Entry("origin hostname", format.OptionalStringerSetting(config.NormalConfig.HostingOriginHostname))
 	print.Entry("Bitbucket username", format.OptionalStringerSetting(config.NormalConfig.BitbucketUsername))
-	print.Entry("Bitbucket app password", format.OptionalStringerSetting(config.NormalConfig.BitbucketAppPassword))
-	print.Entry("Forgejo token", format.OptionalStringerSetting(config.NormalConfig.ForgejoToken))
-	print.Entry("Gitea token", format.OptionalStringerSetting(config.NormalConfig.GiteaToken))
-	print.Entry("GitHub connector type", format.OptionalStringerSetting(config.NormalConfig.GitHubConnectorType))
-	print.Entry("GitHub token", format.OptionalStringerSetting(config.NormalConfig.GitHubToken))
-	print.Entry("GitLab connector type", format.OptionalStringerSetting(config.NormalConfig.GitLabConnectorType))
-	print.Entry("GitLab token", format.OptionalStringerSetting(config.NormalConfig.GitLabToken))
+	print.Entry("Bitbucket app password", formatToken(config.NormalConfig.BitbucketAppPassword, redact))
+	print.Entry("Forgejo token", formatToken(config.NormalConfig.ForgejoToken, redact))
+	print.Entry("Gitea token", formatToken(config.NormalConfig.GiteaToken, redact))
+	print.Entry("GitHub connector", format.OptionalStringerSetting(config.NormalConfig.GithubConnectorType))
+	print.Entry("GitHub token", formatToken(config.NormalConfig.GithubToken, redact))
+	print.Entry("GitLab connector", format.OptionalStringerSetting(config.NormalConfig.GitlabConnectorType))
+	print.Entry("GitLab token", formatToken(config.NormalConfig.GitlabToken, redact))
+	fmt.Println()
+	print.Header("Propose")
+	print.Entry("breadcrumb", format.StringsSetting(config.NormalConfig.ProposalBreadcrumb.String()))
 	fmt.Println()
 	print.Header("Ship")
 	print.Entry("delete tracking branch", format.Bool(config.NormalConfig.ShipDeleteTrackingBranch.ShouldDeleteTrackingBranch()))
+	print.Entry("ignore uncommitted changes", format.Bool(config.NormalConfig.IgnoreUncommitted.AllowUncommitted()))
 	print.Entry("ship strategy", config.NormalConfig.ShipStrategy.String())
 	fmt.Println()
 	print.Header("Sync")
@@ -132,3 +142,11 @@ func printConfig(config config.UnvalidatedConfig) {
 		print.LabelAndValue("Branch Lineage", format.BranchLineage(config.NormalConfig.Lineage, config.NormalConfig.Order))
 	}
 }
+
+// formatToken returns a formatted token value. If redact is true and the token is set, it returns "(configured)".
+func formatToken[T fmt.Stringer](token Option[T], redact configdomain.Redact) string {
+	if redact.ShouldRedact() && token.IsSome() {
+		return "(configured)"
+	}
+	return format.OptionalStringerSetting(token)
+}
