@@ -20,6 +20,7 @@ import (
 	"github.com/git-town/git-town/v22/internal/git/gitdomain"
 	"github.com/git-town/git-town/v22/internal/gohacks/stringslice"
 	"github.com/git-town/git-town/v22/internal/messages"
+	"github.com/git-town/git-town/v22/internal/programs"
 	"github.com/git-town/git-town/v22/internal/state/runstate"
 	"github.com/git-town/git-town/v22/internal/validate"
 	"github.com/git-town/git-town/v22/internal/vm/interpreter/fullinterpreter"
@@ -82,15 +83,16 @@ func detachCommand() *cobra.Command {
 				return err
 			}
 			cliConfig := cliconfig.New(cliconfig.NewArgs{
-				AutoResolve:  None[configdomain.AutoResolve](),
-				AutoSync:     None[configdomain.AutoSync](),
-				Detached:     Some(configdomain.Detached(true)),
-				DisplayTypes: None[configdomain.DisplayTypes](),
-				DryRun:       dryRun,
-				Order:        None[configdomain.Order](),
-				PushBranches: None[configdomain.PushBranches](),
-				Stash:        None[configdomain.Stash](),
-				Verbose:      verbose,
+				AutoResolve:       None[configdomain.AutoResolve](),
+				AutoSync:          None[configdomain.AutoSync](),
+				Detached:          Some(configdomain.Detached(true)),
+				DisplayTypes:      None[configdomain.DisplayTypes](),
+				DryRun:            dryRun,
+				IgnoreUncommitted: None[configdomain.IgnoreUncommitted](),
+				Order:             None[configdomain.Order](),
+				PushBranches:      None[configdomain.PushBranches](),
+				Stash:             None[configdomain.Stash](),
+				Verbose:           verbose,
 			})
 			return executeDetach(cliConfig)
 		},
@@ -147,6 +149,7 @@ Start:
 		Backend:                 repo.Backend,
 		CommandsCounter:         repo.CommandsCounter,
 		Config:                  data.config,
+		ConfigDir:               repo.ConfigDir,
 		Connector:               data.connector,
 		FinalMessages:           repo.FinalMessages,
 		Frontend:                repo.Frontend,
@@ -158,28 +161,28 @@ Start:
 		InitialStashSize:        data.stashSize,
 		Inputs:                  data.inputs,
 		PendingCommand:          None[string](),
-		RootDir:                 repo.RootDir,
 		RunState:                runState,
 	})
 }
 
 type detachData struct {
-	branchInfosLastRun  Option[gitdomain.BranchInfos]
-	branchToDetachInfo  gitdomain.BranchInfo
-	branchToDetachName  gitdomain.LocalBranchName
-	branchToDetachType  configdomain.BranchType
-	branchesSnapshot    gitdomain.BranchesSnapshot
-	children            []detachChildBranch
-	config              config.ValidatedConfig
-	connector           Option[forgedomain.Connector]
-	descendents         []detachChildBranch
-	hasOpenChanges      bool
-	initialBranch       gitdomain.LocalBranchName
-	inputs              dialogcomponents.Inputs
-	nonExistingBranches gitdomain.LocalBranchNames // branches that are listed in the lineage information, but don't exist in the repo, neither locally nor remotely
-	parentBranch        gitdomain.LocalBranchName
-	previousBranch      Option[gitdomain.LocalBranchName]
-	stashSize           gitdomain.StashSize
+	branchInfosLastRun     Option[gitdomain.BranchInfos]
+	branchToDetachInfo     gitdomain.BranchInfo
+	branchToDetachName     gitdomain.LocalBranchName
+	branchToDetachProposal Option[forgedomain.Proposal]
+	branchToDetachType     configdomain.BranchType
+	branchesSnapshot       gitdomain.BranchesSnapshot
+	children               []detachChildBranch
+	config                 config.ValidatedConfig
+	connector              Option[forgedomain.Connector]
+	descendents            []detachChildBranch
+	hasOpenChanges         bool
+	initialBranch          gitdomain.LocalBranchName
+	inputs                 dialogcomponents.Inputs
+	nonExistingBranches    gitdomain.LocalBranchNames // branches that are listed in the lineage information, but don't exist in the repo, neither locally nor remotely
+	parentBranch           gitdomain.LocalBranchName
+	previousBranch         Option[gitdomain.LocalBranchName]
+	stashSize              gitdomain.StashSize
 }
 
 type detachChildBranch struct {
@@ -188,30 +191,33 @@ type detachChildBranch struct {
 	proposal Option[forgedomain.Proposal]
 }
 
-func determineDetachData(repo execute.OpenRepoResult) (data detachData, flow configdomain.ProgramFlow, err error) {
+func determineDetachData(repo execute.OpenRepoResult) (detachData, configdomain.ProgramFlow, error) {
 	inputs := dialogcomponents.LoadInputs(os.Environ())
+	var emptyResult detachData
 	repoStatus, err := repo.Git.RepoStatus(repo.Backend)
 	if err != nil {
-		return data, configdomain.ProgramFlowExit, err
+		return emptyResult, configdomain.ProgramFlowExit, err
 	}
 	config := repo.UnvalidatedConfig.NormalConfig
 	connector, err := forge.NewConnector(forge.NewConnectorArgs{
 		Backend:              repo.Backend,
 		BitbucketAppPassword: config.BitbucketAppPassword,
 		BitbucketUsername:    config.BitbucketUsername,
+		Browser:              config.Browser,
+		ConfigDir:            repo.ConfigDir,
 		ForgeType:            config.ForgeType,
 		ForgejoToken:         config.ForgejoToken,
 		Frontend:             repo.Frontend,
-		GitHubConnectorType:  config.GitHubConnectorType,
-		GitHubToken:          config.GitHubToken,
-		GitLabConnectorType:  config.GitLabConnectorType,
-		GitLabToken:          config.GitLabToken,
 		GiteaToken:           config.GiteaToken,
+		GithubConnectorType:  config.GithubConnectorType,
+		GithubToken:          config.GithubToken,
+		GitlabConnectorType:  config.GitlabConnectorType,
+		GitlabToken:          config.GitlabToken,
 		Log:                  print.Logger{},
 		RemoteURL:            config.DevURL(repo.Backend),
 	})
 	if err != nil {
-		return data, configdomain.ProgramFlowExit, err
+		return emptyResult, configdomain.ProgramFlowExit, err
 	}
 	branchesSnapshot, stashSize, branchInfosLastRun, flow, err := execute.LoadRepoSnapshot(execute.LoadRepoSnapshotArgs{
 		Backend:               repo.Backend,
@@ -231,39 +237,40 @@ func determineDetachData(repo execute.OpenRepoResult) (data detachData, flow con
 		ValidateNoOpenChanges: false,
 	})
 	if err != nil {
-		return data, configdomain.ProgramFlowExit, err
+		return emptyResult, configdomain.ProgramFlowExit, err
 	}
 	switch flow {
 	case configdomain.ProgramFlowContinue:
 	case configdomain.ProgramFlowExit, configdomain.ProgramFlowRestart:
-		return data, flow, nil
+		return emptyResult, flow, nil
 	}
 	if branchesSnapshot.DetachedHead {
-		return data, configdomain.ProgramFlowExit, errors.New(messages.DetachRepoHasDetachedHead)
+		return emptyResult, configdomain.ProgramFlowExit, errors.New(messages.DetachRepoHasDetachedHead)
 	}
 	currentBranch, hasCurrentBranch := branchesSnapshot.Active.Get()
 	if !hasCurrentBranch {
-		return data, configdomain.ProgramFlowExit, errors.New(messages.CurrentBranchCannotDetermine)
+		return emptyResult, configdomain.ProgramFlowExit, errors.New(messages.CurrentBranchCannotDetermine)
 	}
 	branchNameToDetach := currentBranch
 	branchToDetachInfo, hasBranchToDetachInfo := branchesSnapshot.Branches.FindByLocalName(branchNameToDetach).Get()
 	if !hasBranchToDetachInfo {
-		return data, configdomain.ProgramFlowExit, fmt.Errorf(messages.BranchDoesntExist, branchNameToDetach)
+		return emptyResult, configdomain.ProgramFlowExit, fmt.Errorf(messages.BranchDoesntExist, branchNameToDetach)
 	}
 	if branchToDetachInfo.SyncStatus == gitdomain.SyncStatusOtherWorktree {
-		return data, configdomain.ProgramFlowExit, fmt.Errorf(messages.BranchOtherWorktree, branchNameToDetach)
+		return emptyResult, configdomain.ProgramFlowExit, fmt.Errorf(messages.BranchOtherWorktree, branchNameToDetach)
 	}
 	localBranches := branchesSnapshot.Branches.LocalBranches().NamesLocalBranches()
 	branchesAndTypes := repo.UnvalidatedConfig.UnvalidatedBranchesAndTypes(branchesSnapshot.Branches.LocalBranches().NamesLocalBranches())
 	remotes, err := repo.Git.Remotes(repo.Backend)
 	if err != nil {
-		return data, configdomain.ProgramFlowExit, err
+		return emptyResult, configdomain.ProgramFlowExit, err
 	}
 	validatedConfig, exit, err := validate.Config(validate.ConfigArgs{
 		Backend:            repo.Backend,
 		BranchInfos:        branchesSnapshot.Branches,
 		BranchesAndTypes:   branchesAndTypes,
 		BranchesToValidate: gitdomain.LocalBranchNames{},
+		ConfigDir:          repo.ConfigDir,
 		ConfigSnapshot:     repo.ConfigSnapshot,
 		Connector:          connector,
 		Frontend:           repo.Frontend,
@@ -275,40 +282,51 @@ func determineDetachData(repo execute.OpenRepoResult) (data detachData, flow con
 		Unvalidated:        NewMutable(&repo.UnvalidatedConfig),
 	})
 	if err != nil || exit {
-		return data, configdomain.ProgramFlowExit, err
+		return emptyResult, configdomain.ProgramFlowExit, err
 	}
 	branchTypeToDetach := validatedConfig.BranchType(branchNameToDetach)
 	initialBranch, hasInitialBranch := branchesSnapshot.Active.Get()
 	if !hasInitialBranch {
-		return data, configdomain.ProgramFlowExit, errors.New(messages.CurrentBranchCannotDetermine)
+		return emptyResult, configdomain.ProgramFlowExit, errors.New(messages.CurrentBranchCannotDetermine)
 	}
 	previousBranchOpt := repo.Git.PreviouslyCheckedOutBranch(repo.Backend)
 	parentBranch, hasParentBranch := validatedConfig.NormalConfig.Lineage.Parent(branchNameToDetach).Get()
 	if !hasParentBranch {
-		return data, configdomain.ProgramFlowExit, errors.New(messages.DetachNoParent)
+		return emptyResult, configdomain.ProgramFlowExit, errors.New(messages.DetachNoParent)
 	}
 	branchHasMergeCommits, err := repo.Git.BranchContainsMerges(repo.Backend, branchNameToDetach, parentBranch)
 	if err != nil {
-		return data, configdomain.ProgramFlowExit, err
+		return emptyResult, configdomain.ProgramFlowExit, err
 	}
 	if branchHasMergeCommits {
-		return data, configdomain.ProgramFlowExit, fmt.Errorf(messages.BranchContainsMergeCommits, branchNameToDetach)
+		return emptyResult, configdomain.ProgramFlowExit, fmt.Errorf(messages.BranchContainsMergeCommits, branchNameToDetach)
+	}
+
+	connectorProposalFinder := None[forgedomain.ProposalFinder]()
+	branchToDetachProposal := None[forgedomain.Proposal]()
+	if connector, hasConnector := connector.Get(); hasConnector {
+		if proposalFinder, canFindProposals := connector.(forgedomain.ProposalFinder); canFindProposals {
+			connectorProposalFinder = Some(proposalFinder)
+			branchToDetachProposal, err = proposalFinder.FindProposal(branchNameToDetach, parentBranch)
+			if err != nil {
+				return emptyResult, configdomain.ProgramFlowExit, err
+			}
+		}
 	}
 	childBranches := validatedConfig.NormalConfig.Lineage.Children(branchNameToDetach, validatedConfig.NormalConfig.Order)
 	children := make([]detachChildBranch, len(childBranches))
+	proposalFinder, hasProposalFinder := connectorProposalFinder.Get()
 	for c, childBranch := range childBranches {
 		proposal := None[forgedomain.Proposal]()
-		if connector, hasConnector := connector.Get(); hasConnector {
-			if proposalFinder, canFindProposals := connector.(forgedomain.ProposalFinder); canFindProposals {
-				proposal, err = proposalFinder.FindProposal(childBranch, initialBranch)
-				if err != nil {
-					return data, configdomain.ProgramFlowExit, err
-				}
+		if hasProposalFinder {
+			proposal, err = proposalFinder.FindProposal(childBranch, initialBranch)
+			if err != nil {
+				return emptyResult, configdomain.ProgramFlowExit, err
 			}
 		}
 		childInfo, has := branchesSnapshot.Branches.FindByLocalName(childBranch).Get()
 		if !has {
-			return data, configdomain.ProgramFlowExit, fmt.Errorf("cannot find branch info for %q", childBranch)
+			return emptyResult, configdomain.ProgramFlowExit, fmt.Errorf("cannot find branch info for %q", childBranch)
 		}
 		children[c] = detachChildBranch{
 			info:     childInfo,
@@ -321,7 +339,7 @@ func determineDetachData(repo execute.OpenRepoResult) (data detachData, flow con
 	for d, descendentName := range descendentNames {
 		info, has := branchesSnapshot.Branches.FindByLocalName(descendentName).Get()
 		if !has {
-			return data, configdomain.ProgramFlowExit, fmt.Errorf("cannot find branch info for %q", descendentName)
+			return emptyResult, configdomain.ProgramFlowExit, fmt.Errorf("cannot find branch info for %q", descendentName)
 		}
 		descendents[d] = detachChildBranch{
 			info:     info,
@@ -330,47 +348,60 @@ func determineDetachData(repo execute.OpenRepoResult) (data detachData, flow con
 		}
 	}
 	lineageBranches := validatedConfig.NormalConfig.Lineage.BranchNames()
-	_, nonExistingBranches := branchesSnapshot.Branches.Select(repo.UnvalidatedConfig.NormalConfig.DevRemote, lineageBranches...)
+	_, nonExistingBranches := branchesSnapshot.Branches.Select(lineageBranches...)
 	return detachData{
-		branchInfosLastRun:  branchInfosLastRun,
-		branchToDetachInfo:  *branchToDetachInfo,
-		branchToDetachName:  branchNameToDetach,
-		branchToDetachType:  branchTypeToDetach,
-		branchesSnapshot:    branchesSnapshot,
-		children:            children,
-		config:              validatedConfig,
-		connector:           connector,
-		descendents:         descendents,
-		hasOpenChanges:      repoStatus.OpenChanges,
-		initialBranch:       initialBranch,
-		inputs:              inputs,
-		nonExistingBranches: nonExistingBranches,
-		parentBranch:        parentBranch,
-		previousBranch:      previousBranchOpt,
-		stashSize:           stashSize,
+		branchInfosLastRun:     branchInfosLastRun,
+		branchToDetachInfo:     *branchToDetachInfo,
+		branchToDetachName:     branchNameToDetach,
+		branchToDetachProposal: branchToDetachProposal,
+		branchToDetachType:     branchTypeToDetach,
+		branchesSnapshot:       branchesSnapshot,
+		children:               children,
+		config:                 validatedConfig,
+		connector:              connector,
+		descendents:            descendents,
+		hasOpenChanges:         repoStatus.OpenChanges,
+		initialBranch:          initialBranch,
+		inputs:                 inputs,
+		nonExistingBranches:    nonExistingBranches,
+		parentBranch:           parentBranch,
+		previousBranch:         previousBranchOpt,
+		stashSize:              stashSize,
 	}, configdomain.ProgramFlowContinue, nil
 }
 
 func detachProgram(repo execute.OpenRepoResult, data detachData, finalMessages stringslice.Collector) program.Program {
 	prog := NewMutable(&program.Program{})
 	data.config.CleanupLineage(data.branchesSnapshot.Branches, data.nonExistingBranches, finalMessages, repo.Frontend, data.config.NormalConfig.Order)
+	oldParent := data.parentBranch
 	// step 1: delete the commits of the branch to detach from all descendents,
 	// while that branch is still in the form it had inside the stack
-	lastParent := data.parentBranch
 	for _, descendent := range data.descendents {
+		// Determine the correct parent to rebase onto.
+		// If the descendant's parent is the branch being detached, rebase onto that branch's parent.
+		// Otherwise, rebase onto the descendant's actual parent.
+		rebaseOnto := data.parentBranch
+		if descendentParent, hasParent := data.config.NormalConfig.Lineage.Parent(descendent.name).Get(); hasParent {
+			if descendentParent != data.branchToDetachName {
+				rebaseOnto = descendentParent
+			}
+		}
 		sync.RemoveAncestorCommits(sync.RemoveAncestorCommitsArgs{
 			Ancestor:          data.branchToDetachName.BranchName(),
 			Branch:            descendent.name,
 			HasTrackingBranch: descendent.info.HasTrackingBranch(),
 			Program:           prog,
-			RebaseOnto:        lastParent,
+			RebaseOnto:        rebaseOnto,
 		})
-		if descendent.info.HasTrackingBranch() {
+		if descendentTracking, descendentHasTracking := descendent.info.RemoteName.Get(); descendentHasTracking {
 			prog.Value.Add(
-				&opcodes.PushCurrentBranchForceIfNeeded{CurrentBranch: descendent.name, ForceIfIncludes: true},
+				&opcodes.PushCurrentBranchForceIfNeeded{
+					CurrentBranch:   descendent.name,
+					ForceIfIncludes: true,
+					TrackingBranch:  descendentTracking,
+				},
 			)
 		}
-		lastParent = descendent.name
 	}
 	// step 2: delete the commits of parent branches from the detached branch
 	prog.Value.Add(
@@ -382,9 +413,13 @@ func detachProgram(repo execute.OpenRepoResult, data detachData, finalMessages s
 			CommitsToRemove:    data.parentBranch.BranchName().Location(),
 		},
 	)
-	if data.branchToDetachInfo.HasTrackingBranch() {
+	if trackingBranch, hasTrackingBranch := data.branchToDetachInfo.RemoteName.Get(); hasTrackingBranch {
 		prog.Value.Add(
-			&opcodes.PushCurrentBranchForceIfNeeded{CurrentBranch: data.branchToDetachName, ForceIfIncludes: true},
+			&opcodes.PushCurrentBranchForceIfNeeded{
+				CurrentBranch:   data.branchToDetachName,
+				ForceIfIncludes: true,
+				TrackingBranch:  trackingBranch,
+			},
 		)
 	}
 	prog.Value.Add(&opcodes.CheckoutIfNeeded{Branch: data.initialBranch})
@@ -395,15 +430,43 @@ func detachProgram(repo execute.OpenRepoResult, data detachData, finalMessages s
 				Parent: data.config.ValidatedConfigData.MainBranch,
 			},
 		)
-		for _, child := range data.config.NormalConfig.Lineage.Children(data.branchToDetachName, data.config.NormalConfig.Order) {
+	}
+	if proposal, hasProposal := data.branchToDetachProposal.Get(); hasProposal {
+		prog.Value.Add(
+			&opcodes.ProposalUpdateTarget{
+				NewBranch: data.config.ValidatedConfigData.MainBranch,
+				OldBranch: data.parentBranch,
+				Proposal:  proposal,
+			},
+		)
+	}
+	for _, child := range data.children {
+		prog.Value.Add(
+			&opcodes.LineageParentSet{
+				Branch: child.name,
+				Parent: data.parentBranch,
+			},
+		)
+
+		if proposal, hasProposal := child.proposal.Get(); hasProposal {
 			prog.Value.Add(
-				&opcodes.LineageParentSet{
-					Branch: child,
-					Parent: data.parentBranch,
+				&opcodes.ProposalUpdateTarget{
+					NewBranch: data.parentBranch,
+					OldBranch: data.branchToDetachName,
+					Proposal:  proposal,
 				},
 			)
 		}
 	}
+	updateBreadcrumb := data.config.NormalConfig.ProposalBreadcrumb.Enabled()
+	isOnline := data.config.NormalConfig.Offline.IsOnline()
+	if updateBreadcrumb && isOnline {
+		programs.AddSyncProposalsProgram(programs.AddSyncProposalsProgramArgs{
+			Config:          data.config,
+			Program:         prog,
+			TouchedBranches: gitdomain.LocalBranchNames{data.branchToDetachName, oldParent},
+		})
+	}
 	cmdhelpers.Wrap(prog, cmdhelpers.WrapOptions{
 		DryRun:                   data.config.NormalConfig.DryRun,
 		InitialStashSize:         data.stashSize,
