@@ -6,10 +6,13 @@ import (
 	"fmt"
 	"os"
 
+	"github.com/spf13/cobra"
+
 	"github.com/git-town/git-town/v22/internal/cli/dialog/dialogcomponents"
 	"github.com/git-town/git-town/v22/internal/cli/flags"
 	"github.com/git-town/git-town/v22/internal/cli/print"
 	"github.com/git-town/git-town/v22/internal/cmd/cmdhelpers"
+	"github.com/git-town/git-town/v22/internal/cmd/ship"
 	"github.com/git-town/git-town/v22/internal/config"
 	"github.com/git-town/git-town/v22/internal/config/cliconfig"
 	"github.com/git-town/git-town/v22/internal/config/configdomain"
@@ -18,6 +21,7 @@ import (
 	"github.com/git-town/git-town/v22/internal/forge/forgedomain"
 	"github.com/git-town/git-town/v22/internal/git/gitdomain"
 	"github.com/git-town/git-town/v22/internal/messages"
+	"github.com/git-town/git-town/v22/internal/programs"
 	"github.com/git-town/git-town/v22/internal/state/runstate"
 	"github.com/git-town/git-town/v22/internal/validate"
 	"github.com/git-town/git-town/v22/internal/vm/interpreter/fullinterpreter"
@@ -25,12 +29,11 @@ import (
 	"github.com/git-town/git-town/v22/internal/vm/optimizer"
 	"github.com/git-town/git-town/v22/internal/vm/program"
 	. "github.com/git-town/git-town/v22/pkg/prelude"
-	"github.com/spf13/cobra"
 )
 
 const (
 	mergeCmd  = "merge"
-	mergeDesc = "Merges the current branch with its parent"
+	mergeDesc = "Combines the current branch with its parent"
 	mergeHelp = `
 Merges the current branch with its parent branch.
 Both branches must be feature branches.
@@ -78,15 +81,16 @@ func mergeCommand() *cobra.Command {
 				return err
 			}
 			cliConfig := cliconfig.New(cliconfig.NewArgs{
-				AutoResolve:  None[configdomain.AutoResolve](),
-				AutoSync:     None[configdomain.AutoSync](),
-				Detached:     Some(configdomain.Detached(true)),
-				DisplayTypes: None[configdomain.DisplayTypes](),
-				DryRun:       dryRun,
-				Order:        None[configdomain.Order](),
-				PushBranches: None[configdomain.PushBranches](),
-				Stash:        None[configdomain.Stash](),
-				Verbose:      verbose,
+				AutoResolve:       None[configdomain.AutoResolve](),
+				AutoSync:          None[configdomain.AutoSync](),
+				Detached:          Some(configdomain.Detached(true)),
+				DisplayTypes:      None[configdomain.DisplayTypes](),
+				DryRun:            dryRun,
+				IgnoreUncommitted: None[configdomain.IgnoreUncommitted](),
+				Order:             None[configdomain.Order](),
+				PushBranches:      None[configdomain.PushBranches](),
+				Stash:             None[configdomain.Stash](),
+				Verbose:           verbose,
 			})
 			return executeMerge(cliConfig)
 		},
@@ -142,7 +146,8 @@ Start:
 		Backend:                 repo.Backend,
 		CommandsCounter:         repo.CommandsCounter,
 		Config:                  data.config,
-		Connector:               None[forgedomain.Connector](),
+		ConfigDir:               repo.ConfigDir,
+		Connector:               data.connector,
 		FinalMessages:           repo.FinalMessages,
 		Frontend:                repo.Frontend,
 		Git:                     repo.Git,
@@ -153,53 +158,58 @@ Start:
 		InitialStashSize:        data.stashSize,
 		Inputs:                  data.inputs,
 		PendingCommand:          None[string](),
-		RootDir:                 repo.RootDir,
 		RunState:                runState,
 	})
 }
 
 type mergeData struct {
-	branchInfosLastRun Option[gitdomain.BranchInfos]
-	branchesSnapshot   gitdomain.BranchesSnapshot
-	config             config.ValidatedConfig
-	hasOpenChanges     bool
-	initialBranch      gitdomain.LocalBranchName
-	initialBranchInfo  gitdomain.BranchInfo
-	initialBranchSHA   gitdomain.SHA
-	initialBranchType  configdomain.BranchType
-	inputs             dialogcomponents.Inputs
-	parentBranch       gitdomain.LocalBranchName
-	parentBranchInfo   gitdomain.BranchInfo
-	parentBranchSHA    gitdomain.SHA
-	parentBranchType   configdomain.BranchType
-	previousBranch     Option[gitdomain.LocalBranchName]
-	stashSize          gitdomain.StashSize
+	branchInfosLastRun       Option[gitdomain.BranchInfos]
+	branchesSnapshot         gitdomain.BranchesSnapshot
+	childBranches            gitdomain.LocalBranchNames
+	config                   config.ValidatedConfig
+	connector                Option[forgedomain.Connector]
+	hasOpenChanges           bool
+	initialBranch            gitdomain.LocalBranchName
+	initialBranchInfo        gitdomain.BranchInfo
+	initialBranchSHA         gitdomain.SHA
+	initialBranchType        configdomain.BranchType
+	inputs                   dialogcomponents.Inputs
+	parentBranch             gitdomain.LocalBranchName
+	parentBranchInfo         gitdomain.BranchInfo
+	parentBranchSHA          gitdomain.SHA
+	parentBranchType         configdomain.BranchType
+	previousBranch           Option[gitdomain.LocalBranchName]
+	proposalsOfChildBranches []forgedomain.Proposal
+	stashSize                gitdomain.StashSize
 }
 
-func determineMergeData(repo execute.OpenRepoResult) (data mergeData, flow configdomain.ProgramFlow, err error) {
+func determineMergeData(repo execute.OpenRepoResult) (mergeData, configdomain.ProgramFlow, error) {
 	inputs := dialogcomponents.LoadInputs(os.Environ())
+	var emptyResult mergeData
 	repoStatus, err := repo.Git.RepoStatus(repo.Backend)
 	if err != nil {
-		return data, configdomain.ProgramFlowExit, err
+		return emptyResult, configdomain.ProgramFlowExit, err
 	}
 	config := repo.UnvalidatedConfig.NormalConfig
 	connector, err := forge.NewConnector(forge.NewConnectorArgs{
 		Backend:              repo.Backend,
 		BitbucketAppPassword: config.BitbucketAppPassword,
 		BitbucketUsername:    config.BitbucketUsername,
+		Browser:              config.Browser,
+		ConfigDir:            repo.ConfigDir,
 		ForgeType:            config.ForgeType,
 		ForgejoToken:         config.ForgejoToken,
 		Frontend:             repo.Frontend,
-		GitHubConnectorType:  config.GitHubConnectorType,
-		GitHubToken:          config.GitHubToken,
-		GitLabConnectorType:  config.GitLabConnectorType,
-		GitLabToken:          config.GitLabToken,
 		GiteaToken:           config.GiteaToken,
+		GithubConnectorType:  config.GithubConnectorType,
+		GithubToken:          config.GithubToken,
+		GitlabConnectorType:  config.GitlabConnectorType,
+		GitlabToken:          config.GitlabToken,
 		Log:                  print.Logger{},
 		RemoteURL:            config.DevURL(repo.Backend),
 	})
 	if err != nil {
-		return data, configdomain.ProgramFlowExit, err
+		return emptyResult, configdomain.ProgramFlowExit, err
 	}
 	branchesSnapshot, stashSize, branchInfosLastRun, flow, err := execute.LoadRepoSnapshot(execute.LoadRepoSnapshotArgs{
 		Backend:               repo.Backend,
@@ -219,31 +229,32 @@ func determineMergeData(repo execute.OpenRepoResult) (data mergeData, flow confi
 		ValidateNoOpenChanges: false,
 	})
 	if err != nil {
-		return data, configdomain.ProgramFlowExit, err
+		return emptyResult, configdomain.ProgramFlowExit, err
 	}
 	switch flow {
 	case configdomain.ProgramFlowContinue:
 	case configdomain.ProgramFlowExit, configdomain.ProgramFlowRestart:
-		return data, flow, nil
+		return emptyResult, flow, nil
 	}
 	if branchesSnapshot.DetachedHead {
-		return data, configdomain.ProgramFlowExit, errors.New(messages.MergeDetachedHead)
+		return emptyResult, configdomain.ProgramFlowExit, errors.New(messages.MergeDetachedHead)
 	}
 	initialBranch, hasInitialBranch := branchesSnapshot.Active.Get()
 	if !hasInitialBranch {
-		return data, configdomain.ProgramFlowExit, errors.New(messages.CurrentBranchCannotDetermine)
+		return emptyResult, configdomain.ProgramFlowExit, errors.New(messages.CurrentBranchCannotDetermine)
 	}
 	branchesAndTypes := repo.UnvalidatedConfig.UnvalidatedBranchesAndTypes(branchesSnapshot.Branches.LocalBranches().NamesLocalBranches())
 	localBranches := branchesSnapshot.Branches.LocalBranches().NamesLocalBranches()
 	remotes, err := repo.Git.Remotes(repo.Backend)
 	if err != nil {
-		return data, configdomain.ProgramFlowExit, err
+		return emptyResult, configdomain.ProgramFlowExit, err
 	}
 	validatedConfig, exit, err := validate.Config(validate.ConfigArgs{
 		Backend:            repo.Backend,
 		BranchInfos:        branchesSnapshot.Branches,
 		BranchesAndTypes:   branchesAndTypes,
 		BranchesToValidate: gitdomain.LocalBranchNames{initialBranch},
+		ConfigDir:          repo.ConfigDir,
 		ConfigSnapshot:     repo.ConfigSnapshot,
 		Connector:          connector,
 		Frontend:           repo.Frontend,
@@ -255,89 +266,117 @@ func determineMergeData(repo execute.OpenRepoResult) (data mergeData, flow confi
 		Unvalidated:        NewMutable(&repo.UnvalidatedConfig),
 	})
 	if err != nil || exit {
-		return data, configdomain.ProgramFlowExit, err
+		return emptyResult, configdomain.ProgramFlowExit, err
 	}
 	parentBranch, hasParentBranch := validatedConfig.NormalConfig.Lineage.Parent(initialBranch).Get()
 	if !hasParentBranch {
-		return data, configdomain.ProgramFlowExit, fmt.Errorf(messages.MergeNoParent, initialBranch)
+		return emptyResult, configdomain.ProgramFlowExit, fmt.Errorf(messages.MergeNoParent, initialBranch)
 	}
 	grandParentBranch := validatedConfig.NormalConfig.Lineage.Parent(parentBranch)
 	if grandParentBranch.IsNone() {
-		return data, configdomain.ProgramFlowExit, fmt.Errorf(messages.MergeNoGrandParent, initialBranch, parentBranch)
+		return emptyResult, configdomain.ProgramFlowExit, fmt.Errorf(messages.MergeNoGrandParent, initialBranch, parentBranch)
 	}
 	previousBranch := repo.Git.PreviouslyCheckedOutBranch(repo.Backend)
 	initialBranchInfo, hasInitialBranchInfo := branchesSnapshot.Branches.FindByLocalName(initialBranch).Get()
 	if !hasInitialBranchInfo {
-		return data, configdomain.ProgramFlowExit, fmt.Errorf(messages.BranchInfoNotFound, initialBranch)
+		return emptyResult, configdomain.ProgramFlowExit, fmt.Errorf(messages.BranchInfoNotFound, initialBranch)
 	}
-	initialBranchSHA, hasInitialBranchSHA := initialBranchInfo.LocalSHA.Get()
+	initialBranchSHA, hasInitialBranchSHA := initialBranchInfo.LocalSHA().Get()
 	if !hasInitialBranchSHA {
-		return data, configdomain.ProgramFlowExit, fmt.Errorf(messages.MergeBranchNotLocal, initialBranch)
+		return emptyResult, configdomain.ProgramFlowExit, fmt.Errorf(messages.MergeBranchNotLocal, initialBranch)
 	}
 	parentBranchInfo, hasParentBranchInfo := branchesSnapshot.Branches.FindByLocalName(parentBranch).Get()
 	if !hasParentBranchInfo {
-		return data, configdomain.ProgramFlowExit, fmt.Errorf(messages.BranchInfoNotFound, parentBranch)
+		return emptyResult, configdomain.ProgramFlowExit, fmt.Errorf(messages.BranchInfoNotFound, parentBranch)
 	}
-	parentBranchSHA, hasParentBranchSHA := parentBranchInfo.LocalSHA.Get()
+	parentBranchSHA, hasParentBranchSHA := parentBranchInfo.LocalSHA().Get()
 	if !hasParentBranchSHA {
-		return data, configdomain.ProgramFlowExit, fmt.Errorf(messages.MergeBranchNotLocal, parentBranch)
+		return emptyResult, configdomain.ProgramFlowExit, fmt.Errorf(messages.MergeBranchNotLocal, parentBranch)
 	}
 	initialBranchType := validatedConfig.BranchType(initialBranch)
 	parentBranchType := validatedConfig.BranchType(parentBranch)
+
+	childBranches := validatedConfig.NormalConfig.Lineage.Children(initialBranch, validatedConfig.NormalConfig.Order)
+	proposalsOfChildBranches := ship.LoadProposalsOfChildBranches(ship.LoadProposalsOfChildBranchesArgs{
+		ConnectorOpt:               connector,
+		Lineage:                    validatedConfig.NormalConfig.Lineage,
+		Offline:                    repo.IsOffline,
+		OldBranch:                  initialBranch,
+		OldBranchHasTrackingBranch: branchesSnapshot.Branches.FindByLocalName(initialBranch).IsSome(),
+		Order:                      validatedConfig.NormalConfig.Order,
+	})
 	return mergeData{
-		branchInfosLastRun: branchInfosLastRun,
-		branchesSnapshot:   branchesSnapshot,
-		config:             validatedConfig,
-		hasOpenChanges:     repoStatus.OpenChanges,
-		initialBranch:      initialBranch,
-		initialBranchInfo:  *initialBranchInfo,
-		initialBranchSHA:   initialBranchSHA,
-		initialBranchType:  initialBranchType,
-		inputs:             inputs,
-		parentBranch:       parentBranch,
-		parentBranchInfo:   *parentBranchInfo,
-		parentBranchSHA:    parentBranchSHA,
-		parentBranchType:   parentBranchType,
-		previousBranch:     previousBranch,
-		stashSize:          stashSize,
+		branchInfosLastRun:       branchInfosLastRun,
+		branchesSnapshot:         branchesSnapshot,
+		childBranches:            childBranches,
+		config:                   validatedConfig,
+		connector:                connector,
+		hasOpenChanges:           repoStatus.OpenChanges,
+		initialBranch:            initialBranch,
+		initialBranchInfo:        *initialBranchInfo,
+		initialBranchSHA:         initialBranchSHA,
+		initialBranchType:        initialBranchType,
+		inputs:                   inputs,
+		parentBranch:             parentBranch,
+		parentBranchInfo:         *parentBranchInfo,
+		parentBranchSHA:          parentBranchSHA,
+		parentBranchType:         parentBranchType,
+		previousBranch:           previousBranch,
+		proposalsOfChildBranches: proposalsOfChildBranches,
+		stashSize:                stashSize,
 	}, configdomain.ProgramFlowContinue, err
 }
 
 func mergeProgram(repo execute.OpenRepoResult, data mergeData) program.Program {
 	prog := NewMutable(&program.Program{})
-	// there is no point in updating proposals:
-	// If the parent branch has a proposal, it doesn't need to change.
-	// The child branch proposal will get closed because the child branch gets deleted,
-	// and that's correct because it was from the child branch into the parent branch,
-	// and that doesn't make sense anymore because both branches are one now.
+	ship.UpdateChildBranchProposalsToGrandParent(prog.Value, data.proposalsOfChildBranches)
 	prog.Value.Add(&opcodes.Checkout{Branch: data.parentBranch})
 	if data.initialBranchSHA != data.parentBranchSHA {
-		prog.Value.Add(&opcodes.BranchLocalSetToSHA{SHA: data.initialBranchSHA})
+		prog.Value.Add(&opcodes.BranchCurrentResetToSHA{SHA: data.initialBranchSHA})
+	}
+	for _, child := range data.childBranches {
+		prog.Value.Add(&opcodes.LineageParentSetToGrandParent{Branch: child})
 	}
 	prog.Value.Add(&opcodes.LineageParentRemove{
 		Branch: data.initialBranch,
 	})
-	prog.Value.Add(&opcodes.BranchLocalDelete{
-		Branch: data.initialBranch,
-	})
-	if data.parentBranchInfo.RemoteName.IsSome() && repo.IsOffline.IsOnline() {
-		prog.Value.Add(&opcodes.PushCurrentBranchForceIfNeeded{
-			CurrentBranch:   data.parentBranch,
-			ForceIfIncludes: true,
-		})
-	}
+	// We need to delete the remote branch before updating the parent branch.
+	// This order will make sure that if there is a related proposal where
+	// the base is the branch being merged and the target is the parent branch
+	// then that proposal gets marked "closed" rather than "merged" by forges
+	// like GitHub.
 	initialTrackingBranch, initialHasTrackingBranch := data.initialBranchInfo.RemoteName.Get()
 	if initialHasTrackingBranch && repo.IsOffline.IsOnline() {
 		prog.Value.Add(&opcodes.BranchTrackingDelete{
 			Branch: initialTrackingBranch,
 		})
 	}
+	prog.Value.Add(&opcodes.BranchLocalDelete{
+		Branch: data.initialBranch,
+	})
+	parentTracking, parentHasTracking := data.parentBranchInfo.RemoteName.Get()
+	if parentHasTracking && repo.IsOffline.IsOnline() {
+		prog.Value.Add(&opcodes.PushCurrentBranchForceIfNeeded{
+			CurrentBranch:   data.parentBranch,
+			ForceIfIncludes: true,
+			TrackingBranch:  parentTracking,
+		})
+	}
 	if _, hasOverride := data.config.NormalConfig.BranchTypeOverrides[data.initialBranch]; hasOverride {
 		prog.Value.Add(&opcodes.BranchTypeOverrideRemove{
 			Branch: data.initialBranch,
 		})
 	}
 	previousBranchCandidates := []Option[gitdomain.LocalBranchName]{data.previousBranch}
+	updateBreadcrumb := data.config.NormalConfig.ProposalBreadcrumb.Enabled()
+	isOnline := data.config.NormalConfig.Offline.IsOnline()
+	if updateBreadcrumb && isOnline {
+		programs.AddSyncProposalsProgram(programs.AddSyncProposalsProgramArgs{
+			Config:          data.config,
+			Program:         prog,
+			TouchedBranches: gitdomain.LocalBranchNames{data.initialBranch},
+		})
+	}
 	cmdhelpers.Wrap(prog, cmdhelpers.WrapOptions{
 		DryRun:                   data.config.NormalConfig.DryRun,
 		InitialStashSize:         data.stashSize,
