@@ -21,23 +21,23 @@ type shipDataAPI struct {
 	proposal               forgedomain.Proposal
 }
 
-func determineAPIData(sharedData sharedShipData) (result shipDataAPI, err error) {
+func determineAPIData(sharedData sharedShipData) (shipDataAPI, error) {
 	branchToShipRemoteName, hasRemoteBranchToShip := sharedData.branchToShipInfo.RemoteName.Get()
 	if !hasRemoteBranchToShip {
-		return result, fmt.Errorf(messages.ShipAPINoRemoteBranch, sharedData.branchToShip)
+		return shipDataAPI{}, fmt.Errorf(messages.ShipAPINoRemoteBranch, sharedData.branchToShip)
 	}
 	connector, hasConnector := sharedData.connector.Get()
 	if !hasConnector {
-		return result, errors.New(messages.ShipAPIConnectorRequired)
+		return shipDataAPI{}, errors.New(messages.ShipAPIConnectorRequired)
 	}
 	proposalFinder, canFindProposals := connector.(forgedomain.ProposalFinder)
 	if !canFindProposals {
-		return result, errors.New(messages.ShipAPIConnectorUnsupported)
+		return shipDataAPI{}, errors.New(messages.ShipAPIConnectorUnsupported)
 	}
 	proposalOpt, err := proposalFinder.FindProposal(sharedData.branchToShip, sharedData.targetBranchName)
 	proposal, hasProposal := proposalOpt.Get()
 	if !hasProposal {
-		return result, fmt.Errorf(messages.ShipAPINoProposal, sharedData.branchToShip)
+		return shipDataAPI{}, fmt.Errorf(messages.ShipAPINoProposal, sharedData.branchToShip)
 	}
 	return shipDataAPI{
 		branchToShipRemoteName: branchToShipRemoteName,
@@ -47,7 +47,7 @@ func determineAPIData(sharedData sharedShipData) (result shipDataAPI, err error)
 }
 
 func shipAPIProgram(prog Mutable[program.Program], repo execute.OpenRepoResult, sharedData sharedShipData, apiData shipDataAPI, commitMessage Option[gitdomain.CommitMessage]) error {
-	branchToShipLocal, hasLocalBranchToShip := sharedData.branchToShipInfo.LocalName.Get()
+	branchToShipLocal, hasLocalBranchToShip := sharedData.branchToShipInfo.LocalName().Get()
 	UpdateChildBranchProposalsToGrandParent(prog.Value, sharedData.proposalsOfChildBranches)
 	prog.Value.Add(&opcodes.CheckoutIfNeeded{Branch: sharedData.targetBranchName})
 	connector, hasConnector := sharedData.connector.Get()
