@@ -3,6 +3,7 @@ package configdomain
 import (
 	"encoding/json"
 
+	"github.com/git-town/git-town/v22/internal/forge/forgedomain"
 	"github.com/git-town/git-town/v22/internal/git/gitdomain"
 	"github.com/git-town/git-town/v22/pkg"
 	. "github.com/git-town/git-town/v22/pkg/prelude"
@@ -58,6 +59,8 @@ const (
 	KeyAutoSync                            = Key("git-town.auto-sync")
 	KeyBitbucketAppPassword                = Key("git-town.bitbucket-app-password")
 	KeyBitbucketUsername                   = Key("git-town.bitbucket-username")
+	KeyBranchPrefix                        = Key("git-town.branch-prefix")
+	KeyBrowser                             = Key("git-town.browser")
 	KeyContributionRegex                   = Key("git-town.contribution-regex")
 	KeyDeprecatedCodebergToken             = Key("git-town.codeberg-token")
 	KeyDeprecatedCodeHostingDriver         = Key("git-town.code-hosting-driver")
@@ -74,6 +77,7 @@ const (
 	KeyDeprecatedObservedBranches          = Key("git-town.observed-branches")
 	KeyDeprecatedParkedBranches            = Key("git-town.parked-branches")
 	KeyDeprecatedPerennialBranchNames      = Key("git-town.perennial-branch-names")
+	KeyDeprecatedProposalsShowLineage      = Key("git-town.proposals-show-lineage")
 	KeyDeprecatedPrototypeBranches         = Key("git-town.prototype-branches")
 	KeyDeprecatedPullBranchStrategy        = Key("git-town.pull-branch-strategy")
 	KeyDeprecatedPushNewBranches           = Key("git-town.push-new-branches")
@@ -87,11 +91,12 @@ const (
 	KeyForgejoToken                        = Key("git-town.forgejo-token")
 	KeyForgeType                           = Key("git-town.forge-type")
 	KeyGiteaToken                          = Key("git-town.gitea-token")
-	KeyGitHubConnectorType                 = Key("git-town.github-connector")
-	KeyGitHubToken                         = Key(pkg.KeyGitHubToken)
-	KeyGitLabConnectorType                 = Key("git-town.gitlab-connector")
-	KeyGitLabToken                         = Key("git-town.gitlab-token")
+	KeyGithubConnectorType                 = Key("git-town.github-connector")
+	KeyGithubToken                         = Key(pkg.KeyGithubToken)
+	KeyGitlabConnectorType                 = Key("git-town.gitlab-connector")
+	KeyGitlabToken                         = Key("git-town.gitlab-token")
 	KeyHostingOriginHostname               = Key("git-town.hosting-origin-hostname")
+	KeyIgnoreUncommitted                   = Key("git-town.ignore-uncommitted")
 	KeyMainBranch                          = Key("git-town.main-branch")
 	KeyNewBranchType                       = Key("git-town.new-branch-type")
 	KeyObservedRegex                       = Key("git-town.observed-regex")
@@ -100,7 +105,7 @@ const (
 	KeyOrder                               = Key("git-town.order")
 	KeyPerennialBranches                   = Key("git-town.perennial-branches")
 	KeyPerennialRegex                      = Key("git-town.perennial-regex")
-	KeyProposalsShowLineage                = Key("git-town.proposals-show-lineage")
+	KeyProposalBreadcrumb                  = Key("git-town.proposal-breadcrumb")
 	KeyPushBranches                        = Key("git-town.push-branches")
 	KeyPushHook                            = Key("git-town.push-hook")
 	KeyShareNewBranches                    = Key("git-town.share-new-branches")
@@ -122,6 +127,8 @@ var keys = []Key{
 	KeyAutoSync,
 	KeyBitbucketAppPassword,
 	KeyBitbucketUsername,
+	KeyBranchPrefix,
+	KeyBrowser,
 	KeyContributionRegex,
 	KeyDeprecatedAliasKill,
 	KeyDeprecatedAliasRenameBranch,
@@ -138,6 +145,7 @@ var keys = []Key{
 	KeyDeprecatedObservedBranches,
 	KeyDeprecatedParkedBranches,
 	KeyDeprecatedPerennialBranchNames,
+	KeyDeprecatedProposalsShowLineage,
 	KeyDeprecatedPrototypeBranches,
 	KeyDeprecatedPullBranchStrategy,
 	KeyDeprecatedPushNewBranches,
@@ -151,10 +159,10 @@ var keys = []Key{
 	KeyForgejoToken,
 	KeyForgeType,
 	KeyGiteaToken,
-	KeyGitHubConnectorType,
-	KeyGitHubToken,
-	KeyGitLabConnectorType,
-	KeyGitLabToken,
+	KeyGithubConnectorType,
+	KeyGithubToken,
+	KeyGitlabConnectorType,
+	KeyGitlabToken,
 	KeyGitUserEmail,
 	KeyGitUserName,
 	KeyHostingOriginHostname,
@@ -166,11 +174,12 @@ var keys = []Key{
 	KeyOrder,
 	KeyPerennialBranches,
 	KeyPerennialRegex,
-	KeyProposalsShowLineage,
+	KeyProposalBreadcrumb,
 	KeyPushBranches,
 	KeyPushHook,
 	KeyShareNewBranches,
 	KeyShipDeleteTrackingBranch,
+	KeyIgnoreUncommitted,
 	KeyShipStrategy,
 	KeyStash,
 	KeySyncFeatureStrategy,
@@ -210,6 +219,7 @@ var DeprecatedKeys = map[Key]Key{
 	KeyDeprecatedMainBranchName:            KeyMainBranch,
 	KeyDeprecatedNewBranchPushFlag:         KeyDeprecatedPushNewBranches,
 	KeyDeprecatedPerennialBranchNames:      KeyPerennialBranches,
+	KeyDeprecatedProposalsShowLineage:      KeyProposalBreadcrumb,
 	KeyDeprecatedPullBranchStrategy:        KeySyncPerennialStrategy,
 	KeyDeprecatedPushVerify:                KeyPushHook,
 	KeyDeprecatedShipDeleteRemoteBranch:    KeyShipDeleteTrackingBranch,
@@ -231,6 +241,16 @@ var ObsoleteBranchLists = map[Key]BranchType{
 
 // ConfigUpdates defines the config that should have its keys and values to be updated
 var ConfigUpdates = []ConfigUpdate{
+	{
+		Before: ConfigSetting{
+			Key:   KeyProposalBreadcrumb,
+			Value: "cli",
+		},
+		After: ConfigSetting{
+			Key:   KeyProposalBreadcrumb,
+			Value: string(forgedomain.ProposalBreadcrumbBranches),
+		},
+	},
 	{
 		Before: ConfigSetting{
 			Key:   KeyDeprecatedAliasKill,
