@@ -9,6 +9,7 @@ import (
 	"github.com/git-town/git-town/v22/internal/gohacks/mapstools"
 	"github.com/git-town/git-town/v22/internal/gohacks/slice"
 	. "github.com/git-town/git-town/v22/pkg/prelude"
+	"github.com/git-town/git-town/v22/pkg/set"
 )
 
 // Lineage encapsulates all data and functionality around parent branches.
@@ -32,6 +33,19 @@ func NewLineageWith(data LineageData) Lineage {
 	}
 }
 
+// provides the nth ancestor of the given branch
+func (self Lineage) Ancestor(branch gitdomain.LocalBranchName, nth uint) Option[gitdomain.LocalBranchName] {
+	current := branch
+	for range nth {
+		var hasCurrent bool
+		current, hasCurrent = self.Parent(current).Get()
+		if !hasCurrent {
+			return None[gitdomain.LocalBranchName]()
+		}
+	}
+	return Some(current)
+}
+
 // Ancestors provides the names of all parent branches of the branch with the given name.
 func (self Lineage) Ancestors(branch gitdomain.LocalBranchName) gitdomain.LocalBranchNames {
 	current := branch
@@ -103,7 +117,7 @@ func (self Lineage) BranchesAndAncestors(branchNames gitdomain.LocalBranchNames,
 	return self.OrderHierarchically(result, order)
 }
 
-// provides all branches for which the parent is known
+// BranchesWithParents provides all branches for which the parent is known.
 func (self Lineage) BranchesWithParents() gitdomain.LocalBranchNames {
 	var result gitdomain.LocalBranchNames = slices.Collect(maps.Keys(self.data))
 	slice.NaturalSort(result)
@@ -127,6 +141,15 @@ func (self Lineage) Children(branch gitdomain.LocalBranchName, order Order) gitd
 	return result
 }
 
+// Clan provides all branches that are related to the given branches, i.e. all ancestors and descendents.
+func (self Lineage) Clan(branches gitdomain.LocalBranchNames, perennialBranches gitdomain.LocalBranchNames) gitdomain.LocalBranchNames {
+	result := set.New[gitdomain.LocalBranchName]()
+	for _, branch := range branches {
+		result.Add(self.BranchLineageWithoutRoot(branch, perennialBranches, OrderAsc)...)
+	}
+	return result.Values()
+}
+
 // Descendants provides all branches that depend on the given branch in its lineage.
 func (self Lineage) Descendants(branch gitdomain.LocalBranchName, order Order) gitdomain.LocalBranchNames {
 	result := gitdomain.LocalBranchNames{}
@@ -184,7 +207,7 @@ func (self Lineage) Len() int {
 	return len(self.data)
 }
 
-// provides a new Lineage that consists of entries from both this and the given Lineage
+// Merge provides a new Lineage that consists of entries from both this and the given Lineage
 func (self Lineage) Merge(other Lineage) Lineage {
 	return Lineage{
 		data: mapstools.Merge(self.data, other.data),
@@ -247,7 +270,7 @@ func (self Lineage) Set(branch, parent gitdomain.LocalBranchName) Lineage {
 	return self
 }
 
-// provides the first branch from the given whitelist that is an ancestor of the given branch
+// YoungestAncestorWithin provides the first branch from the given whitelist that is an ancestor of the given branch
 func (self Lineage) YoungestAncestorWithin(branch gitdomain.LocalBranchName, whitelist gitdomain.LocalBranchNames) Option[gitdomain.LocalBranchName] {
 	for {
 		parent, hasParent := self.Parent(branch).Get()
