@@ -21,7 +21,9 @@ type PartialConfig struct {
 	AutoSync                 Option[AutoSync]
 	BitbucketAppPassword     Option[forgedomain.BitbucketAppPassword]
 	BitbucketUsername        Option[forgedomain.BitbucketUsername]
+	BranchPrefix             Option[BranchPrefix]
 	BranchTypeOverrides      BranchTypeOverrides
+	Browser                  Option[Browser]
 	ContributionRegex        Option[ContributionRegex]
 	Detached                 Option[Detached]
 	DevRemote                Option[gitdomain.Remote]
@@ -30,14 +32,15 @@ type PartialConfig struct {
 	FeatureRegex             Option[FeatureRegex]
 	ForgeType                Option[forgedomain.ForgeType]
 	ForgejoToken             Option[forgedomain.ForgejoToken]
-	GitHubConnectorType      Option[forgedomain.GitHubConnectorType]
-	GitHubToken              Option[forgedomain.GitHubToken]
-	GitLabConnectorType      Option[forgedomain.GitLabConnectorType]
-	GitLabToken              Option[forgedomain.GitLabToken]
 	GitUserEmail             Option[gitdomain.GitUserEmail]
 	GitUserName              Option[gitdomain.GitUserName]
 	GiteaToken               Option[forgedomain.GiteaToken]
+	GithubConnectorType      Option[forgedomain.GithubConnectorType]
+	GithubToken              Option[forgedomain.GithubToken]
+	GitlabConnectorType      Option[forgedomain.GitlabConnectorType]
+	GitlabToken              Option[forgedomain.GitlabToken]
 	HostingOriginHostname    Option[HostingOriginHostname]
+	IgnoreUncommitted        Option[IgnoreUncommitted]
 	Lineage                  Lineage
 	MainBranch               Option[gitdomain.LocalBranchName]
 	NewBranchType            Option[NewBranchType]
@@ -46,7 +49,7 @@ type PartialConfig struct {
 	Order                    Option[Order]
 	PerennialBranches        gitdomain.LocalBranchNames
 	PerennialRegex           Option[PerennialRegex]
-	ProposalsShowLineage     Option[forgedomain.ProposalsShowLineage]
+	ProposalBreadcrumb       Option[forgedomain.ProposalBreadcrumb]
 	PushBranches             Option[PushBranches]
 	PushHook                 Option[PushHook]
 	ShareNewBranches         Option[ShareNewBranches]
@@ -69,7 +72,8 @@ func EmptyPartialConfig() PartialConfig {
 	} //exhaustruct:ignore
 }
 
-// Merges the given PartialConfig into this configuration object.
+// Merge combines the data of the given PartialConfig with this PartialConfig,
+// favoring the data of the given PartialConfig.
 func (self PartialConfig) Merge(other PartialConfig) PartialConfig {
 	return PartialConfig{
 		Aliases:                  mapstools.Merge(other.Aliases, self.Aliases),
@@ -77,7 +81,9 @@ func (self PartialConfig) Merge(other PartialConfig) PartialConfig {
 		AutoSync:                 other.AutoSync.Or(self.AutoSync),
 		BitbucketAppPassword:     other.BitbucketAppPassword.Or(self.BitbucketAppPassword),
 		BitbucketUsername:        other.BitbucketUsername.Or(self.BitbucketUsername),
+		BranchPrefix:             other.BranchPrefix.Or(self.BranchPrefix),
 		BranchTypeOverrides:      other.BranchTypeOverrides.Concat(self.BranchTypeOverrides),
+		Browser:                  other.Browser.Or(self.Browser),
 		ContributionRegex:        other.ContributionRegex.Or(self.ContributionRegex),
 		Detached:                 other.Detached.Or(self.Detached),
 		DevRemote:                other.DevRemote.Or(self.DevRemote),
@@ -86,14 +92,15 @@ func (self PartialConfig) Merge(other PartialConfig) PartialConfig {
 		FeatureRegex:             other.FeatureRegex.Or(self.FeatureRegex),
 		ForgeType:                other.ForgeType.Or(self.ForgeType),
 		ForgejoToken:             other.ForgejoToken.Or(self.ForgejoToken),
-		GitHubConnectorType:      other.GitHubConnectorType.Or(self.GitHubConnectorType),
-		GitHubToken:              other.GitHubToken.Or(self.GitHubToken),
-		GitLabConnectorType:      other.GitLabConnectorType.Or(self.GitLabConnectorType),
-		GitLabToken:              other.GitLabToken.Or(self.GitLabToken),
 		GitUserEmail:             other.GitUserEmail.Or(self.GitUserEmail),
 		GitUserName:              other.GitUserName.Or(self.GitUserName),
 		GiteaToken:               other.GiteaToken.Or(self.GiteaToken),
+		GithubConnectorType:      other.GithubConnectorType.Or(self.GithubConnectorType),
+		GithubToken:              other.GithubToken.Or(self.GithubToken),
+		GitlabConnectorType:      other.GitlabConnectorType.Or(self.GitlabConnectorType),
+		GitlabToken:              other.GitlabToken.Or(self.GitlabToken),
 		HostingOriginHostname:    other.HostingOriginHostname.Or(self.HostingOriginHostname),
+		IgnoreUncommitted:        other.IgnoreUncommitted.Or(self.IgnoreUncommitted),
 		Lineage:                  other.Lineage.Merge(self.Lineage),
 		MainBranch:               other.MainBranch.Or(self.MainBranch),
 		NewBranchType:            other.NewBranchType.Or(self.NewBranchType),
@@ -102,7 +109,7 @@ func (self PartialConfig) Merge(other PartialConfig) PartialConfig {
 		Order:                    other.Order.Or(self.Order),
 		PerennialBranches:        append(other.PerennialBranches, self.PerennialBranches...),
 		PerennialRegex:           other.PerennialRegex.Or(self.PerennialRegex),
-		ProposalsShowLineage:     other.ProposalsShowLineage.Or(self.ProposalsShowLineage),
+		ProposalBreadcrumb:       other.ProposalBreadcrumb.Or(self.ProposalBreadcrumb),
 		PushBranches:             other.PushBranches.Or(self.PushBranches),
 		PushHook:                 other.PushHook.Or(self.PushHook),
 		ShareNewBranches:         other.ShareNewBranches.Or(self.ShareNewBranches),
