@@ -1,13 +1,21 @@
 package configdomain
 
-import . "github.com/git-town/git-town/v18/pkg/prelude"
+import (
+	"fmt"
+
+	"github.com/git-town/git-town/v22/internal/messages"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
+)
 
 type PerennialRegex struct {
 	VerifiedRegex
 }
 
-func ParsePerennialRegex(value string) (Option[PerennialRegex], error) {
+func ParsePerennialRegex(value string, source string) (Option[PerennialRegex], error) {
 	verifiedRegexOpt, err := ParseRegex(value)
+	if err != nil {
+		return None[PerennialRegex](), fmt.Errorf(messages.CannotParse, source, err)
+	}
 	if verifiedRegex, hasVerifiedRegex := verifiedRegexOpt.Get(); hasVerifiedRegex {
 		return Some(PerennialRegex{VerifiedRegex: verifiedRegex}), err
 	}
