@@ -1,12 +1,14 @@
 package configdomain
 
+import "github.com/git-town/git-town/v22/internal/gohacks/mapstools"
+
 // SingleSnapshot contains all of the local or global Git metadata config settings.
 type SingleSnapshot map[Key]string
 
-// provides all the keys that describe aliases for Git Town commands
+// AliasEntries provides all the keys that describe aliases for Git Town commands
 func (self SingleSnapshot) AliasEntries() map[AliasKey]string {
 	result := map[AliasKey]string{}
-	for key, value := range self {
+	for key, value := range self { // okay to iterate the map in random order here because we assign to a new map
 		if aliasKey, isAliasKey := NewAliasKey(key).Get(); isAliasKey {
 			result[aliasKey] = value
 		}
@@ -17,27 +19,16 @@ func (self SingleSnapshot) AliasEntries() map[AliasKey]string {
 func (self SingleSnapshot) Aliases() Aliases {
 	aliasEntries := self.AliasEntries()
 	result := make(Aliases, len(aliasEntries))
-	for key, value := range aliasEntries {
+	for key, value := range mapstools.SortedKeyValues(aliasEntries) {
 		result[key.AliasableCommand()] = value
 	}
 	return result
 }
 
-// provides all the configuration entries that describe branch type overrides
-func (self SingleSnapshot) BranchTypeOverrideEntries() map[BranchTypeOverrideKey]string {
-	result := map[BranchTypeOverrideKey]string{}
-	for key, value := range self {
-		if branchTypeKey, isBranchTypeKey := ParseBranchTypeOverrideKey(key).Get(); isBranchTypeKey {
-			result[branchTypeKey] = value
-		}
-	}
-	return result
-}
-
-// provides all the keys that describe lineage entries
+// LineageEntries provides all the keys that describe lineage entries
 func (self SingleSnapshot) LineageEntries() map[LineageKey]string {
 	result := map[LineageKey]string{}
-	for key, value := range self {
+	for key, value := range self { // okay to iterate the map in random order here because we assign to a new map
 		if lineageKey, isLineageKey := ParseLineageKey(key).Get(); isLineageKey {
 			result[lineageKey] = value
 		}
