@@ -1,7 +1,10 @@
 package configdomain
 
 import (
-	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"fmt"
+
+	"github.com/git-town/git-town/v22/internal/messages"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 )
 
 // SyncFeatureStrategy defines legal values for the "sync-feature-strategy" configuration setting.
@@ -21,8 +24,11 @@ const (
 	SyncFeatureStrategyCompress = SyncFeatureStrategy(SyncStrategyCompress)
 )
 
-func ParseSyncFeatureStrategy(text string) (Option[SyncFeatureStrategy], error) {
-	syncStrategyOpt, err := ParseSyncStrategy(text)
+func ParseSyncFeatureStrategy(value string, source string) (Option[SyncFeatureStrategy], error) {
+	syncStrategyOpt, err := ParseSyncStrategy(value)
+	if err != nil {
+		return None[SyncFeatureStrategy](), fmt.Errorf(messages.CannotParse, source, err)
+	}
 	if syncStrategy, has := syncStrategyOpt.Get(); has {
 		return Some(SyncFeatureStrategy(syncStrategy)), err
 	}
