@@ -44,46 +44,52 @@ func Load(rootDir gitdomain.RepoRootDir, fileName string, finalMessages stringsl
 
 // Validate converts the given low-level configfile data into high-level config data.
 func Validate(data Data, finalMessages stringslice.Collector) (configdomain.PartialConfig, error) {
-	// keep-sorted start
-	var autoResolve Option[configdomain.AutoResolve]
-	var autoSync Option[configdomain.AutoSync]
-	var contributionRegex Option[configdomain.ContributionRegex]
-	var detached Option[configdomain.Detached]
-	var devRemote Option[gitdomain.Remote]
-	var displayTypes Option[configdomain.DisplayTypes]
-	var featureRegex Option[configdomain.FeatureRegex]
-	var forgeType Option[forgedomain.ForgeType]
-	var githubConnectorType Option[forgedomain.GitHubConnectorType]
-	var gitlabConnectorType Option[forgedomain.GitLabConnectorType]
-	var hostingOriginHostname Option[configdomain.HostingOriginHostname]
-	var mainBranch Option[gitdomain.LocalBranchName]
-	var newBranchType Option[configdomain.NewBranchType]
-	var observedRegex Option[configdomain.ObservedRegex]
-	var order Option[configdomain.Order]
-	var perennialBranches gitdomain.LocalBranchNames
-	var perennialRegex Option[configdomain.PerennialRegex]
-	var proposalsShowLineage Option[forgedomain.ProposalsShowLineage]
-	var pushBranches Option[configdomain.PushBranches]
-	var pushHook Option[configdomain.PushHook]
-	var shareNewBranches Option[configdomain.ShareNewBranches]
-	var shipDeleteTrackingBranch Option[configdomain.ShipDeleteTrackingBranch]
-	var shipStrategy Option[configdomain.ShipStrategy]
-	var stash Option[configdomain.Stash]
-	var syncFeatureStrategy Option[configdomain.SyncFeatureStrategy]
-	var syncPerennialStrategy Option[configdomain.SyncPerennialStrategy]
-	var syncPrototypeStrategy Option[configdomain.SyncPrototypeStrategy]
-	var syncTags Option[configdomain.SyncTags]
-	var syncUpstream Option[configdomain.SyncUpstream]
-	var unknownBranchType Option[configdomain.UnknownBranchType]
-	// keep-sorted end
+	// TODO: convert to proper variable initialization using None
+	var (
+		// keep-sorted start
+		autoResolve              Option[configdomain.AutoResolve]
+		autoSync                 Option[configdomain.AutoSync]
+		branchPrefix             Option[configdomain.BranchPrefix]
+		browser                  Option[configdomain.Browser]
+		contributionRegex        Option[configdomain.ContributionRegex]
+		detached                 Option[configdomain.Detached]
+		devRemote                Option[gitdomain.Remote]
+		displayTypes             Option[configdomain.DisplayTypes]
+		featureRegex             Option[configdomain.FeatureRegex]
+		forgeType                Option[forgedomain.ForgeType]
+		githubConnectorType      Option[forgedomain.GithubConnectorType]
+		gitlabConnectorType      Option[forgedomain.GitlabConnectorType]
+		hostingOriginHostname    Option[configdomain.HostingOriginHostname]
+		ignoreUncommitted        Option[configdomain.IgnoreUncommitted]
+		mainBranch               Option[gitdomain.LocalBranchName]
+		newBranchType            Option[configdomain.NewBranchType]
+		observedRegex            Option[configdomain.ObservedRegex]
+		order                    Option[configdomain.Order]
+		perennialBranches        gitdomain.LocalBranchNames
+		perennialRegex           Option[configdomain.PerennialRegex]
+		proposalBreadcrumb       Option[forgedomain.ProposalBreadcrumb]
+		pushBranches             Option[configdomain.PushBranches]
+		pushHook                 Option[configdomain.PushHook]
+		shareNewBranches         Option[configdomain.ShareNewBranches]
+		shipDeleteTrackingBranch Option[configdomain.ShipDeleteTrackingBranch]
+		shipStrategy             Option[configdomain.ShipStrategy]
+		stash                    Option[configdomain.Stash]
+		syncFeatureStrategy      Option[configdomain.SyncFeatureStrategy]
+		syncPerennialStrategy    Option[configdomain.SyncPerennialStrategy]
+		syncPrototypeStrategy    Option[configdomain.SyncPrototypeStrategy]
+		syncTags                 Option[configdomain.SyncTags]
+		syncUpstream             Option[configdomain.SyncUpstream]
+		unknownBranchType        Option[configdomain.UnknownBranchType]
+		// keep-sorted end
+	)
 	var err error
 	// load legacy definitions first, so that the proper definitions loaded later override them
 	if data.CreatePrototypeBranches != nil {
 		newBranchType = Some(configdomain.NewBranchType(configdomain.BranchTypePrototypeBranch))
 		finalMessages.Add(messages.CreatePrototypeBranchesDeprecation)
 	}
-	if data.PushNewbranches != nil {
-		shareNewBranches = Some(configdomain.ParseShareNewBranchesDeprecatedBool(*data.PushNewbranches))
+	if data.PushNewBranches != nil {
+		shareNewBranches = Some(configdomain.ParseShareNewBranchesDeprecatedBool(*data.PushNewBranches))
 		finalMessages.Add(messages.PushNewBranchesDeprecation)
 	}
 	if data.PushHook != nil {
@@ -153,13 +159,17 @@ func Validate(data Data, finalMessages stringslice.Collector) (configdomain.Part
 		}
 	}
 	if data.Create != nil {
+		if data.Create.BranchPrefix != nil {
+			branchPrefix, err = configdomain.ParseBranchPrefix(*data.Create.BranchPrefix, messages.ConfigFile)
+			ec.Check(err)
+		}
 		if data.Create.NewBranchType != nil {
 			branchType, err := configdomain.ParseBranchType(*data.Create.NewBranchType, messages.ConfigFile)
 			ec.Check(err)
 			newBranchType = configdomain.NewBranchTypeOpt(branchType)
 		}
-		if data.Create.PushNewbranches != nil {
-			shareNewBranches = Some(configdomain.ParseShareNewBranchesDeprecatedBool(*data.Create.PushNewbranches))
+		if data.Create.PushNewBranches != nil {
+			shareNewBranches = Some(configdomain.ParseShareNewBranchesDeprecatedBool(*data.Create.PushNewBranches))
 			finalMessages.Add(messages.PushNewBranchesDeprecation)
 		}
 		if data.Create.ShareNewBranches != nil {
@@ -171,6 +181,10 @@ func Validate(data Data, finalMessages stringslice.Collector) (configdomain.Part
 		}
 	}
 	if data.Hosting != nil {
+		if data.Hosting.Browser != nil {
+			browser, err = configdomain.ParseBrowser(*data.Hosting.Browser, messages.ConfigFile)
+			ec.Check(err)
+		}
 		if data.Hosting.Platform != nil {
 			forgeType, err = forgedomain.ParseForgeType(*data.Hosting.Platform, messages.ConfigFile)
 			ec.Check(err)
@@ -182,12 +196,12 @@ func Validate(data Data, finalMessages stringslice.Collector) (configdomain.Part
 			forgeType, err = forgedomain.ParseForgeType(*data.Hosting.ForgeType, messages.ConfigFile)
 			ec.Check(err)
 		}
-		if data.Hosting.GitHubConnectorType != nil {
-			githubConnectorType, err = forgedomain.ParseGitHubConnectorType(*data.Hosting.GitHubConnectorType, messages.ConfigFile)
+		if data.Hosting.GithubConnector != nil {
+			githubConnectorType, err = forgedomain.ParseGithubConnectorType(*data.Hosting.GithubConnector, messages.ConfigFile)
 			ec.Check(err)
 		}
-		if data.Hosting.GitLabConnectorType != nil {
-			gitlabConnectorType, err = forgedomain.ParseGitLabConnectorType(*data.Hosting.GitLabConnectorType, messages.ConfigFile)
+		if data.Hosting.GitlabConnector != nil {
+			gitlabConnectorType, err = forgedomain.ParseGitlabConnectorType(*data.Hosting.GitlabConnector, messages.ConfigFile)
 			ec.Check(err)
 		}
 		if data.Hosting.OriginHostname != nil {
@@ -195,8 +209,13 @@ func Validate(data Data, finalMessages stringslice.Collector) (configdomain.Part
 		}
 	}
 	if data.Propose != nil {
+		// load the deprecated "lineage" setting first so that "breadcrumb" can override the value later
 		if data.Propose.Lineage != nil {
-			proposalsShowLineage, err = forgedomain.ParseProposalsShowLineage(*data.Propose.Lineage, messages.ConfigFile)
+			proposalBreadcrumb, err = forgedomain.ParseProposalBreadcrumb(*data.Propose.Lineage, messages.ConfigFile)
+			ec.Check(err)
+		}
+		if data.Propose.Breadcrumb != nil {
+			proposalBreadcrumb, err = forgedomain.ParseProposalBreadcrumb(*data.Propose.Breadcrumb, messages.ConfigFile)
 			ec.Check(err)
 		}
 	}
@@ -204,6 +223,9 @@ func Validate(data Data, finalMessages stringslice.Collector) (configdomain.Part
 		if data.Ship.DeleteTrackingBranch != nil {
 			shipDeleteTrackingBranch = Some(configdomain.ShipDeleteTrackingBranch(*data.Ship.DeleteTrackingBranch))
 		}
+		if data.Ship.IgnoreUncommitted != nil {
+			ignoreUncommitted = Some(configdomain.IgnoreUncommitted(*data.Ship.IgnoreUncommitted))
+		}
 		if data.Ship.Strategy != nil {
 			shipStrategy = Some(configdomain.ShipStrategy(*data.Ship.Strategy))
 		}
@@ -262,7 +284,9 @@ func Validate(data Data, finalMessages stringslice.Collector) (configdomain.Part
 		AutoSync:                 autoSync,
 		BitbucketAppPassword:     None[forgedomain.BitbucketAppPassword](),
 		BitbucketUsername:        None[forgedomain.BitbucketUsername](),
+		BranchPrefix:             branchPrefix,
 		BranchTypeOverrides:      configdomain.BranchTypeOverrides{},
+		Browser:                  browser,
 		ForgejoToken:             None[forgedomain.ForgejoToken](),
 		ContributionRegex:        contributionRegex,
 		Detached:                 detached,
@@ -272,10 +296,10 @@ func Validate(data Data, finalMessages stringslice.Collector) (configdomain.Part
 		DevRemote:                devRemote,
 		FeatureRegex:             featureRegex,
 		ForgeType:                forgeType,
-		GitHubConnectorType:      githubConnectorType,
-		GitHubToken:              None[forgedomain.GitHubToken](),
-		GitLabConnectorType:      gitlabConnectorType,
-		GitLabToken:              None[forgedomain.GitLabToken](),
+		GithubConnectorType:      githubConnectorType,
+		GithubToken:              None[forgedomain.GithubToken](),
+		GitlabConnectorType:      gitlabConnectorType,
+		GitlabToken:              None[forgedomain.GitlabToken](),
 		GitUserEmail:             None[gitdomain.GitUserEmail](),
 		GitUserName:              None[gitdomain.GitUserName](),
 		GiteaToken:               None[forgedomain.GiteaToken](),
@@ -289,11 +313,12 @@ func Validate(data Data, finalMessages stringslice.Collector) (configdomain.Part
 		Order:                    order,
 		PerennialBranches:        perennialBranches,
 		PerennialRegex:           perennialRegex,
-		ProposalsShowLineage:     proposalsShowLineage,
+		ProposalBreadcrumb:       proposalBreadcrumb,
 		PushBranches:             pushBranches,
 		PushHook:                 pushHook,
 		ShareNewBranches:         shareNewBranches,
 		ShipDeleteTrackingBranch: shipDeleteTrackingBranch,
+		IgnoreUncommitted:        ignoreUncommitted,
 		ShipStrategy:             shipStrategy,
 		Stash:                    stash,
 		SyncFeatureStrategy:      syncFeatureStrategy,
