@@ -45,62 +45,90 @@ func TestSave(t *testing.T) {
 		t.Parallel()
 		t.Run("all options given", func(t *testing.T) {
 			t.Parallel()
+			contributionRegex := asserts.NoError1(configdomain.ParseContributionRegex("contribution-", "test"))
+			featureRegex := asserts.NoError1(configdomain.ParseFeatureRegex("feature-", "test"))
+			observedRegex := asserts.NoError1(configdomain.ParseObservedRegex("observed-", "test"))
+			perennialRegex := asserts.NoError1(configdomain.ParsePerennialRegex("perennial-", "test"))
 			have := configfile.RenderTOML(configdomain.PartialConfig{
-				AutoResolve: Some(configdomain.AutoResolve(false)),
-				DevRemote:   Some(gitdomain.RemoteOrigin),
+				AutoResolve:       Some(configdomain.AutoResolve(false)),
+				BranchPrefix:      Some(configdomain.BranchPrefix("feature-")),
+				Browser:           Some(configdomain.Browser("chrome")),
+				ContributionRegex: contributionRegex,
+				Detached:          Some(configdomain.Detached(true)),
+				DevRemote:         Some(gitdomain.RemoteOrigin),
 				DisplayTypes: Some(configdomain.DisplayTypes{
 					BranchTypes: []configdomain.BranchType{configdomain.BranchTypeMainBranch, configdomain.BranchTypePerennialBranch},
 					Quantifier:  configdomain.QuantifierNo,
 				}),
+				FeatureRegex:             featureRegex,
 				ForgeType:                asserts.NoError1(forgedomain.ParseForgeType("github", "test")),
+				GithubConnectorType:      Some(forgedomain.GithubConnectorTypeGh),
+				GitlabConnectorType:      Some(forgedomain.GitlabConnectorTypeGlab),
 				HostingOriginHostname:    configdomain.ParseHostingOriginHostname("forge"),
+				IgnoreUncommitted:        Some(configdomain.IgnoreUncommitted(true)),
 				MainBranch:               Some(gitdomain.NewLocalBranchName("main")),
 				NewBranchType:            Some(configdomain.NewBranchType(configdomain.BranchTypePrototypeBranch)),
+				ObservedRegex:            observedRegex,
 				Order:                    Some(configdomain.OrderDesc),
 				PerennialBranches:        gitdomain.NewLocalBranchNames("qa", "staging"),
-				PerennialRegex:           asserts.NoError1(configdomain.ParsePerennialRegex("perennial-", "test")),
-				ProposalsShowLineage:     Some(forgedomain.ProposalsShowLineageCLI),
+				PerennialRegex:           perennialRegex,
+				ProposalBreadcrumb:       Some(forgedomain.ProposalBreadcrumbBranches),
+				PushBranches:             Some(configdomain.PushBranches(true)),
 				PushHook:                 Some(configdomain.PushHook(true)),
 				ShareNewBranches:         Some(configdomain.ShareNewBranchesPropose),
 				ShipDeleteTrackingBranch: Some(configdomain.ShipDeleteTrackingBranch(true)),
 				ShipStrategy:             Some(configdomain.ShipStrategyAPI),
+				Stash:                    Some(configdomain.Stash(true)),
 				SyncFeatureStrategy:      Some(configdomain.SyncFeatureStrategyMerge),
 				SyncPerennialStrategy:    Some(configdomain.SyncPerennialStrategyRebase),
 				SyncPrototypeStrategy:    Some(configdomain.SyncPrototypeStrategyCompress),
 				SyncTags:                 Some(configdomain.SyncTags(true)),
 				SyncUpstream:             Some(configdomain.SyncUpstream(true)),
+				UnknownBranchType:        Some(configdomain.UnknownBranchType(configdomain.BranchTypePrototypeBranch)),
 			})
 			want := `
 # See https://www.git-town.com/configuration-file for details
 
 [branches]
+contribution-regex = "contribution-"
+display-types = "no main perennial"
+feature-regex = "feature-"
 main = "main"
+observed-regex = "observed-"
 order = "desc"
 perennials = ["qa", "staging"]
 perennial-regex = "perennial-"
-display-types = "no main perennial"
+unknown-type = "prototype"
 
 [create]
+branch-prefix = "feature-"
 new-branch-type = "prototype"
 share-new-branches = "propose"
+stash = true
 
 [hosting]
+browser = "chrome"
 dev-remote = "origin"
 forge-type = "github"
+github-connector = "gh"
+gitlab-connector = "glab"
 origin-hostname = "forge"
 
 [propose]
-lineage = "cli"
+breadcrumb = "branches"
 
 [ship]
 delete-tracking-branch = true
+ignore-uncommitted = true
 strategy = "api"
 
 [sync]
 auto-resolve = false
+detached = true
 feature-strategy = "merge"
 perennial-strategy = "rebase"
 prototype-strategy = "compress"
+push-branches = true
 push-hook = true
 tags = true
 upstream = true
