@@ -18,14 +18,14 @@ func TestLoad(t *testing.T) {
 			env := envconfig.NewEnvVars([]string{})
 			cfg, err := envconfig.Load(env)
 			must.NoError(t, err)
-			must.True(t, cfg.GitHubToken.IsNone())
+			must.True(t, cfg.GithubToken.IsNone())
 		})
 		t.Run("GITHUB_TOKEN is set", func(t *testing.T) {
 			t.Parallel()
 			env := envconfig.NewEnvVars([]string{"GITHUB_TOKEN=my-token"})
 			cfg, err := envconfig.Load(env)
 			must.NoError(t, err)
-			token, has := cfg.GitHubToken.Get()
+			token, has := cfg.GithubToken.Get()
 			must.True(t, has)
 			must.Eq(t, token, "my-token")
 		})
@@ -34,15 +34,15 @@ func TestLoad(t *testing.T) {
 			env := envconfig.NewEnvVars([]string{"GITHUB_AUTH_TOKEN=my-auth-token"})
 			cfg, err := envconfig.Load(env)
 			must.NoError(t, err)
-			must.True(t, cfg.GitHubToken.EqualSome("my-auth-token"))
+			must.True(t, cfg.GithubToken.EqualSome("my-auth-token"))
 		})
 		t.Run("GITHUB_TOKEN and GITHUB_AUTH_TOKEN are set", func(t *testing.T) {
 			t.Parallel()
 			env := envconfig.NewEnvVars([]string{"GITHUB_AUTH_TOKEN=my-auth-token", "GITHUB_TOKEN=my-token"})
 			cfg, err := envconfig.Load(env)
 			must.NoError(t, err)
-			fmt.Println(cfg.GitHubToken)
-			must.True(t, cfg.GitHubToken.EqualSome("my-token"))
+			fmt.Println(cfg.GithubToken)
+			must.True(t, cfg.GithubToken.EqualSome("my-token"))
 		})
 	})
 }
