@@ -34,7 +34,9 @@ type NormalConfig struct {
 	AutoSync                 configdomain.AutoSync
 	BitbucketAppPassword     Option[forgedomain.BitbucketAppPassword]
 	BitbucketUsername        Option[forgedomain.BitbucketUsername]
+	BranchPrefix             Option[configdomain.BranchPrefix]
 	BranchTypeOverrides      configdomain.BranchTypeOverrides
+	Browser                  Option[configdomain.Browser]
 	ContributionRegex        Option[configdomain.ContributionRegex]
 	Detached                 configdomain.Detached
 	DevRemote                gitdomain.Remote
@@ -43,14 +45,15 @@ type NormalConfig struct {
 	FeatureRegex             Option[configdomain.FeatureRegex]
 	ForgeType                Option[forgedomain.ForgeType] // None = auto-detect
 	ForgejoToken             Option[forgedomain.ForgejoToken]
-	GitHubConnectorType      Option[forgedomain.GitHubConnectorType]
-	GitHubToken              Option[forgedomain.GitHubToken]
-	GitLabConnectorType      Option[forgedomain.GitLabConnectorType]
-	GitLabToken              Option[forgedomain.GitLabToken]
 	GitUserEmail             Option[gitdomain.GitUserEmail]
 	GitUserName              Option[gitdomain.GitUserName]
 	GiteaToken               Option[forgedomain.GiteaToken]
+	GithubConnectorType      Option[forgedomain.GithubConnectorType]
+	GithubToken              Option[forgedomain.GithubToken]
+	GitlabConnectorType      Option[forgedomain.GitlabConnectorType]
+	GitlabToken              Option[forgedomain.GitlabToken]
 	HostingOriginHostname    Option[configdomain.HostingOriginHostname]
+	IgnoreUncommitted        configdomain.IgnoreUncommitted
 	Lineage                  configdomain.Lineage
 	NewBranchType            Option[configdomain.NewBranchType]
 	ObservedRegex            Option[configdomain.ObservedRegex]
@@ -58,7 +61,7 @@ type NormalConfig struct {
 	Order                    configdomain.Order
 	PerennialBranches        gitdomain.LocalBranchNames
 	PerennialRegex           Option[configdomain.PerennialRegex]
-	ProposalsShowLineage     forgedomain.ProposalsShowLineage
+	ProposalBreadcrumb       forgedomain.ProposalBreadcrumb
 	PushBranches             configdomain.PushBranches
 	PushHook                 configdomain.PushHook
 	ShareNewBranches         configdomain.ShareNewBranches
@@ -91,7 +94,7 @@ func (self *NormalConfig) DevURL(querier subshelldomain.Querier) Option[giturl.P
 	return self.RemoteURL(querier, self.DevRemote)
 }
 
-// provides a new NormalConfig that contains data from the given PartialConfig,
+// OverwriteWith provides a new NormalConfig that contains data from the given PartialConfig,
 // backfilled with data from this NormalConfig where missing
 func (self *NormalConfig) OverwriteWith(other configdomain.PartialConfig) NormalConfig {
 	return NormalConfig{
@@ -100,7 +103,9 @@ func (self *NormalConfig) OverwriteWith(other configdomain.PartialConfig) Normal
 		AutoSync:                 other.AutoSync.GetOr(self.AutoSync),
 		BitbucketAppPassword:     other.BitbucketAppPassword.Or(self.BitbucketAppPassword),
 		BitbucketUsername:        other.BitbucketUsername.Or(self.BitbucketUsername),
+		BranchPrefix:             other.BranchPrefix.Or(self.BranchPrefix),
 		BranchTypeOverrides:      other.BranchTypeOverrides.Concat(self.BranchTypeOverrides),
+		Browser:                  other.Browser.Or(self.Browser),
 		ContributionRegex:        other.ContributionRegex.Or(self.ContributionRegex),
 		Detached:                 other.Detached.GetOr(self.Detached),
 		DevRemote:                other.DevRemote.GetOr(self.DevRemote),
@@ -109,14 +114,15 @@ func (self *NormalConfig) OverwriteWith(other configdomain.PartialConfig) Normal
 		FeatureRegex:             other.FeatureRegex.Or(self.FeatureRegex),
 		ForgeType:                other.ForgeType.Or(self.ForgeType),
 		ForgejoToken:             other.ForgejoToken.Or(self.ForgejoToken),
-		GitHubConnectorType:      other.GitHubConnectorType.Or(self.GitHubConnectorType),
-		GitHubToken:              other.GitHubToken.Or(self.GitHubToken),
-		GitLabConnectorType:      other.GitLabConnectorType.Or(self.GitLabConnectorType),
-		GitLabToken:              other.GitLabToken.Or(self.GitLabToken),
 		GitUserEmail:             other.GitUserEmail.Or(self.GitUserEmail),
 		GitUserName:              other.GitUserName.Or(self.GitUserName),
 		GiteaToken:               other.GiteaToken.Or(self.GiteaToken),
+		GithubConnectorType:      other.GithubConnectorType.Or(self.GithubConnectorType),
+		GithubToken:              other.GithubToken.Or(self.GithubToken),
+		GitlabConnectorType:      other.GitlabConnectorType.Or(self.GitlabConnectorType),
+		GitlabToken:              other.GitlabToken.Or(self.GitlabToken),
 		HostingOriginHostname:    other.HostingOriginHostname.Or(self.HostingOriginHostname),
+		IgnoreUncommitted:        other.IgnoreUncommitted.GetOr(self.IgnoreUncommitted),
 		Lineage:                  other.Lineage.Merge(self.Lineage),
 		NewBranchType:            other.NewBranchType.Or(self.NewBranchType),
 		ObservedRegex:            other.ObservedRegex.Or(self.ObservedRegex),
@@ -124,7 +130,7 @@ func (self *NormalConfig) OverwriteWith(other configdomain.PartialConfig) Normal
 		Order:                    other.Order.GetOr(self.Order),
 		PerennialBranches:        other.PerennialBranches.AppendAllMissing(self.PerennialBranches),
 		PerennialRegex:           other.PerennialRegex.Or(self.PerennialRegex),
-		ProposalsShowLineage:     other.ProposalsShowLineage.GetOr(self.ProposalsShowLineage),
+		ProposalBreadcrumb:       other.ProposalBreadcrumb.GetOr(self.ProposalBreadcrumb),
 		PushBranches:             other.PushBranches.GetOr(self.PushBranches),
 		PushHook:                 other.PushHook.GetOr(self.PushHook),
 		ShareNewBranches:         other.ShareNewBranches.GetOr(self.ShareNewBranches),
@@ -217,7 +223,7 @@ func (self *NormalConfig) RemovePerennialAncestors(runner subshelldomain.Runner,
 		if self.Lineage.Parent(perennialBranch).IsSome() {
 			_ = gitconfig.RemoveParent(runner, perennialBranch)
 			self.Lineage = self.Lineage.RemoveBranch(perennialBranch)
-			finalMessages.Add(fmt.Sprintf(messages.PerennialBranchRemovedParentEntry, perennialBranch))
+			finalMessages.Addf(messages.PerennialBranchRemovedParentEntry, perennialBranch)
 		}
 	}
 }
@@ -249,7 +255,9 @@ func DefaultNormalConfig() NormalConfig {
 		AutoSync:             true,
 		BitbucketAppPassword: None[forgedomain.BitbucketAppPassword](),
 		BitbucketUsername:    None[forgedomain.BitbucketUsername](),
+		BranchPrefix:         None[configdomain.BranchPrefix](),
 		BranchTypeOverrides:  configdomain.BranchTypeOverrides{},
+		Browser:              None[configdomain.Browser](),
 		ContributionRegex:    None[configdomain.ContributionRegex](),
 		Detached:             false,
 		DevRemote:            gitdomain.RemoteOrigin,
@@ -261,14 +269,15 @@ func DefaultNormalConfig() NormalConfig {
 		FeatureRegex:             None[configdomain.FeatureRegex](),
 		ForgeType:                None[forgedomain.ForgeType](),
 		ForgejoToken:             None[forgedomain.ForgejoToken](),
-		GitHubConnectorType:      None[forgedomain.GitHubConnectorType](),
-		GitHubToken:              None[forgedomain.GitHubToken](),
-		GitLabConnectorType:      None[forgedomain.GitLabConnectorType](),
-		GitLabToken:              None[forgedomain.GitLabToken](),
 		GitUserEmail:             None[gitdomain.GitUserEmail](),
 		GitUserName:              None[gitdomain.GitUserName](),
 		GiteaToken:               None[forgedomain.GiteaToken](),
+		GithubConnectorType:      None[forgedomain.GithubConnectorType](),
+		GithubToken:              None[forgedomain.GithubToken](),
+		GitlabConnectorType:      None[forgedomain.GitlabConnectorType](),
+		GitlabToken:              None[forgedomain.GitlabToken](),
 		HostingOriginHostname:    None[configdomain.HostingOriginHostname](),
+		IgnoreUncommitted:        false,
 		Lineage:                  configdomain.NewLineage(),
 		NewBranchType:            None[configdomain.NewBranchType](),
 		ObservedRegex:            None[configdomain.ObservedRegex](),
@@ -276,7 +285,7 @@ func DefaultNormalConfig() NormalConfig {
 		Order:                    configdomain.OrderAsc,
 		PerennialBranches:        gitdomain.LocalBranchNames{},
 		PerennialRegex:           None[configdomain.PerennialRegex](),
-		ProposalsShowLineage:     forgedomain.ProposalsShowLineageNone,
+		ProposalBreadcrumb:       forgedomain.ProposalBreadcrumbNone,
 		PushBranches:             true,
 		PushHook:                 true,
 		ShareNewBranches:         configdomain.ShareNewBranchesNone,
@@ -301,7 +310,9 @@ func NewNormalConfigFromPartial(partial configdomain.PartialConfig, defaults Nor
 		AutoSync:                 partial.AutoSync.GetOr(defaults.AutoSync),
 		BitbucketAppPassword:     partial.BitbucketAppPassword,
 		BitbucketUsername:        partial.BitbucketUsername,
+		BranchPrefix:             partial.BranchPrefix,
 		BranchTypeOverrides:      partial.BranchTypeOverrides,
+		Browser:                  partial.Browser.Or(defaults.Browser),
 		ContributionRegex:        partial.ContributionRegex,
 		Detached:                 partial.Detached.GetOr(defaults.Detached),
 		DevRemote:                partial.DevRemote.GetOr(defaults.DevRemote),
@@ -310,14 +321,15 @@ func NewNormalConfigFromPartial(partial configdomain.PartialConfig, defaults Nor
 		FeatureRegex:             partial.FeatureRegex,
 		ForgeType:                partial.ForgeType,
 		ForgejoToken:             partial.ForgejoToken,
-		GitHubConnectorType:      partial.GitHubConnectorType,
-		GitHubToken:              partial.GitHubToken,
-		GitLabConnectorType:      partial.GitLabConnectorType,
-		GitLabToken:              partial.GitLabToken,
 		GitUserEmail:             partial.GitUserEmail,
 		GitUserName:              partial.GitUserName,
 		GiteaToken:               partial.GiteaToken,
+		GithubConnectorType:      partial.GithubConnectorType,
+		GithubToken:              partial.GithubToken,
+		GitlabConnectorType:      partial.GitlabConnectorType,
+		GitlabToken:              partial.GitlabToken,
 		HostingOriginHostname:    partial.HostingOriginHostname,
+		IgnoreUncommitted:        partial.IgnoreUncommitted.GetOr(defaults.IgnoreUncommitted),
 		Lineage:                  partial.Lineage,
 		NewBranchType:            partial.NewBranchType.Or(defaults.NewBranchType),
 		ObservedRegex:            partial.ObservedRegex,
@@ -325,7 +337,7 @@ func NewNormalConfigFromPartial(partial configdomain.PartialConfig, defaults Nor
 		Order:                    partial.Order.GetOr(defaults.Order),
 		PerennialBranches:        partial.PerennialBranches,
 		PerennialRegex:           partial.PerennialRegex,
-		ProposalsShowLineage:     partial.ProposalsShowLineage.GetOr(defaults.ProposalsShowLineage),
+		ProposalBreadcrumb:       partial.ProposalBreadcrumb.GetOr(defaults.ProposalBreadcrumb),
 		PushBranches:             partial.PushBranches.GetOr(defaults.PushBranches),
 		PushHook:                 partial.PushHook.GetOr(defaults.PushHook),
 		ShareNewBranches:         partial.ShareNewBranches.GetOr(defaults.ShareNewBranches),
