@@ -1,6 +1,7 @@
 package azuredevops
 
 import (
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
 	"github.com/git-town/git-town/v22/internal/forge/forgedomain"
 	"github.com/git-town/git-town/v22/internal/git/giturl"
 	. "github.com/git-town/git-town/v22/pkg/prelude"
@@ -12,8 +13,8 @@ func Detect(remoteURL giturl.Parts) bool {
 }
 
 type NewConnectorArgs struct {
-	ProposalOverride Option[forgedomain.ProposalOverride]
-	RemoteURL        giturl.Parts
+	Browser   Option[configdomain.Browser]
+	RemoteURL giturl.Parts
 }
 
 // NewConnector provides the correct connector for talking to Azure DevOps.
@@ -24,5 +25,6 @@ func NewConnector(args NewConnectorArgs) WebConnector {
 			Organization: args.RemoteURL.Org,
 			Repository:   args.RemoteURL.Repo,
 		},
+		browser: args.Browser,
 	}
 }
