@@ -15,8 +15,7 @@ func TestWebConnector(t *testing.T) {
 	t.Parallel()
 	url := giturl.Parse("git@ssh.dev.azure.com:v3/kevingoslar/tikibase/tikibase").GetOrPanic()
 	connector := azuredevops.NewConnector(azuredevops.NewConnectorArgs{
-		ProposalOverride: None[forgedomain.ProposalOverride](),
-		RemoteURL:        url,
+		RemoteURL: url,
 	})
 
 	t.Run("NewProposalURL", func(t *testing.T) {
@@ -26,7 +25,7 @@ func TestWebConnector(t *testing.T) {
 			FrontendRunner: nil,
 			MainBranch:     "main",
 			ParentBranch:   "parent",
-			ProposalBody:   Some(gitdomain.ProposalBody("body")),
+			ProposalBody:   gitdomain.NewProposalBodyOpt("body"),
 			ProposalTitle:  Some(gitdomain.ProposalTitle("title")),
 		})
 		want := "https://dev.azure.com/kevingoslar/tikibase/_git/tikibase/pullrequestcreate?sourceRef=feature&targetRef=parent"
