@@ -42,60 +42,42 @@ type VerifyCredentialsResult struct {
 	AuthorizationError  error          // error while verifying authorization, nil == user is authenticated
 }
 
-// ProposalUpdater describes methods that connectors need to implement
+// ProposalBodyUpdater describes methods that connectors need to implement
 // to enable Git Town to update proposals at the active forge.
 type ProposalBodyUpdater interface {
-	// If the connector instance supports loading proposals via the API,
-	// calling this function returns a function that you can call
-	// to update the body (description) of the given proposal to the given value.
-	// A None return value indicates that this connector does not support this feature (yet).
-	UpdateProposalBody(proposal ProposalInterface, newBody string) error
+	// Updates the body (description) of the given proposal to the given value.
+	UpdateProposalBody(proposal ProposalInterface, newBody gitdomain.ProposalBody) error
 }
 
 // ProposalFinder describes methods that connectors need to implement
 // to enable Git Town to find proposals at the active forge.
 type ProposalFinder interface {
-	// If this connector instance supports loading proposals via the API,
-	// calling this function returns a function that you can call
-	// to load details about the proposal for the given branch into the given target branch.
-	// A None return value indicates that this connector does not support this feature (yet).
+	// Loads details about the proposal for the given branch into the given target branch.
 	FindProposal(branch, target gitdomain.LocalBranchName) (Option[Proposal], error)
 }
 
 // ProposalMerger describes methods that connectors need to implement
 // to enable Git Town to merge for proposals at the active forge.
 type ProposalMerger interface {
-	// If this connector instance supports loading proposals via the API,
-	// calling this function returns a function that you can call
-	// to merge the proposal with the given number using the given message.
-	// A None return value indicates that this connector does not support this feature (yet).
-	SquashMergeProposal(number int, message gitdomain.CommitMessage) error
+	// Merges the proposal with the given number using the given message.
+	SquashMergeProposal(number ProposalNumber, message gitdomain.CommitMessage) error
 }
 
 // ProposalSearcher describes methods that connectors need to implement
 // to enable Git Town to search for proposals at the active forge.
 type ProposalSearcher interface {
-	// If this connector instance supports loading proposals via the API,
-	// calling this function returns a function that you can call
-	// to search for a proposal that has the given branch as its source branch.
-	// A None return value indicates that this connector does not support this feature (yet).
-	SearchProposal(branch gitdomain.LocalBranchName) (Option[Proposal], error)
+	// SearchProposals finds all active proposals that have the given branch as its source branch.
+	SearchProposals(branch gitdomain.LocalBranchName) ([]Proposal, error)
 }
 
 // ProposalSourceUpdater describes methods that connectors need to implement
 // to enable Git Town to update the source branch of proposals at the active forge.
 type ProposalSourceUpdater interface {
-	// If this connector instance supports loading proposals via the API,
-	// calling this function returns a function that you can call
-	// to update the source branch of the proposal with the given number.
-	// A None return value indicates that this connector does not support this feature (yet).
+	// Updates the source branch of the proposal with the given number.
 	UpdateProposalSource(proposal ProposalInterface, newSource gitdomain.LocalBranchName) error
 }
 
 type ProposalTargetUpdater interface {
-	// If this connector instance supports loading proposals via the API,
-	// calling this function returns a function that you can call
-	// to update the target branch of the proposal with the given number.
-	// A None return value indicates that this connector does not support this feature (yet).
+	// Updates the target branch of the proposal with the given number.
 	UpdateProposalTarget(proposal ProposalInterface, newTarget gitdomain.LocalBranchName) error
 }
