@@ -14,7 +14,7 @@ type Proposal struct {
 }
 
 func (self Proposal) MarshalJSON() ([]byte, error) {
-	return json.Marshal(map[string]interface{}{
+	return json.Marshal(map[string]any{
 		"data":       self.Data,
 		"forge-type": self.ForgeType.String(),
 	})
@@ -43,7 +43,7 @@ func (self *Proposal) UnmarshalJSON(b []byte) error {
 		var data BitbucketCloudProposalData
 		err = json.Unmarshal(mapping["data"], &data)
 		self.Data = data
-	case ForgeTypeAzureDevOps, ForgeTypeBitbucketDatacenter, ForgeTypeForgejo, ForgeTypeGitHub, ForgeTypeGitLab, ForgeTypeGitea:
+	case ForgeTypeAzuredevops, ForgeTypeBitbucketDatacenter, ForgeTypeForgejo, ForgeTypeGithub, ForgeTypeGitlab, ForgeTypeGitea:
 		var data ProposalData
 		err = json.Unmarshal(mapping["data"], &data)
 		self.Data = data
