@@ -6,12 +6,13 @@ import (
 )
 
 type ProposalData struct {
-	Body         Option[string]
+	Active       bool // whether the proposal is open
+	Body         Option[gitdomain.ProposalBody]
 	MergeWithAPI bool
-	Number       int
+	Number       ProposalNumber
 	Source       gitdomain.LocalBranchName
 	Target       gitdomain.LocalBranchName
-	Title        string
+	Title        gitdomain.ProposalTitle
 	URL          string
 }
 
