@@ -2,11 +2,10 @@ package forgedomain_test
 
 import (
 	"encoding/json"
-	"fmt"
 	"testing"
 
 	"github.com/git-town/git-town/v22/internal/forge/forgedomain"
-	. "github.com/git-town/git-town/v22/pkg/prelude"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
 	"github.com/shoenig/test/must"
 )
 
@@ -17,7 +16,8 @@ func TestBitbucketCloudProposalData(t *testing.T) {
 		t.Parallel()
 		data := forgedomain.BitbucketCloudProposalData{
 			ProposalData: forgedomain.ProposalData{
-				Body:         Some("body"),
+				Active:       true,
+				Body:         gitdomain.NewProposalBodyOpt("body"),
 				MergeWithAPI: true,
 				Number:       123,
 				Source:       "source",
@@ -30,9 +30,9 @@ func TestBitbucketCloudProposalData(t *testing.T) {
 		}
 		serialized, err := json.MarshalIndent(data, "", "  ")
 		must.NoError(t, err)
-		fmt.Println(string(serialized))
 		want := `
 {
+  "Active": true,
   "Body": "body",
   "MergeWithAPI": true,
   "Number": 123,
