@@ -5,8 +5,10 @@ import (
 	"net/url"
 
 	"github.com/git-town/git-town/v22/internal/browser"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
 	"github.com/git-town/git-town/v22/internal/forge/forgedomain"
 	"github.com/git-town/git-town/v22/internal/subshell/subshelldomain"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 )
 
 var (
@@ -17,15 +19,16 @@ var (
 // WebConnector provides connectivity to Forgejo through the web browser.
 type WebConnector struct {
 	forgedomain.HostedRepoInfo
+	browser Option[configdomain.Browser]
 }
 
 func (self WebConnector) BrowseRepository(runner subshelldomain.Runner) error {
-	browser.Open(self.RepositoryURL(), runner)
+	browser.Open(self.RepositoryURL(), runner, self.browser)
 	return nil
 }
 
 func (self WebConnector) CreateProposal(data forgedomain.CreateProposalArgs) error {
-	browser.Open(self.NewProposalURL(data), data.FrontendRunner)
+	browser.Open(self.NewProposalURL(data), data.FrontendRunner, self.browser)
 	return nil
 }
 
