@@ -3,18 +3,18 @@ package gitlab
 import (
 	"github.com/git-town/git-town/v22/internal/forge/forgedomain"
 	"github.com/git-town/git-town/v22/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v22/pkg/prelude"
 	gitlab "gitlab.com/gitlab-org/api/client-go"
 )
 
 func parseMergeRequest(mergeRequest *gitlab.BasicMergeRequest) forgedomain.ProposalData {
 	return forgedomain.ProposalData{
+		Active:       mergeRequest.State == "opened",
 		MergeWithAPI: true,
-		Number:       mergeRequest.IID,
+		Number:       forgedomain.ProposalNumber(mergeRequest.IID),
 		Source:       gitdomain.NewLocalBranchName(mergeRequest.SourceBranch),
 		Target:       gitdomain.NewLocalBranchName(mergeRequest.TargetBranch),
-		Title:        mergeRequest.Title,
-		Body:         NewOption(mergeRequest.Description),
+		Title:        gitdomain.ProposalTitle(mergeRequest.Title),
+		Body:         gitdomain.NewProposalBodyOpt(mergeRequest.Description),
 		URL:          mergeRequest.WebURL,
 	}
 }
