@@ -2,6 +2,7 @@ package forge
 
 import (
 	"github.com/git-town/git-town/v22/internal/cli/print"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
 	"github.com/git-town/git-town/v22/internal/forge/azuredevops"
 	"github.com/git-town/git-town/v22/internal/forge/bitbucketcloud"
 	"github.com/git-town/git-town/v22/internal/forge/bitbucketdatacenter"
@@ -24,94 +25,85 @@ func NewConnector(args NewConnectorArgs) (Option[forgedomain.Connector], error)
 	if !hasRemoteURL || !hasForgeType {
 		return None[forgedomain.Connector](), nil
 	}
-	proposalOverride := forgedomain.ReadProposalOverride()
 	var connector forgedomain.Connector
 	var err error
 	switch forgeType {
-	case forgedomain.ForgeTypeAzureDevOps:
+	case forgedomain.ForgeTypeAzuredevops:
 		connector = azuredevops.NewConnector(azuredevops.NewConnectorArgs{
-			ProposalOverride: proposalOverride,
-			RemoteURL:        remoteURL,
+			Browser:   args.Browser,
+			RemoteURL: remoteURL,
 		})
 	case forgedomain.ForgeTypeBitbucket:
 		connector = bitbucketcloud.NewConnector(bitbucketcloud.NewConnectorArgs{
-			AppPassword:      args.BitbucketAppPassword,
-			Log:              args.Log,
-			ProposalOverride: proposalOverride,
-			RemoteURL:        remoteURL,
-			UserName:         args.BitbucketUsername,
+			AppPassword: args.BitbucketAppPassword,
+			Browser:     args.Browser,
+			ConfigDir:   args.ConfigDir,
+			Log:         args.Log,
+			RemoteURL:   remoteURL,
+			UserName:    args.BitbucketUsername,
 		})
 	case forgedomain.ForgeTypeBitbucketDatacenter:
 		connector = bitbucketdatacenter.NewConnector(bitbucketdatacenter.NewConnectorArgs{
-			AppPassword:      args.BitbucketAppPassword,
-			Log:              args.Log,
-			ProposalOverride: proposalOverride,
-			RemoteURL:        remoteURL,
-			UserName:         args.BitbucketUsername,
+			AppPassword: args.BitbucketAppPassword,
+			Browser:     args.Browser,
+			ConfigDir:   args.ConfigDir,
+			Log:         args.Log,
+			RemoteURL:   remoteURL,
+			UserName:    args.BitbucketUsername,
 		})
 	case forgedomain.ForgeTypeForgejo:
 		connector = forgejo.NewConnector(forgejo.NewConnectorArgs{
-			APIToken:         args.ForgejoToken,
-			Log:              args.Log,
-			ProposalOverride: proposalOverride,
-			RemoteURL:        remoteURL,
+			APIToken:  args.ForgejoToken,
+			Browser:   args.Browser,
+			ConfigDir: args.ConfigDir,
+			Log:       args.Log,
+			RemoteURL: remoteURL,
 		})
 	case forgedomain.ForgeTypeGitea:
 		connector = gitea.NewConnector(gitea.NewConnectorArgs{
-			APIToken:         args.GiteaToken,
-			Log:              args.Log,
-			ProposalOverride: proposalOverride,
-			RemoteURL:        remoteURL,
+			APIToken:  args.GiteaToken,
+			Browser:   args.Browser,
+			ConfigDir: args.ConfigDir,
+			Log:       args.Log,
+			RemoteURL: remoteURL,
 		})
-	case forgedomain.ForgeTypeGitHub:
-		if githubConnectorType, hasGitHubConnectorType := args.GitHubConnectorType.Get(); hasGitHubConnectorType {
-			switch githubConnectorType {
-			case forgedomain.GitHubConnectorTypeAPI:
-				connector, err = github.NewConnector(github.NewConnectorArgs{
-					APIToken:         args.GitHubToken,
-					Log:              args.Log,
-					ProposalOverride: proposalOverride,
-					RemoteURL:        remoteURL,
-				})
-			case forgedomain.GitHubConnectorTypeGh:
-				connector = gh.Connector{
-					Backend:  args.Backend,
-					Frontend: args.Frontend,
-				}
-			}
-		} else {
-			// no GitHubConnectorType specified --> use the API connector
+	case forgedomain.ForgeTypeGithub:
+		switch args.GithubConnectorType.GetOr(forgedomain.GithubConnectorTypeAPI) {
+		case forgedomain.GithubConnectorTypeAPI:
 			connector, err = github.NewConnector(github.NewConnectorArgs{
-				APIToken:         args.GitHubToken,
-				Log:              args.Log,
-				ProposalOverride: proposalOverride,
-				RemoteURL:        remoteURL,
+				APIToken:  args.GithubToken,
+				Browser:   args.Browser,
+				ConfigDir: args.ConfigDir,
+				Log:       args.Log,
+				RemoteURL: remoteURL,
 			})
-		}
-	case forgedomain.ForgeTypeGitLab:
-		if gitLabConnectorType, hasGitLabConnectorType := args.GitLabConnectorType.Get(); hasGitLabConnectorType {
-			switch gitLabConnectorType {
-			case forgedomain.GitLabConnectorTypeAPI:
-				connector, err = gitlab.NewConnector(gitlab.NewConnectorArgs{
-					APIToken:         args.GitLabToken,
-					Log:              args.Log,
-					ProposalOverride: proposalOverride,
-					RemoteURL:        remoteURL,
-				})
-			case forgedomain.GitLabConnectorTypeGlab:
-				connector = glab.Connector{
+		case forgedomain.GithubConnectorTypeGh:
+			connector = &gh.CachedConnector{
+				Connector: gh.Connector{
 					Backend:  args.Backend,
 					Frontend: args.Frontend,
-				}
+				},
+				Cache: forgedomain.APICache{},
 			}
-		} else {
-			// no GitLabConnectorType specified --> use the API connector
+		}
+	case forgedomain.ForgeTypeGitlab:
+		switch args.GitlabConnectorType.GetOr(forgedomain.GitlabConnectorTypeAPI) {
+		case forgedomain.GitlabConnectorTypeAPI:
 			connector, err = gitlab.NewConnector(gitlab.NewConnectorArgs{
-				APIToken:         args.GitLabToken,
-				Log:              args.Log,
-				ProposalOverride: proposalOverride,
-				RemoteURL:        remoteURL,
+				APIToken:  args.GitlabToken,
+				Browser:   args.Browser,
+				ConfigDir: args.ConfigDir,
+				Log:       args.Log,
+				RemoteURL: remoteURL,
 			})
+		case forgedomain.GitlabConnectorTypeGlab:
+			connector = &glab.CachedConnector{
+				Connector: glab.Connector{
+					Backend:  args.Backend,
+					Frontend: args.Frontend,
+				},
+				Cache: forgedomain.APICache{},
+			}
 		}
 	}
 	return NewOption(connector), err
@@ -121,14 +113,16 @@ type NewConnectorArgs struct {
 	Backend              subshelldomain.Querier
 	BitbucketAppPassword Option[forgedomain.BitbucketAppPassword]
 	BitbucketUsername    Option[forgedomain.BitbucketUsername]
+	Browser              Option[configdomain.Browser]
+	ConfigDir            configdomain.RepoConfigDir
 	ForgeType            Option[forgedomain.ForgeType]
 	ForgejoToken         Option[forgedomain.ForgejoToken]
 	Frontend             subshelldomain.Runner
-	GitHubConnectorType  Option[forgedomain.GitHubConnectorType]
-	GitHubToken          Option[forgedomain.GitHubToken]
-	GitLabConnectorType  Option[forgedomain.GitLabConnectorType]
-	GitLabToken          Option[forgedomain.GitLabToken]
 	GiteaToken           Option[forgedomain.GiteaToken]
+	GithubConnectorType  Option[forgedomain.GithubConnectorType]
+	GithubToken          Option[forgedomain.GithubToken]
+	GitlabConnectorType  Option[forgedomain.GitlabConnectorType]
+	GitlabToken          Option[forgedomain.GitlabToken]
 	Log                  print.Logger
 	RemoteURL            Option[giturl.Parts]
 }
