@@ -8,6 +8,7 @@ import (
 	"slices"
 	"strconv"
 	"strings"
+	"sync"
 
 	"github.com/git-town/git-town/v22/internal/config/configdomain"
 	"github.com/git-town/git-town/v22/internal/config/gitconfig"
@@ -62,7 +63,7 @@ func (self *Commands) BranchExists(runner subshelldomain.Runner, branch gitdomai
 	return err == nil
 }
 
-func (self *Commands) BranchExistsRemotely(runner subshelldomain.Runner, branch gitdomain.LocalBranchName, remote gitdomain.Remote) bool {
+func (self *Commands) BranchExistsAtRemote(runner subshelldomain.Runner, branch gitdomain.LocalBranchName, remote gitdomain.Remote) bool {
 	err := runner.Run("git", "ls-remote", remote.String(), branch.String())
 	return err == nil
 }
@@ -81,10 +82,10 @@ func (self *Commands) BranchInSyncWithParent(querier subshelldomain.Querier, bra
 
 // BranchInSyncWithTracking returns whether the local branch with the given name
 // contains commits that have not been pushed to its tracking branch.
-func (self *Commands) BranchInSyncWithTracking(querier subshelldomain.Querier, branch gitdomain.LocalBranchName, devRemote gitdomain.Remote) (bool, error) {
-	out, err := querier.QueryTrim("git", "rev-parse", branch.String(), branch.TrackingBranch(devRemote).String())
+func (self *Commands) BranchInSyncWithTracking(querier subshelldomain.Querier, localBranch gitdomain.LocalBranchName, trackingBranch gitdomain.RemoteBranchName) (bool, error) {
+	out, err := querier.QueryTrim("git", "rev-parse", localBranch.String(), trackingBranch.String())
 	if err != nil {
-		return false, fmt.Errorf(messages.DiffProblem, branch, branch, err)
+		return false, fmt.Errorf(messages.DiffProblem, localBranch, trackingBranch, err)
 	}
 	lines := strings.Split(out, "\n")
 	if len(lines) != 2 {
@@ -95,6 +96,32 @@ func (self *Commands) BranchInSyncWithTracking(querier subshelldomain.Querier, b
 	return branchSHA == trackingSHA, nil
 }
 
+func (self *Commands) BranchesAvailableInCurrentWorktree(querier subshelldomain.Querier) (gitdomain.LocalBranchNames, error) {
+	branches, err := branchesQuery(querier)
+	if err != nil {
+		return gitdomain.LocalBranchNames{}, err
+	}
+	result := gitdomain.LocalBranchNames{}
+	for _, branch := range branches {
+		// Skip symbolic refs
+		if branch.Symref {
+			continue
+		}
+		// Only include local branches
+		if !isLocalRefName(branch.RefName) {
+			continue
+		}
+		// Include branches that are not checked out in other worktrees
+		// A branch is available in the current worktree if:
+		// - It's not checked out anywhere (!branch.Worktree), OR
+		// - It's checked out in the current worktree (branch.Head)
+		if !branch.Worktree || branch.Head {
+			result = append(result, branch.BranchName.LocalName())
+		}
+	}
+	return result, nil
+}
+
 func (self *Commands) BranchesSnapshot(querier subshelldomain.Querier) (gitdomain.BranchesSnapshot, error) {
 	branches, err := branchesQuery(querier)
 	if err != nil {
@@ -126,8 +153,7 @@ func (self *Commands) BranchesSnapshot(querier subshelldomain.Querier) (gitdomai
 		switch {
 		case branch.Worktree && !branch.Head:
 			result = append(result, gitdomain.BranchInfo{
-				LocalName:  Some(branch.BranchName.LocalName()),
-				LocalSHA:   Some(branch.SHA),
+				Local:      Some(gitdomain.BranchData{Name: branch.BranchName.LocalName(), SHA: branch.SHA}),
 				RemoteName: branch.UpstreamOption,
 				RemoteSHA:  None[gitdomain.SHA](), // may be added later
 				SyncStatus: gitdomain.SyncStatusOtherWorktree,
@@ -135,8 +161,7 @@ func (self *Commands) BranchesSnapshot(querier subshelldomain.Querier) (gitdomai
 		case isLocalRefName(branch.RefName):
 			syncStatus := determineSyncStatus(branch.Track, branch.UpstreamOption)
 			result = append(result, gitdomain.BranchInfo{
-				LocalName:  Some(branch.BranchName.LocalName()),
-				LocalSHA:   Some(branch.SHA),
+				Local:      Some(gitdomain.BranchData{Name: branch.BranchName.LocalName(), SHA: branch.SHA}),
 				RemoteName: branch.UpstreamOption,
 				RemoteSHA:  None[gitdomain.SHA](), // may be added later
 				SyncStatus: syncStatus,
@@ -148,8 +173,7 @@ func (self *Commands) BranchesSnapshot(querier subshelldomain.Querier) (gitdomai
 				existingBranchWithTracking.RemoteSHA = Some(branch.SHA)
 			} else {
 				result = append(result, gitdomain.BranchInfo{
-					LocalName:  None[gitdomain.LocalBranchName](),
-					LocalSHA:   None[gitdomain.SHA](),
+					Local:      None[gitdomain.BranchData](),
 					RemoteName: Some(remoteBranchName),
 					RemoteSHA:  Some(branch.SHA),
 					SyncStatus: gitdomain.SyncStatusRemoteOnly,
@@ -173,8 +197,7 @@ func (self *Commands) BranchesSnapshot(querier subshelldomain.Querier) (gitdomai
 			currentBranchOpt = gitdomain.NewLocalBranchNameOption(headSHA.String())
 			// prepend to result
 			result = slices.Insert(result, 0, gitdomain.BranchInfo{
-				LocalName:  currentBranchOpt,
-				LocalSHA:   Some(headSHA),
+				Local:      Some(gitdomain.BranchData{Name: gitdomain.LocalBranchName(headSHA.String()), SHA: headSHA}),
 				RemoteName: None[gitdomain.RemoteBranchName](),
 				RemoteSHA:  None[gitdomain.SHA](),
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
@@ -243,10 +266,18 @@ func (self *Commands) CommentOutSquashCommitMessage(prefix Option[string]) error
 	if prefix, hasPrefix := prefix.Get(); hasPrefix {
 		content = prefix + "\n" + content
 	}
-	content = regexp.MustCompile("(?m)^").ReplaceAllString(content, "# ")
+	commentOutSquashCommitMessageOnce.Do(func() {
+		commentOutSquashCommitMessageRegex = regexp.MustCompile("(?m)^")
+	})
+	content = commentOutSquashCommitMessageRegex.ReplaceAllString(content, "# ")
 	return os.WriteFile(squashMessageFile, []byte(content), 0o600)
 }
 
+var (
+	commentOutSquashCommitMessageOnce  sync.Once
+	commentOutSquashCommitMessageRegex *regexp.Regexp
+)
+
 func (self *Commands) Commit(runner subshelldomain.Runner, useMessage configdomain.UseMessage, author Option[gitdomain.Author], commitHook configdomain.CommitHook) error {
 	args := []string{"commit"}
 	switch {
@@ -292,12 +323,9 @@ func (self *Commands) CommitsInFeatureBranch(querier subshelldomain.Querier, bra
 	if err != nil {
 		return gitdomain.Commits{}, err
 	}
-	lines := strings.Split(output, "\n")
+	lines := stringslice.NonEmptyLines(output)
 	result := make(gitdomain.Commits, 0, len(lines))
 	for _, line := range lines {
-		if len(line) == 0 {
-			continue
-		}
 		sha, message, ok := strings.Cut(line, " ")
 		if !ok {
 			continue
@@ -415,8 +443,7 @@ func (self *Commands) CurrentBranchDuringRebase(querier subshelldomain.Querier)
 			continue
 		}
 		refName := strings.TrimSpace(string(content))
-		if strings.HasPrefix(refName, "refs/heads/") {
-			branchName := strings.TrimPrefix(refName, "refs/heads/")
+		if branchName, isBranchName := strings.CutPrefix(refName, "refs/heads/"); isBranchName {
 			return Some(gitdomain.NewLocalBranchName(branchName)), nil
 		}
 		// rebase head name is not a branch name
@@ -494,7 +521,7 @@ func (self *Commands) FileConflicts(querier subshelldomain.Querier) (FileConflic
 	return ParseLsFilesUnmergedOutput(output)
 }
 
-// provides the commit message of the first commit in the branch with the given name
+// FirstCommitMessageInBranch provides the commit message of the first commit in the branch with the given name.
 func (self *Commands) FirstCommitMessageInBranch(runner subshelldomain.Querier, branch, parent gitdomain.BranchName) (Option[gitdomain.CommitMessage], error) {
 	output, err := runner.QueryTrim("git", "log", fmt.Sprintf("%s..%s", parent, branch), "--format=%s", "--reverse")
 	if err != nil {
@@ -507,7 +534,7 @@ func (self *Commands) FirstCommitMessageInBranch(runner subshelldomain.Querier,
 	return Some(gitdomain.CommitMessage(lines[0])), nil
 }
 
-// provides the first branch in the given list of branch names that actually exists
+// FirstExistingBranch provides the first branch in the given list of branch names that actually exists.
 func (self *Commands) FirstExistingBranch(runner subshelldomain.Runner, branches ...gitdomain.LocalBranchName) Option[gitdomain.LocalBranchName] {
 	for _, branch := range branches {
 		if self.BranchExists(runner, branch) {
@@ -529,12 +556,14 @@ func (self *Commands) ForcePushBranchSafely(runner subshelldomain.Runner, pushHo
 }
 
 func (self *Commands) GitVersion(querier subshelldomain.Querier) (Version, error) {
-	versionRegexp := regexp.MustCompile(`git version (\d+).(\d+).(\w+)`)
 	output, err := querier.QueryTrim("git", "version")
 	if err != nil {
 		return EmptyVersion(), fmt.Errorf(messages.GitVersionProblem, err)
 	}
-	matches := versionRegexp.FindStringSubmatch(output)
+	gitVersionOnce.Do(func() {
+		gitVersionRegex = regexp.MustCompile(`git version (\d+).(\d+).(\w+)`)
+	})
+	matches := gitVersionRegex.FindStringSubmatch(output)
 	if matches == nil {
 		return EmptyVersion(), fmt.Errorf(messages.GitVersionUnexpectedOutput, output)
 	}
@@ -552,6 +581,11 @@ func (self *Commands) GitVersion(querier subshelldomain.Querier) (Version, error
 	}, nil
 }
 
+var (
+	gitVersionOnce  sync.Once
+	gitVersionRegex *regexp.Regexp
+)
+
 func (self *Commands) HasMergeInProgress(runner subshelldomain.Runner) bool {
 	err := runner.Run("git", "rev-parse", "--verify", "-q", "MERGE_HEAD")
 	return err == nil
@@ -576,7 +610,7 @@ func (self *Commands) MergeBranchNoEdit(runner subshelldomain.Runner, branch git
 	return runner.Run("git", "merge", "--no-edit", "--ff", branch.String())
 }
 
-// loads the information needed to determine which of the given file conflicts are phantom merge conflicts
+// MergeConflicts loads the information needed to determine which of the given file conflicts are phantom merge conflicts.
 func (self *Commands) MergeConflicts(querier subshelldomain.Querier, fileConflicts FileConflicts, parentLocation gitdomain.Location, rootBranch gitdomain.LocalBranchName) (MergeConflicts, error) {
 	result := make(MergeConflicts, len(fileConflicts))
 	for f, fileConflict := range fileConflicts {
@@ -695,7 +729,7 @@ func (self *Commands) Rebase(runner subshelldomain.Runner, target gitdomain.Bran
 	return runner.Run("git", "-c", "rebase.updateRefs=false", "rebase", target.String())
 }
 
-// Rebase initiates a Git rebase of the current branch onto the given branch.
+// RebaseOnto initiates a Git rebase of the current branch onto the given branch.
 func (self *Commands) RebaseOnto(runner subshelldomain.Runner, branchToRebaseOnto gitdomain.Location, commitsToRemove gitdomain.Location) error {
 	return runner.Run("git", "-c", "rebase.updateRefs=false", "rebase", "--onto", branchToRebaseOnto.String(), commitsToRemove.String())
 }
@@ -809,7 +843,7 @@ func (self *Commands) StageFiles(runner subshelldomain.Runner, names ...string)
 	return runner.Run("git", args...)
 }
 
-// determines the branch that is configured in Git as the default branch
+// StandardBranch determines the branch that is configured in Git as the default branch.
 func (self *Commands) StandardBranch(querier subshelldomain.Querier) Option[gitdomain.LocalBranchName] {
 	if defaultBranch, has := gitconfig.DefaultBranch(querier).Get(); has {
 		return Some(defaultBranch)
@@ -960,8 +994,7 @@ func makeBranchesSnapshotNewRepo(branch gitdomain.LocalBranchName) gitdomain.Bra
 		Active: Some(branch),
 		Branches: gitdomain.BranchInfos{
 			gitdomain.BranchInfo{
-				LocalName:  Some(branch),
-				LocalSHA:   None[gitdomain.SHA](),
+				Local:      Some(gitdomain.BranchData{Name: branch, SHA: "0000000"}), // brand-new repos witout any commits don't have a SHA
 				SyncStatus: gitdomain.SyncStatusLocalOnly,
 				RemoteName: None[gitdomain.RemoteBranchName](),
 				RemoteSHA:  None[gitdomain.SHA](),
