@@ -297,7 +297,7 @@ func TestBackendCommands(t *testing.T) {
 			local := testruntime.Clone(origin.TestRunner, t.TempDir())
 			asserts.NoError(local.Git.CreateAndCheckoutBranch(local.TestRunner, "branch"))
 			asserts.NoError(local.Git.CreateTrackingBranch(local.TestRunner, "branch", gitdomain.RemoteOrigin, false))
-			inSync := asserts.NoError1(local.Git.BranchInSyncWithTracking(local.TestRunner, "branch", gitdomain.RemoteOrigin))
+			inSync := asserts.NoError1(local.Git.BranchInSyncWithTracking(local.TestRunner, "branch", "origin/branch"))
 			must.True(t, inSync)
 		})
 		t.Run("branch has local commits", func(t *testing.T) {
@@ -312,7 +312,7 @@ func TestBackendCommands(t *testing.T) {
 				FileName:    "local_file",
 				Message:     "add local file",
 			})
-			inSync := asserts.NoError1(local.Git.BranchInSyncWithTracking(local.TestRunner, "branch", gitdomain.RemoteOrigin))
+			inSync := asserts.NoError1(local.Git.BranchInSyncWithTracking(local.TestRunner, "branch", "origin/branch"))
 			must.False(t, inSync)
 		})
 		t.Run("branch has remote commits", func(t *testing.T) {
@@ -328,7 +328,7 @@ func TestBackendCommands(t *testing.T) {
 				Message:     "add remote file",
 			})
 			local.Fetch()
-			inSync := asserts.NoError1(local.Git.BranchInSyncWithTracking(local.TestRunner, "branch", gitdomain.RemoteOrigin))
+			inSync := asserts.NoError1(local.Git.BranchInSyncWithTracking(local.TestRunner, "branch", "origin/branch"))
 			must.False(t, inSync)
 		})
 		t.Run("branch has different local and remote commits", func(t *testing.T) {
@@ -350,11 +350,63 @@ func TestBackendCommands(t *testing.T) {
 				Message:     "add remote file",
 			})
 			local.Fetch()
-			inSync := asserts.NoError1(local.Git.BranchInSyncWithTracking(local.TestRunner, "branch", gitdomain.RemoteOrigin))
+			inSync := asserts.NoError1(local.Git.BranchInSyncWithTracking(local.TestRunner, "branch", "origin/branch"))
 			must.False(t, inSync)
 		})
 	})
 
+	t.Run("BranchesAvailableInCurrentWorktree", func(t *testing.T) {
+		t.Parallel()
+		t.Run("includes branches not checked out anywhere", func(t *testing.T) {
+			t.Parallel()
+			runtime := testruntime.Create(t)
+			runtime.CreateBranch("branch1", initial.BranchName())
+			runtime.CreateBranch("branch2", initial.BranchName())
+			runtime.CheckoutBranch("branch1")
+			available := asserts.NoError1(runtime.Git.BranchesAvailableInCurrentWorktree(runtime))
+			must.SliceContainsAll(t, gitdomain.LocalBranchNames{
+				gitdomain.NewLocalBranchName("initial"),
+				gitdomain.NewLocalBranchName("branch1"),
+				gitdomain.NewLocalBranchName("branch2"),
+			}, available)
+		})
+
+		t.Run("excludes branch checked out in another worktree", func(t *testing.T) {
+			t.Parallel()
+			runtime := testruntime.Create(t)
+			runtime.CreateBranch("branch1", initial.BranchName())
+			runtime.CreateBranch("branch2", initial.BranchName())
+			worktreeDir := t.TempDir()
+			runtime.AddWorktree(worktreeDir, "branch1")
+			available := asserts.NoError1(runtime.Git.BranchesAvailableInCurrentWorktree(runtime))
+			must.SliceContainsAll(t, gitdomain.LocalBranchNames{
+				gitdomain.NewLocalBranchName("initial"),
+				gitdomain.NewLocalBranchName("branch2"),
+			}, available)
+		})
+
+		t.Run("excludes remote branches", func(t *testing.T) {
+			t.Parallel()
+			origin := testruntime.Create(t)
+			local := testruntime.Clone(origin.TestRunner, t.TempDir())
+			origin.CreateBranch("remote-branch", initial.BranchName())
+			local.Fetch()
+			available := asserts.NoError1(local.Git.BranchesAvailableInCurrentWorktree(local))
+			must.SliceContainsAll(t, gitdomain.LocalBranchNames{
+				gitdomain.NewLocalBranchName("initial"),
+			}, available)
+		})
+
+		t.Run("empty repository", func(t *testing.T) {
+			t.Parallel()
+			runtime := testruntime.Create(t)
+			available := asserts.NoError1(runtime.Git.BranchesAvailableInCurrentWorktree(runtime))
+			must.SliceContainsAll(t, gitdomain.LocalBranchNames{
+				gitdomain.NewLocalBranchName("initial"),
+			}, available)
+		})
+	})
+
 	t.Run("BranchesSnapshot", func(t *testing.T) {
 		t.Parallel()
 		t.Run("recognizes the active branch names", func(t *testing.T) {
@@ -428,8 +480,7 @@ func TestBackendCommands(t *testing.T) {
 					Active: Some(initial),
 					Branches: gitdomain.BranchInfos{
 						gitdomain.BranchInfo{
-							LocalName:  Some(initial),
-							LocalSHA:   Some(commits[0].SHA),
+							Local:      Some(gitdomain.BranchData{Name: initial, SHA: commits[0].SHA}),
 							SyncStatus: gitdomain.SyncStatusAhead,
 							RemoteName: Some(gitdomain.NewRemoteBranchName("origin/initial")),
 							RemoteSHA:  Some(commits[1].SHA),
@@ -462,8 +513,7 @@ func TestBackendCommands(t *testing.T) {
 					Active: Some(initial),
 					Branches: gitdomain.BranchInfos{
 						gitdomain.BranchInfo{
-							LocalName:  Some(initial),
-							LocalSHA:   Some(commits[1].SHA),
+							Local:      Some(gitdomain.BranchData{Name: initial, SHA: commits[1].SHA}),
 							SyncStatus: gitdomain.SyncStatusBehind,
 							RemoteName: Some(gitdomain.NewRemoteBranchName("origin/initial")),
 							RemoteSHA:  Some(commits[0].SHA),
@@ -503,8 +553,7 @@ func TestBackendCommands(t *testing.T) {
 					Active: Some(initial),
 					Branches: gitdomain.BranchInfos{
 						gitdomain.BranchInfo{
-							LocalName:  Some(initial),
-							LocalSHA:   Some(localCommits[0].SHA),
+							Local:      Some(gitdomain.BranchData{Name: initial, SHA: localCommits[0].SHA}),
 							SyncStatus: gitdomain.SyncStatusNotInSync,
 							RemoteName: Some(gitdomain.NewRemoteBranchName("origin/initial")),
 							RemoteSHA:  Some(originCommits[0].SHA),
@@ -530,8 +579,7 @@ func TestBackendCommands(t *testing.T) {
 					Active: Some(initial),
 					Branches: gitdomain.BranchInfos{
 						gitdomain.BranchInfo{
-							LocalName:  Some(initial),
-							LocalSHA:   Some(commits[0].SHA),
+							Local:      Some(gitdomain.BranchData{Name: initial, SHA: commits[0].SHA}),
 							SyncStatus: gitdomain.SyncStatusUpToDate,
 							RemoteName: Some(gitdomain.NewRemoteBranchName("origin/initial")),
 							RemoteSHA:  Some(commits[0].SHA),
@@ -560,15 +608,13 @@ func TestBackendCommands(t *testing.T) {
 					Active: Some(initial),
 					Branches: gitdomain.BranchInfos{
 						gitdomain.BranchInfo{
-							LocalName:  Some(initial),
-							LocalSHA:   Some(localCommits[0].SHA),
+							Local:      Some(gitdomain.BranchData{Name: initial, SHA: localCommits[0].SHA}),
 							SyncStatus: gitdomain.SyncStatusUpToDate,
 							RemoteName: Some(gitdomain.NewRemoteBranchName("origin/initial")),
 							RemoteSHA:  Some(localCommits[0].SHA),
 						},
 						gitdomain.BranchInfo{
-							LocalName:  None[gitdomain.LocalBranchName](),
-							LocalSHA:   None[gitdomain.SHA](),
+							Local:      None[gitdomain.BranchData](),
 							SyncStatus: gitdomain.SyncStatusRemoteOnly,
 							RemoteName: Some(gitdomain.NewRemoteBranchName("origin/branch")),
 							RemoteSHA:  Some(originBranchCommits[0].SHA),
@@ -596,15 +642,13 @@ func TestBackendCommands(t *testing.T) {
 					Active: Some[gitdomain.LocalBranchName]("branch"),
 					Branches: gitdomain.BranchInfos{
 						gitdomain.BranchInfo{
-							LocalName:  Some[gitdomain.LocalBranchName]("branch"),
-							LocalSHA:   Some(localBranchCommits[0].SHA),
+							Local:      Some(gitdomain.BranchData{Name: "branch", SHA: localBranchCommits[0].SHA}),
 							SyncStatus: gitdomain.SyncStatusLocalOnly,
 							RemoteName: None[gitdomain.RemoteBranchName](),
 							RemoteSHA:  None[gitdomain.SHA](),
 						},
 						gitdomain.BranchInfo{
-							LocalName:  Some(initial),
-							LocalSHA:   Some(initialCommits[0].SHA),
+							Local:      Some(gitdomain.BranchData{Name: initial, SHA: initialCommits[0].SHA}),
 							SyncStatus: gitdomain.SyncStatusUpToDate,
 							RemoteName: Some(gitdomain.NewRemoteBranchName("origin/initial")),
 							RemoteSHA:  Some(initialCommits[0].SHA),
@@ -637,15 +681,13 @@ func TestBackendCommands(t *testing.T) {
 					Active: Some[gitdomain.LocalBranchName]("branch"),
 					Branches: gitdomain.BranchInfos{
 						gitdomain.BranchInfo{
-							LocalName:  Some[gitdomain.LocalBranchName]("branch"),
-							LocalSHA:   Some(branchCommits[0].SHA),
+							Local:      Some(gitdomain.BranchData{Name: "branch", SHA: branchCommits[0].SHA}),
 							SyncStatus: gitdomain.SyncStatusDeletedAtRemote,
 							RemoteName: Some(gitdomain.NewRemoteBranchName("origin/branch")),
 							RemoteSHA:  None[gitdomain.SHA](),
 						},
 						gitdomain.BranchInfo{
-							LocalName:  Some(initial),
-							LocalSHA:   Some(initialCommits[1].SHA),
+							Local:      Some(gitdomain.BranchData{Name: initial, SHA: initialCommits[1].SHA}),
 							SyncStatus: gitdomain.SyncStatusUpToDate,
 							RemoteName: Some(gitdomain.NewRemoteBranchName("origin/initial")),
 							RemoteSHA:  Some(initialCommits[1].SHA),
@@ -661,21 +703,19 @@ func TestBackendCommands(t *testing.T) {
 				runtime := testruntime.Create(t)
 				runtime.CreateBranch("branch", initial.BranchName())
 				worktreeDir := t.TempDir()
-				runtime.CreateWorktree(worktreeDir, "branch")
+				runtime.AddWorktree(worktreeDir, "branch")
 				commits := asserts.NoError1(runtime.Git.CommitsInBranch(runtime, initial, None[gitdomain.LocalBranchName]()))
 				want := gitdomain.BranchesSnapshot{
 					Active: Some[gitdomain.LocalBranchName]("initial"),
 					Branches: gitdomain.BranchInfos{
 						gitdomain.BranchInfo{
-							LocalName:  gitdomain.NewLocalBranchNameOption("branch"),
-							LocalSHA:   Some(commits[0].SHA),
+							Local:      Some(gitdomain.BranchData{Name: "branch", SHA: commits[0].SHA}),
 							SyncStatus: gitdomain.SyncStatusOtherWorktree,
 							RemoteName: None[gitdomain.RemoteBranchName](),
 							RemoteSHA:  None[gitdomain.SHA](),
 						},
 						gitdomain.BranchInfo{
-							LocalName:  Some(initial),
-							LocalSHA:   Some(commits[0].SHA),
+							Local:      Some(gitdomain.BranchData{Name: initial, SHA: commits[0].SHA}),
 							SyncStatus: gitdomain.SyncStatusLocalOnly,
 							RemoteName: None[gitdomain.RemoteBranchName](),
 							RemoteSHA:  None[gitdomain.SHA](),
@@ -713,15 +753,13 @@ func TestBackendCommands(t *testing.T) {
 					Active: None[gitdomain.LocalBranchName](),
 					Branches: gitdomain.BranchInfos{
 						gitdomain.BranchInfo{
-							LocalName:  Some[gitdomain.LocalBranchName]("branch"),
-							LocalSHA:   Some(branchCommits[0].SHA),
+							Local:      Some(gitdomain.BranchData{Name: "branch", SHA: branchCommits[0].SHA}),
 							SyncStatus: gitdomain.SyncStatusLocalOnly,
 							RemoteName: None[gitdomain.RemoteBranchName](),
 							RemoteSHA:  None[gitdomain.SHA](),
 						},
 						gitdomain.BranchInfo{
-							LocalName:  Some(initial),
-							LocalSHA:   Some(initialCommits[0].SHA),
+							Local:      Some(gitdomain.BranchData{Name: initial, SHA: initialCommits[0].SHA}),
 							SyncStatus: gitdomain.SyncStatusLocalOnly,
 							RemoteName: None[gitdomain.RemoteBranchName](),
 							RemoteSHA:  None[gitdomain.SHA](),
@@ -768,29 +806,25 @@ func TestBackendCommands(t *testing.T) {
 				Active: gitdomain.NewLocalBranchNameOption("branch-2"),
 				Branches: gitdomain.BranchInfos{
 					gitdomain.BranchInfo{
-						LocalName:  gitdomain.NewLocalBranchNameOption("branch-1"),
-						LocalSHA:   Some(branch1Commits[0].SHA),
+						Local:      Some(gitdomain.BranchData{Name: "branch-1", SHA: branch1Commits[0].SHA}),
 						SyncStatus: gitdomain.SyncStatusLocalOnly,
 						RemoteName: None[gitdomain.RemoteBranchName](),
 						RemoteSHA:  None[gitdomain.SHA](),
 					},
 					gitdomain.BranchInfo{
-						LocalName:  gitdomain.NewLocalBranchNameOption("branch-2"),
-						LocalSHA:   Some(branch2Commits[0].SHA),
+						Local:      Some(gitdomain.BranchData{Name: "branch-2", SHA: branch2Commits[0].SHA}),
 						SyncStatus: gitdomain.SyncStatusUpToDate,
 						RemoteName: Some(gitdomain.NewRemoteBranchName("origin/branch-2")),
 						RemoteSHA:  Some(branch2Commits[0].SHA),
 					},
 					gitdomain.BranchInfo{
-						LocalName:  Some(initial),
-						LocalSHA:   Some(initialCommits[1].SHA),
+						Local:      Some(gitdomain.BranchData{Name: initial, SHA: initialCommits[1].SHA}),
 						SyncStatus: gitdomain.SyncStatusUpToDate,
 						RemoteName: Some(gitdomain.NewRemoteBranchName("origin/initial")),
 						RemoteSHA:  Some(initialCommits[1].SHA),
 					},
 					gitdomain.BranchInfo{
-						LocalName:  None[gitdomain.LocalBranchName](),
-						LocalSHA:   None[gitdomain.SHA](),
+						Local:      None[gitdomain.BranchData](),
 						SyncStatus: gitdomain.SyncStatusRemoteOnly,
 						RemoteName: Some(gitdomain.NewRemoteBranchName("origin/branch-3")),
 						RemoteSHA:  Some(branch3Commits[0].SHA),
@@ -811,8 +845,7 @@ func TestBackendCommands(t *testing.T) {
 				Active: Some(initial),
 				Branches: gitdomain.BranchInfos{
 					gitdomain.BranchInfo{
-						LocalName:  Some(initial),
-						LocalSHA:   Some(commits[0].SHA),
+						Local:      Some(gitdomain.BranchData{Name: initial, SHA: commits[0].SHA}),
 						SyncStatus: gitdomain.SyncStatusUpToDate,
 						RemoteName: Some(gitdomain.NewRemoteBranchName("origin/initial")),
 						RemoteSHA:  Some(commits[0].SHA),
@@ -1191,7 +1224,7 @@ func TestBackendCommands(t *testing.T) {
 			repo.PushBranchToRemote(branch, gitdomain.RemoteOrigin)
 			repo.CheckoutBranch(main.LocalBranchName())
 			asserts.NoError(repo.Git.DeleteLocalBranch(repo.TestRunner, branch))
-			have := asserts.NoError1(repo.Git.FirstCommitMessageInBranch(repo.TestRunner, branch.TrackingBranch(gitdomain.RemoteOrigin).BranchName(), main.BranchName()))
+			have := asserts.NoError1(repo.Git.FirstCommitMessageInBranch(repo.TestRunner, "origin/branch", main.BranchName()))
 			want := Some(gitdomain.CommitMessage("commit message 1"))
 			must.Eq(t, want, have)
 		})
