@@ -2,6 +2,7 @@ package gitdomain
 
 import (
 	"fmt"
+	"strings"
 
 	. "github.com/git-town/git-town/v22/pkg/prelude"
 )
@@ -19,10 +20,30 @@ func (self BranchInfos) BranchIsActiveInAnotherWorktree(branch LocalBranchName)
 	return branchInfo.SyncStatus == SyncStatusOtherWorktree
 }
 
+func (self BranchInfos) BranchesDeletedAtRemote() LocalBranchNames {
+	result := LocalBranchNames{}
+	for _, bi := range self {
+		if bi.SyncStatus == SyncStatusDeletedAtRemote {
+			result = append(result, bi.GetLocalOrRemoteNameAsLocalName())
+		}
+	}
+	return result
+}
+
+func (self BranchInfos) BranchesInOtherWorktrees() LocalBranchNames {
+	result := LocalBranchNames{}
+	for _, bi := range self {
+		if bi.SyncStatus == SyncStatusOtherWorktree {
+			result = append(result, bi.GetLocalOrRemoteNameAsLocalName())
+		}
+	}
+	return result
+}
+
 // FindByLocalName provides the branch with the given name if one exists.
 func (self BranchInfos) FindByLocalName(branchName LocalBranchName) OptionalMutable[BranchInfo] {
 	for bi, branch := range self {
-		if localName, hasLocalName := branch.LocalName.Get(); hasLocalName {
+		if localName, hasLocalName := branch.LocalName().Get(); hasLocalName {
 			if localName == branchName {
 				return MutableSome(&self[bi])
 			}
@@ -44,23 +65,20 @@ func (self BranchInfos) FindByRemoteName(remoteBranch RemoteBranchName) Optional
 	return MutableNone[BranchInfo]()
 }
 
-func (self BranchInfos) FindLocalOrRemote(branchName LocalBranchName, remote Remote) OptionalMutable[BranchInfo] {
-	branchInfoOpt := self.FindByLocalName(branchName)
-	if branchInfoOpt.IsSome() {
-		return branchInfoOpt
+func (self BranchInfos) FindLocalOrRemote(branchName LocalBranchName) OptionalMutable[BranchInfo] {
+	if localInfo := self.FindByLocalName(branchName); localInfo.IsSome() {
+		return localInfo
 	}
-	remoteName := branchName.AtRemote(remote)
-	branchInfoOpt = self.FindByRemoteName(remoteName)
-	if branchInfoOpt.IsSome() {
-		return branchInfoOpt
+	if remoteInfo := self.FindRemoteNameMatchingLocal(branchName); remoteInfo.IsSome() {
+		return remoteInfo
 	}
 	return MutableNone[BranchInfo]()
 }
 
 func (self BranchInfos) FindMatchingRecord(other BranchInfo) OptionalMutable[BranchInfo] {
 	for b, bi := range self {
-		biLocalName, hasBiLocalName := bi.LocalName.Get()
-		otherLocalName, hasOtherLocalName := other.LocalName.Get()
+		biLocalName, hasBiLocalName := bi.LocalName().Get()
+		otherLocalName, hasOtherLocalName := other.LocalName().Get()
 		if hasBiLocalName && hasOtherLocalName && biLocalName == otherLocalName {
 			return MutableSome(&self[b])
 		}
@@ -73,9 +91,21 @@ func (self BranchInfos) FindMatchingRecord(other BranchInfo) OptionalMutable[Bra
 	return MutableNone[BranchInfo]()
 }
 
+// FindRemoteNameMatchingLocal finds the BranchInfo with a remote name that matches the given local branch name.
+func (self BranchInfos) FindRemoteNameMatchingLocal(localBranch LocalBranchName) OptionalMutable[BranchInfo] {
+	for b, bi := range self {
+		if remoteName, hasRemoteName := bi.RemoteName.Get(); hasRemoteName {
+			if remoteName.LocalBranchName() == localBranch {
+				return MutableSome(&self[b])
+			}
+		}
+	}
+	return MutableNone[BranchInfo]()
+}
+
 func (self BranchInfos) HasBranch(branch LocalBranchName) bool {
 	for _, branchInfo := range self {
-		if localName, hasLocalName := branchInfo.LocalName.Get(); hasLocalName {
+		if localName, hasLocalName := branchInfo.LocalName().Get(); hasLocalName {
 			if localName == branch {
 				return true
 			}
@@ -92,7 +122,7 @@ func (self BranchInfos) HasBranch(branch LocalBranchName) bool {
 // HasLocalBranch indicates whether the given local branch is already known to this BranchInfos instance.
 func (self BranchInfos) HasLocalBranch(branch LocalBranchName) bool {
 	for _, bi := range self {
-		if biLocalName, hasBiLocalName := bi.LocalName.Get(); hasBiLocalName {
+		if biLocalName, hasBiLocalName := bi.LocalName().Get(); hasBiLocalName {
 			if biLocalName == branch {
 				return true
 			}
@@ -111,16 +141,16 @@ func (self BranchInfos) HasLocalBranches(branches LocalBranchNames) bool {
 	return true
 }
 
-// HasMatchingRemoteBranchFor indicates whether there is already a remote branch matching the given local branch.
-func (self BranchInfos) HasMatchingTrackingBranchFor(localBranch LocalBranchName, devRemote Remote) bool {
-	return self.FindByRemoteName(localBranch.TrackingBranch(devRemote)).IsSome()
+// HasMatchingTrackingBranchFor indicates whether there is already a remote branch matching the given local branch.
+func (self BranchInfos) HasMatchingTrackingBranchFor(localBranch LocalBranchName) bool {
+	return self.FindRemoteNameMatchingLocal(localBranch).IsSome()
 }
 
 // LocalBranches provides only the branches that exist on the local machine.
 func (self BranchInfos) LocalBranches() BranchInfos {
 	result := BranchInfos{}
 	for _, bi := range self {
-		if bi.LocalName.IsSome() {
+		if bi.LocalName().IsSome() {
 			result = append(result, bi)
 		}
 	}
@@ -151,7 +181,7 @@ func (self BranchInfos) NamesAllBranches() LocalBranchNames {
 func (self BranchInfos) NamesLocalBranches() LocalBranchNames {
 	result := make(LocalBranchNames, 0, len(self))
 	for _, bi := range self {
-		if localName, hasLocalName := bi.LocalName.Get(); hasLocalName {
+		if localName, hasLocalName := bi.LocalName().Get(); hasLocalName {
 			result = append(result, localName)
 		}
 	}
@@ -161,7 +191,7 @@ func (self BranchInfos) NamesLocalBranches() LocalBranchNames {
 func (self BranchInfos) Remove(branchName LocalBranchName) BranchInfos {
 	result := BranchInfos{}
 	for _, bi := range self {
-		localName, hasLocalName := bi.LocalName.Get()
+		localName, hasLocalName := bi.LocalName().Get()
 		if !hasLocalName || localName != branchName {
 			result = append(result, bi)
 		}
@@ -170,15 +200,14 @@ func (self BranchInfos) Remove(branchName LocalBranchName) BranchInfos {
 }
 
 // Select provides the BranchInfos with the given names.
-func (self BranchInfos) Select(remote Remote, names ...LocalBranchName) (result BranchInfos, nonExisting LocalBranchNames) {
+func (self BranchInfos) Select(names ...LocalBranchName) (result BranchInfos, nonExisting LocalBranchNames) { //nolint:nonamedreturns
 	result = make(BranchInfos, 0, len(names))
 	for _, name := range names {
 		if branchInfo, has := self.FindByLocalName(name).Get(); has {
 			result = append(result, *branchInfo)
 			continue
 		}
-		remoteName := name.AtRemote(remote)
-		if branchInfo, has := self.FindByRemoteName(remoteName).Get(); has {
+		if branchInfo, has := self.FindRemoteNameMatchingLocal(name).Get(); has {
 			result = append(result, *branchInfo)
 			continue
 		}
@@ -188,18 +217,21 @@ func (self BranchInfos) Select(remote Remote, names ...LocalBranchName) (result
 }
 
 func (self BranchInfos) String() string {
-	result := "BranchInfos:\n"
+	result := strings.Builder{}
+	result.WriteString("BranchInfos:\n")
 	for _, bi := range self {
-		result += bi.String() + "\n"
+		result.WriteString(bi.String())
+		result.WriteRune('\n')
 	}
-	return result
+	return result.String()
 }
 
 func (self BranchInfos) UpdateLocalSHA(branch LocalBranchName, sha SHA) error {
 	for b := range self {
-		if localName, hasLocalName := self[b].LocalName.Get(); hasLocalName {
-			if localName == branch {
-				self[b].LocalSHA = Some(sha)
+		if local, hasLocal := self[b].Local.Get(); hasLocal {
+			if local.Name == branch {
+				local.SHA = sha
+				self[b].Local = Some(local)
 				return nil
 			}
 		}
