@@ -25,11 +25,6 @@ func isValidLocalBranchName(value string) bool {
 	return len(value) > 0
 }
 
-// AtRemote provides the RemoteBranchName of this branch at the given remote.
-func (self LocalBranchName) AtRemote(remote Remote) RemoteBranchName {
-	return NewRemoteBranchName(remote.String() + "/" + (string(self)))
-}
-
 // BranchName widens the type of this LocalBranchName to a more generic BranchName.
 func (self LocalBranchName) BranchName() BranchName {
 	return BranchName(string(self))
@@ -45,10 +40,5 @@ func (self LocalBranchName) RefName() string {
 	return "refs/heads/" + self.String()
 }
 
-// Implementation of the fmt.Stringer interface.
+// String implements the fmt.Stringer interface.
 func (self LocalBranchName) String() string { return string(self) }
-
-// TrackingBranch provides the name of the tracking branch for this local branch.
-func (self LocalBranchName) TrackingBranch(devRemote Remote) RemoteBranchName {
-	return self.AtRemote(devRemote)
-}
