@@ -28,14 +28,6 @@ func TestLocalBranchNames(t *testing.T) {
 		})
 	})
 
-	t.Run("AtRemote", func(t *testing.T) {
-		t.Parallel()
-		branch := gitdomain.NewLocalBranchName("branch")
-		have := branch.AtRemote(gitdomain.RemoteOrigin)
-		want := gitdomain.NewRemoteBranchName("origin/branch")
-		must.EqOp(t, want, have)
-	})
-
 	t.Run("Contains", func(t *testing.T) {
 		t.Parallel()
 		branches := gitdomain.NewLocalBranchNames("one", "two")
@@ -46,14 +38,14 @@ func TestLocalBranchNames(t *testing.T) {
 
 	t.Run("Hoist", func(t *testing.T) {
 		t.Parallel()
-		t.Run("haystack contains needle", func(t *testing.T) {
+		t.Run("haystack contains needles", func(t *testing.T) {
 			t.Parallel()
-			branches := gitdomain.NewLocalBranchNames("one", "two", "three")
-			have := branches.Hoist("two")
-			want := gitdomain.NewLocalBranchNames("two", "one", "three")
+			branches := gitdomain.NewLocalBranchNames("one", "two", "three", "four")
+			have := branches.Hoist("four", "two")
+			want := gitdomain.NewLocalBranchNames("four", "two", "one", "three")
 			must.Eq(t, want, have)
 		})
-		t.Run("haystack does not contain needle", func(t *testing.T) {
+		t.Run("haystack does not contain needles", func(t *testing.T) {
 			t.Parallel()
 			branches := gitdomain.NewLocalBranchNames("one", "two", "three")
 			have := branches.Hoist("zonk")
@@ -136,12 +128,4 @@ func TestLocalBranchNames(t *testing.T) {
 			must.Eq(t, want, have)
 		})
 	})
-
-	t.Run("TrackingBranch", func(t *testing.T) {
-		t.Parallel()
-		branch := gitdomain.NewLocalBranchName("branch")
-		have := branch.TrackingBranch(gitdomain.RemoteOrigin)
-		want := gitdomain.NewRemoteBranchName("origin/branch")
-		must.EqOp(t, want, have)
-	})
 }
