@@ -3,7 +3,7 @@ package slice_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v18/internal/gohacks/slice"
+	"github.com/git-town/git-town/v22/internal/gohacks/slice"
 	"github.com/shoenig/test/must"
 )
 
@@ -16,8 +16,8 @@ func TestNaturalSort(t *testing.T) {
 		{"a10b10", "a10b2"}:      {"a10b2", "a10b10"},      // multiple parts of numbers and characters
 	}
 	for give, want := range tests {
-		have := slice.NaturalSort(*give)
-		must.Eq(t, want, &have)
+		slice.NaturalSort(*give)
+		must.Eq(t, want, give)
 	}
 }
 
