@@ -28,7 +28,7 @@ func TestIndent(t *testing.T) {
 	t.Run("empty", func(t *testing.T) {
 		t.Parallel()
 		have := gohacks.IndentLines("", 2)
-		must.EqOp(t, "  ", have)
+		must.EqOp(t, "", have)
 	})
 
 	t.Run("indent by 2 spaces", func(t *testing.T) {
@@ -47,3 +47,19 @@ func TestIndent(t *testing.T) {
 		must.EqOp(t, want, have)
 	})
 }
+
+func TestLeadingWhitespace(t *testing.T) {
+	t.Parallel()
+	tests := map[string]string{
+		"    text":   "    ",   // spaces
+		"\t\ttext":   "\t\t",   // tabs
+		"  \t  text": "  \t  ", // mixed spaces and tabs
+		"text":       "",       // no indentation
+		"":           "",       // empty string
+		"    ":       "    ",   // only whitespace
+	}
+	for give, want := range tests {
+		have := gohacks.LeadingWhitespace(give)
+		must.EqOp(t, want, have)
+	}
+}
