@@ -15,14 +15,14 @@ import (
 	. "github.com/git-town/git-town/v22/pkg/prelude"
 )
 
-func Save(userInput UserInput, unvalidatedConfig config.UnvalidatedConfig, data Data, frontend subshelldomain.Runner) error {
+func Save(userInput UserInput, unvalidatedConfig config.UnvalidatedConfig, data Data, enterAll bool, frontend subshelldomain.Runner) error {
 	fc := gohacks.ErrorCollector{}
 	fc.Check(
 		saveAliases(userInput.Data.Aliases, unvalidatedConfig.GitGlobal.Aliases, frontend),
 	)
 	if forgeType, hasForgeType := userInput.DeterminedForgeType.Get(); hasForgeType {
 		switch forgeType {
-		case forgedomain.ForgeTypeAzureDevOps:
+		case forgedomain.ForgeTypeAzuredevops:
 			// no API token for now
 		case forgedomain.ForgeTypeBitbucket, forgedomain.ForgeTypeBitbucketDatacenter:
 			fc.Check(
@@ -35,13 +35,13 @@ func Save(userInput UserInput, unvalidatedConfig config.UnvalidatedConfig, data
 			fc.Check(
 				saveForgejoToken(userInput.Data.ForgejoToken, unvalidatedConfig.GitLocal.ForgejoToken, userInput.Scope, frontend),
 			)
-		case forgedomain.ForgeTypeGitHub:
+		case forgedomain.ForgeTypeGithub:
 			fc.Check(
-				saveGitHubToken(userInput.Data.GitHubToken, unvalidatedConfig.GitLocal.GitHubToken, userInput.Scope, userInput.Data.GitHubConnectorType, frontend),
+				saveGithubToken(userInput.Data.GithubToken, unvalidatedConfig.GitLocal.GithubToken, userInput.Scope, userInput.Data.GithubConnectorType, frontend),
 			)
-		case forgedomain.ForgeTypeGitLab:
+		case forgedomain.ForgeTypeGitlab:
 			fc.Check(
-				saveGitLabToken(userInput.Data.GitLabToken, unvalidatedConfig.GitLocal.GitLabToken, userInput.Scope, userInput.Data.GitLabConnectorType, frontend),
+				saveGitlabToken(userInput.Data.GitlabToken, unvalidatedConfig.GitLocal.GitlabToken, userInput.Scope, userInput.Data.GitlabConnectorType, frontend),
 			)
 		case forgedomain.ForgeTypeGitea:
 			fc.Check(
@@ -54,17 +54,18 @@ func Save(userInput UserInput, unvalidatedConfig config.UnvalidatedConfig, data
 	}
 	switch userInput.StorageLocation {
 	case dialog.ConfigStorageOptionFile:
-		return saveAllToFile(userInput, unvalidatedConfig.GitLocal, frontend)
+		return saveAllToFile(userInput, unvalidatedConfig.File, unvalidatedConfig.GitLocal, frontend)
 	case dialog.ConfigStorageOptionGit:
-		return saveAllToGit(userInput, unvalidatedConfig.GitLocal, unvalidatedConfig.File, data, frontend)
+		return saveAllToGit(userInput, unvalidatedConfig.GitLocal, unvalidatedConfig.File, data, enterAll, frontend)
 	}
 	return nil
 }
 
-func saveAliases(valuesToWriteToGit configdomain.Aliases, valuesAlreadyInGit configdomain.Aliases, frontend subshelldomain.Runner) (err error) {
+func saveAliases(valuesToWriteToGit configdomain.Aliases, valuesAlreadyInGit configdomain.Aliases, frontend subshelldomain.Runner) error {
 	for _, aliasableCommand := range configdomain.AllAliasableCommands() {
 		oldAlias, hasOld := valuesAlreadyInGit[aliasableCommand]
 		newAlias, hasNew := valuesToWriteToGit[aliasableCommand]
+		var err error
 		switch {
 		case hasOld && !hasNew:
 			err = gitconfig.RemoveAlias(frontend, aliasableCommand)
@@ -78,14 +79,19 @@ func saveAliases(valuesToWriteToGit configdomain.Aliases, valuesAlreadyInGit con
 	return nil
 }
 
-func saveAllToFile(userInput UserInput, gitConfig configdomain.PartialConfig, runner subshelldomain.Runner) error {
+func saveAllToFile(userInput UserInput, existingConfigFile configdomain.PartialConfig, gitConfig configdomain.PartialConfig, runner subshelldomain.Runner) error {
 	userInput.Data.MainBranch = Some(userInput.ValidatedConfig.MainBranch)
-	if err := configfile.Save(userInput.Data); err != nil {
+	configData := existingConfigFile.Merge(userInput.Data)
+	if err := configfile.Save(configData); err != nil {
 		return err
 	}
+	// keep-sorted start block=yes
 	if gitConfig.AutoSync.IsSome() {
 		_ = gitconfig.RemoveAutoSync(runner)
 	}
+	if gitConfig.BranchPrefix.IsSome() {
+		_ = gitconfig.RemoveBranchPrefix(runner)
+	}
 	if gitConfig.ContributionRegex.IsSome() {
 		_ = gitconfig.RemoveContributionRegex(runner)
 	}
@@ -98,6 +104,21 @@ func saveAllToFile(userInput UserInput, gitConfig configdomain.PartialConfig, ru
 	if gitConfig.FeatureRegex.IsSome() {
 		_ = gitconfig.RemoveFeatureRegex(runner)
 	}
+	if gitConfig.ForgeType.IsSome() {
+		_ = gitconfig.RemoveForgeType(runner)
+	}
+	if gitConfig.GithubConnectorType.IsSome() {
+		_ = gitconfig.RemoveGithubConnectorType(runner)
+	}
+	if gitConfig.GitlabConnectorType.IsSome() {
+		_ = gitconfig.RemoveGitlabConnectorType(runner)
+	}
+	if gitConfig.HostingOriginHostname.IsSome() {
+		_ = gitconfig.RemoveOriginHostname(runner)
+	}
+	if gitConfig.IgnoreUncommitted.IsSome() {
+		_ = gitconfig.RemoveIgnoreUncommitted(runner)
+	}
 	if gitConfig.MainBranch.IsSome() {
 		_ = gitconfig.RemoveMainBranch(runner)
 	}
@@ -110,14 +131,11 @@ func saveAllToFile(userInput UserInput, gitConfig configdomain.PartialConfig, ru
 	if gitConfig.Order.IsSome() {
 		_ = gitconfig.RemoveOrder(runner)
 	}
-	if len(gitConfig.PerennialBranches) > 0 {
-		_ = gitconfig.RemovePerennialBranches(runner)
-	}
 	if gitConfig.PerennialRegex.IsSome() {
 		_ = gitconfig.RemovePerennialRegex(runner)
 	}
-	if gitConfig.ShareNewBranches.IsSome() {
-		_ = gitconfig.RemoveShareNewBranches(runner)
+	if gitConfig.ProposalBreadcrumb.IsSome() {
+		_ = gitconfig.RemoveProposalBreadcrumb(runner)
 	}
 	if gitConfig.PushBranches.IsSome() {
 		_ = gitconfig.RemovePushBranches(runner)
@@ -125,12 +143,15 @@ func saveAllToFile(userInput UserInput, gitConfig configdomain.PartialConfig, ru
 	if gitConfig.PushHook.IsSome() {
 		_ = gitconfig.RemovePushHook(runner)
 	}
-	if gitConfig.ShipStrategy.IsSome() {
-		_ = gitconfig.RemoveShipStrategy(runner)
+	if gitConfig.ShareNewBranches.IsSome() {
+		_ = gitconfig.RemoveShareNewBranches(runner)
 	}
 	if gitConfig.ShipDeleteTrackingBranch.IsSome() {
 		_ = gitconfig.RemoveShipDeleteTrackingBranch(runner)
 	}
+	if gitConfig.ShipStrategy.IsSome() {
+		_ = gitconfig.RemoveShipStrategy(runner)
+	}
 	if gitConfig.Stash.IsSome() {
 		_ = gitconfig.RemoveStash(runner)
 	}
@@ -143,59 +164,29 @@ func saveAllToFile(userInput UserInput, gitConfig configdomain.PartialConfig, ru
 	if gitConfig.SyncPrototypeStrategy.IsSome() {
 		_ = gitconfig.RemoveSyncPrototypeStrategy(runner)
 	}
-	if gitConfig.SyncUpstream.IsSome() {
-		_ = gitconfig.RemoveSyncUpstream(runner)
-	}
 	if gitConfig.SyncTags.IsSome() {
 		_ = gitconfig.RemoveSyncTags(runner)
 	}
+	if gitConfig.SyncUpstream.IsSome() {
+		_ = gitconfig.RemoveSyncUpstream(runner)
+	}
 	if gitConfig.UnknownBranchType.IsSome() {
 		_ = gitconfig.RemoveUnknownBranchType(runner)
 	}
+	if len(gitConfig.PerennialBranches) > 0 {
+		_ = gitconfig.RemovePerennialBranches(runner)
+	}
+	// keep-sorted end
 	if err := saveUnknownBranchType(userInput.Data.UnknownBranchType, gitConfig.UnknownBranchType, runner); err != nil {
 		return err
 	}
 	return saveFeatureRegex(userInput.Data.FeatureRegex, gitConfig.FeatureRegex, runner)
 }
 
-func saveAllToGit(userInput UserInput, existingGitConfig configdomain.PartialConfig, configFile configdomain.PartialConfig, data Data, frontend subshelldomain.Runner) error {
+func saveAllToGit(userInput UserInput, existingGitConfig configdomain.PartialConfig, configFile configdomain.PartialConfig, data Data, enterAll bool, frontend subshelldomain.Runner) error {
 	fc := gohacks.ErrorCollector{}
-	// TODO: sort this alphabetically
-	if configFile.AutoSync.IsNone() {
-		fc.Check(
-			saveAutoSync(userInput.Data.AutoSync, existingGitConfig.AutoSync, frontend),
-		)
-	}
-	if configFile.Detached.IsNone() {
-		fc.Check(
-			saveDetached(userInput.Data.Detached, existingGitConfig.Detached, frontend),
-		)
-	}
-	if configFile.NewBranchType.IsNone() {
-		fc.Check(
-			saveNewBranchType(userInput.Data.NewBranchType, existingGitConfig.NewBranchType, frontend),
-		)
-	}
-	if configFile.ForgeType.IsNone() {
-		fc.Check(
-			saveForgeType(userInput.Data.ForgeType, existingGitConfig.ForgeType, frontend),
-		)
-	}
-	if configFile.GitHubConnectorType.IsNone() {
-		fc.Check(
-			saveGitHubConnectorType(userInput.Data.GitHubConnectorType, existingGitConfig.GitHubConnectorType, frontend),
-		)
-	}
-	if configFile.GitLabConnectorType.IsNone() {
-		fc.Check(
-			saveGitLabConnectorType(userInput.Data.GitLabConnectorType, existingGitConfig.GitLabConnectorType, frontend),
-		)
-	}
-	if configFile.HostingOriginHostname.IsNone() {
-		fc.Check(
-			saveOriginHostname(userInput.Data.HostingOriginHostname, existingGitConfig.HostingOriginHostname, frontend),
-		)
-	}
+
+	// BASIC CONFIGURATION
 	if configFile.MainBranch.IsNone() {
 		fc.Check(
 			saveMainBranch(userInput.Data.MainBranch, existingGitConfig.MainBranch, frontend),
@@ -204,29 +195,71 @@ func saveAllToGit(userInput UserInput, existingGitConfig configdomain.PartialCon
 	fc.Check(
 		savePerennialBranches(userInput.Data.PerennialBranches, existingGitConfig.PerennialBranches, frontend),
 	)
-	if configFile.PerennialRegex.IsNone() {
-		fc.Check(
-			savePerennialRegex(userInput.Data.PerennialRegex, existingGitConfig.PerennialRegex, frontend),
-		)
-	}
-	if configFile.UnknownBranchType.IsNone() {
-		fc.Check(
-			saveUnknownBranchType(userInput.Data.UnknownBranchType, existingGitConfig.UnknownBranchType, frontend),
-		)
-	}
 	if len(data.Remotes) > 1 && configFile.DevRemote.IsNone() {
 		fc.Check(
 			saveDevRemote(userInput.Data.DevRemote, existingGitConfig.DevRemote, frontend),
 		)
 	}
+	if configFile.HostingOriginHostname.IsNone() {
+		fc.Check(
+			saveOriginHostname(userInput.Data.HostingOriginHostname, existingGitConfig.HostingOriginHostname, frontend),
+		)
+	}
+	if configFile.ForgeType.IsNone() {
+		fc.Check(
+			saveForgeType(userInput.Data.ForgeType, existingGitConfig.ForgeType, frontend),
+		)
+	}
+	if configFile.GithubConnectorType.IsNone() {
+		fc.Check(
+			saveGithubConnectorType(userInput.Data.GithubConnectorType, existingGitConfig.GithubConnectorType, frontend),
+		)
+	}
+	if configFile.GitlabConnectorType.IsNone() {
+		fc.Check(
+			saveGitlabConnectorType(userInput.Data.GitlabConnectorType, existingGitConfig.GitlabConnectorType, frontend),
+		)
+	}
+
+	if !enterAll {
+		return fc.Err
+	}
+
+	// EXTENDED CONFIGURATION
+	// keep-sorted start block=yes
+	if configFile.AutoSync.IsNone() {
+		fc.Check(
+			saveAutoSync(userInput.Data.AutoSync, existingGitConfig.AutoSync, frontend),
+		)
+	}
+	if configFile.BranchPrefix.IsNone() {
+		fc.Check(
+			saveBranchPrefix(userInput.Data.BranchPrefix, existingGitConfig.BranchPrefix, frontend),
+		)
+	}
+	if configFile.ContributionRegex.IsNone() {
+		fc.Check(
+			saveContributionRegex(userInput.Data.ContributionRegex, existingGitConfig.ContributionRegex, frontend),
+		)
+	}
+	if configFile.Detached.IsNone() {
+		fc.Check(
+			saveDetached(userInput.Data.Detached, existingGitConfig.Detached, frontend),
+		)
+	}
 	if configFile.FeatureRegex.IsNone() {
 		fc.Check(
 			saveFeatureRegex(userInput.Data.FeatureRegex, existingGitConfig.FeatureRegex, frontend),
 		)
 	}
-	if configFile.ContributionRegex.IsNone() {
+	if configFile.IgnoreUncommitted.IsNone() {
 		fc.Check(
-			saveContributionRegex(userInput.Data.ContributionRegex, existingGitConfig.ContributionRegex, frontend),
+			saveIgnoreUncommitted(userInput.Data.IgnoreUncommitted, existingGitConfig.IgnoreUncommitted, frontend),
+		)
+	}
+	if configFile.NewBranchType.IsNone() {
+		fc.Check(
+			saveNewBranchType(userInput.Data.NewBranchType, existingGitConfig.NewBranchType, frontend),
 		)
 	}
 	if configFile.ObservedRegex.IsNone() {
@@ -239,6 +272,16 @@ func saveAllToGit(userInput UserInput, existingGitConfig configdomain.PartialCon
 			saveOrder(userInput.Data.Order, existingGitConfig.Order, frontend),
 		)
 	}
+	if configFile.PerennialRegex.IsNone() {
+		fc.Check(
+			savePerennialRegex(userInput.Data.PerennialRegex, existingGitConfig.PerennialRegex, frontend),
+		)
+	}
+	if configFile.ProposalBreadcrumb.IsNone() {
+		fc.Check(
+			saveProposalBreadcrumb(userInput.Data.ProposalBreadcrumb, existingGitConfig.ProposalBreadcrumb, frontend),
+		)
+	}
 	if configFile.PushBranches.IsNone() {
 		fc.Check(
 			savePushBranches(userInput.Data.PushBranches, existingGitConfig.PushBranches, frontend),
@@ -254,16 +297,16 @@ func saveAllToGit(userInput UserInput, existingGitConfig configdomain.PartialCon
 			saveShareNewBranches(userInput.Data.ShareNewBranches, existingGitConfig.ShareNewBranches, frontend),
 		)
 	}
-	if configFile.ShipStrategy.IsNone() {
-		fc.Check(
-			saveShipStrategy(userInput.Data.ShipStrategy, existingGitConfig.ShipStrategy, frontend),
-		)
-	}
 	if configFile.ShipDeleteTrackingBranch.IsNone() {
 		fc.Check(
 			saveShipDeleteTrackingBranch(userInput.Data.ShipDeleteTrackingBranch, existingGitConfig.ShipDeleteTrackingBranch, frontend),
 		)
 	}
+	if configFile.ShipStrategy.IsNone() {
+		fc.Check(
+			saveShipStrategy(userInput.Data.ShipStrategy, existingGitConfig.ShipStrategy, frontend),
+		)
+	}
 	if configFile.Stash.IsNone() {
 		fc.Check(
 			saveStash(userInput.Data.Stash, existingGitConfig.Stash, frontend),
@@ -284,16 +327,22 @@ func saveAllToGit(userInput UserInput, existingGitConfig configdomain.PartialCon
 			saveSyncPrototypeStrategy(userInput.Data.SyncPrototypeStrategy, existingGitConfig.SyncPrototypeStrategy, frontend),
 		)
 	}
-	if configFile.SyncUpstream.IsNone() {
-		fc.Check(
-			saveSyncUpstream(userInput.Data.SyncUpstream, existingGitConfig.SyncUpstream, frontend),
-		)
-	}
 	if configFile.SyncTags.IsNone() {
 		fc.Check(
 			saveSyncTags(userInput.Data.SyncTags, existingGitConfig.SyncTags, frontend),
 		)
 	}
+	if configFile.SyncUpstream.IsNone() {
+		fc.Check(
+			saveSyncUpstream(userInput.Data.SyncUpstream, existingGitConfig.SyncUpstream, frontend),
+		)
+	}
+	if configFile.UnknownBranchType.IsNone() {
+		fc.Check(
+			saveUnknownBranchType(userInput.Data.UnknownBranchType, existingGitConfig.UnknownBranchType, frontend),
+		)
+	}
+	// keep-sorted end
 	return fc.Err
 }
 
@@ -329,6 +378,17 @@ func saveBitbucketUsername(valueToWriteToGit Option[forgedomain.BitbucketUsernam
 	return gitconfig.RemoveBitbucketUsername(frontend)
 }
 
+func saveBranchPrefix(valueToWriteToGit Option[configdomain.BranchPrefix], valueAlreadyInGit Option[configdomain.BranchPrefix], runner subshelldomain.Runner) error {
+	if valueToWriteToGit.Equal(valueAlreadyInGit) {
+		return nil
+	}
+	if value, has := valueToWriteToGit.Get(); has {
+		return gitconfig.SetBranchPrefix(runner, value, configdomain.ConfigScopeLocal)
+	}
+	_ = gitconfig.RemoveBranchPrefix(runner)
+	return nil
+}
+
 func saveContributionRegex(valueToWriteToGit Option[configdomain.ContributionRegex], valueAlreadyInGit Option[configdomain.ContributionRegex], runner subshelldomain.Runner) error {
 	if valueToWriteToGit.Equal(valueAlreadyInGit) {
 		return nil
@@ -372,7 +432,7 @@ func saveFeatureRegex(valueToWriteToGit Option[configdomain.FeatureRegex], value
 	return nil
 }
 
-func saveForgeType(valueToWriteToGit Option[forgedomain.ForgeType], valueAlreadyInGit Option[forgedomain.ForgeType], frontend subshelldomain.Runner) (err error) {
+func saveForgeType(valueToWriteToGit Option[forgedomain.ForgeType], valueAlreadyInGit Option[forgedomain.ForgeType], frontend subshelldomain.Runner) error {
 	oldValue, oldHas := valueAlreadyInGit.Get()
 	newValue, newHas := valueToWriteToGit.Get()
 	if !oldHas && !newHas {
@@ -397,56 +457,6 @@ func saveForgejoToken(valueToWriteToGit Option[forgedomain.ForgejoToken], valueA
 	return gitconfig.RemoveForgejoToken(frontend)
 }
 
-func saveGitHubConnectorType(valueToWriteToGit Option[forgedomain.GitHubConnectorType], valueAlreadyInGit Option[forgedomain.GitHubConnectorType], frontend subshelldomain.Runner) error {
-	if valueToWriteToGit.Equal(valueAlreadyInGit) {
-		return nil
-	}
-	if value, has := valueToWriteToGit.Get(); has {
-		return gitconfig.SetGitHubConnectorType(frontend, value, configdomain.ConfigScopeLocal)
-	}
-	return gitconfig.RemoveGitHubConnectorType(frontend)
-}
-
-func saveGitHubToken(valueToWriteToGit Option[forgedomain.GitHubToken], valueAlreadyInGit Option[forgedomain.GitHubToken], scope configdomain.ConfigScope, githubConnectorType Option[forgedomain.GitHubConnectorType], frontend subshelldomain.Runner) error {
-	if connectorType, has := githubConnectorType.Get(); has {
-		if connectorType == forgedomain.GitHubConnectorTypeGh {
-			return nil
-		}
-	}
-	if valueToWriteToGit.Equal(valueAlreadyInGit) {
-		return nil
-	}
-	if value, has := valueToWriteToGit.Get(); has {
-		return gitconfig.SetGitHubToken(frontend, value, scope)
-	}
-	return gitconfig.RemoveGitHubToken(frontend)
-}
-
-func saveGitLabConnectorType(valueToWriteToGit Option[forgedomain.GitLabConnectorType], valueAlreadyInGit Option[forgedomain.GitLabConnectorType], frontend subshelldomain.Runner) error {
-	if valueToWriteToGit.Equal(valueAlreadyInGit) {
-		return nil
-	}
-	if value, has := valueToWriteToGit.Get(); has {
-		return gitconfig.SetGitLabConnectorType(frontend, value, configdomain.ConfigScopeLocal)
-	}
-	return gitconfig.RemoveGitLabConnectorType(frontend)
-}
-
-func saveGitLabToken(valueToWriteToGit Option[forgedomain.GitLabToken], valueAlreadyInGit Option[forgedomain.GitLabToken], scope configdomain.ConfigScope, gitlabConnectorType Option[forgedomain.GitLabConnectorType], frontend subshelldomain.Runner) error {
-	if connectorType, has := gitlabConnectorType.Get(); has {
-		if connectorType == forgedomain.GitLabConnectorTypeGlab {
-			return nil
-		}
-	}
-	if valueToWriteToGit.Equal(valueAlreadyInGit) {
-		return nil
-	}
-	if value, has := valueToWriteToGit.Get(); has {
-		return gitconfig.SetGitLabToken(frontend, value, scope)
-	}
-	return gitconfig.RemoveGitLabToken(frontend)
-}
-
 func saveGiteaToken(valueToWriteToGit Option[forgedomain.GiteaToken], valueAlreadyInGit Option[forgedomain.GiteaToken], scope configdomain.ConfigScope, frontend subshelldomain.Runner) error {
 	if valueToWriteToGit.Equal(valueAlreadyInGit) {
 		return nil
@@ -457,6 +467,66 @@ func saveGiteaToken(valueToWriteToGit Option[forgedomain.GiteaToken], valueAlrea
 	return gitconfig.RemoveGiteaToken(frontend)
 }
 
+func saveGithubConnectorType(valueToWriteToGit Option[forgedomain.GithubConnectorType], valueAlreadyInGit Option[forgedomain.GithubConnectorType], frontend subshelldomain.Runner) error {
+	if valueToWriteToGit.Equal(valueAlreadyInGit) {
+		return nil
+	}
+	if value, has := valueToWriteToGit.Get(); has {
+		return gitconfig.SetGithubConnectorType(frontend, value, configdomain.ConfigScopeLocal)
+	}
+	return gitconfig.RemoveGithubConnectorType(frontend)
+}
+
+func saveGithubToken(valueToWriteToGit Option[forgedomain.GithubToken], valueAlreadyInGit Option[forgedomain.GithubToken], scope configdomain.ConfigScope, githubConnectorType Option[forgedomain.GithubConnectorType], frontend subshelldomain.Runner) error {
+	if connectorType, has := githubConnectorType.Get(); has {
+		if connectorType == forgedomain.GithubConnectorTypeGh {
+			return nil
+		}
+	}
+	if valueToWriteToGit.Equal(valueAlreadyInGit) {
+		return nil
+	}
+	if value, has := valueToWriteToGit.Get(); has {
+		return gitconfig.SetGithubToken(frontend, value, scope)
+	}
+	return gitconfig.RemoveGithubToken(frontend)
+}
+
+func saveGitlabConnectorType(valueToWriteToGit Option[forgedomain.GitlabConnectorType], valueAlreadyInGit Option[forgedomain.GitlabConnectorType], frontend subshelldomain.Runner) error {
+	if valueToWriteToGit.Equal(valueAlreadyInGit) {
+		return nil
+	}
+	if value, has := valueToWriteToGit.Get(); has {
+		return gitconfig.SetGitlabConnectorType(frontend, value, configdomain.ConfigScopeLocal)
+	}
+	return gitconfig.RemoveGitlabConnectorType(frontend)
+}
+
+func saveGitlabToken(valueToWriteToGit Option[forgedomain.GitlabToken], valueAlreadyInGit Option[forgedomain.GitlabToken], scope configdomain.ConfigScope, gitlabConnectorType Option[forgedomain.GitlabConnectorType], frontend subshelldomain.Runner) error {
+	if connectorType, has := gitlabConnectorType.Get(); has {
+		if connectorType == forgedomain.GitlabConnectorTypeGlab {
+			return nil
+		}
+	}
+	if valueToWriteToGit.Equal(valueAlreadyInGit) {
+		return nil
+	}
+	if value, has := valueToWriteToGit.Get(); has {
+		return gitconfig.SetGitlabToken(frontend, value, scope)
+	}
+	return gitconfig.RemoveGitlabToken(frontend)
+}
+
+func saveIgnoreUncommitted(valueToWriteToGit Option[configdomain.IgnoreUncommitted], valueAlreadyInGit Option[configdomain.IgnoreUncommitted], runner subshelldomain.Runner) error {
+	if valueAlreadyInGit.Equal(valueToWriteToGit) {
+		return nil
+	}
+	if value, has := valueToWriteToGit.Get(); has {
+		return gitconfig.SetIgnoreUncommitted(runner, value, configdomain.ConfigScopeLocal)
+	}
+	return gitconfig.RemoveIgnoreUncommitted(runner)
+}
+
 func saveMainBranch(valueToWriteToGit Option[gitdomain.LocalBranchName], valueAlreadyInGit Option[gitdomain.LocalBranchName], runner subshelldomain.Runner) error {
 	if valueToWriteToGit.Equal(valueAlreadyInGit) {
 		return nil
@@ -527,6 +597,16 @@ func savePerennialRegex(valueToWriteToGit Option[configdomain.PerennialRegex], v
 	return nil
 }
 
+func saveProposalBreadcrumb(valueToWriteToGit Option[forgedomain.ProposalBreadcrumb], valueAlreadyInGit Option[forgedomain.ProposalBreadcrumb], runner subshelldomain.Runner) error {
+	if valueAlreadyInGit.Equal(valueToWriteToGit) {
+		return nil
+	}
+	if value, has := valueToWriteToGit.Get(); has {
+		return gitconfig.SetProposalBreadcrumb(runner, value, configdomain.ConfigScopeLocal)
+	}
+	return gitconfig.RemoveProposalBreadcrumb(runner)
+}
+
 func savePushBranches(valueToWriteToGit Option[configdomain.PushBranches], valueAlreadyInGit Option[configdomain.PushBranches], runner subshelldomain.Runner) error {
 	if valueAlreadyInGit.Equal(valueToWriteToGit) {
 		return nil
