@@ -3,13 +3,13 @@ package runstate_test
 import (
 	"encoding/json"
 	"os"
+	"path/filepath"
 	"testing"
 	"time"
 
 	"github.com/git-town/git-town/v22/internal/config/configdomain"
 	"github.com/git-town/git-town/v22/internal/forge/forgedomain"
 	"github.com/git-town/git-town/v22/internal/git/gitdomain"
-	"github.com/git-town/git-town/v22/internal/state"
 	"github.com/git-town/git-town/v22/internal/state/runstate"
 	"github.com/git-town/git-town/v22/internal/vm/opcodes"
 	"github.com/git-town/git-town/v22/internal/vm/program"
@@ -20,19 +20,6 @@ import (
 func TestLoadSave(t *testing.T) {
 	t.Parallel()
 
-	t.Run("SanitizePath", func(t *testing.T) {
-		t.Parallel()
-		tests := map[string]string{
-			"/home/user/development/git-town":        "home-user-development-git-town",
-			"c:\\Users\\user\\development\\git-town": "c-users-user-development-git-town",
-		}
-		for give, want := range tests {
-			rootDir := gitdomain.NewRepoRootDir(give)
-			have := state.SanitizePath(rootDir)
-			must.EqOp(t, want, have)
-		}
-	})
-
 	t.Run("Save and Load", func(t *testing.T) {
 		t.Parallel()
 		runState := runstate.RunState{
@@ -55,7 +42,7 @@ func TestLoadSave(t *testing.T) {
 				&opcodes.BranchCreateAndCheckoutExistingParent{Ancestors: gitdomain.NewLocalBranchNames("one", "two", "three"), Branch: "branch"},
 				&opcodes.BranchCurrentReset{Base: "branch"},
 				&opcodes.BranchCurrentResetToParent{CurrentBranch: "branch"},
-				&opcodes.BranchCurrentResetToSHA{SetToSHA: "111111"},
+				&opcodes.BranchCurrentResetToSHA{SHA: "111111"},
 				&opcodes.BranchCurrentResetToSHAIfNeeded{MustHaveSHA: "222222", SetToSHA: "111111"},
 				&opcodes.BranchEnsureShippableChanges{Branch: "branch", Parent: "parent"},
 				&opcodes.BranchLocalDelete{Branch: "branch"},
@@ -67,6 +54,7 @@ func TestLoadSave(t *testing.T) {
 				&opcodes.BranchReset{Target: "branch"},
 				&opcodes.BranchTrackingCreate{Branch: "branch"},
 				&opcodes.BranchTrackingCreateIfLocalExists{Branch: "branch"},
+				&opcodes.BranchTrackingCreateIfNeeded{CurrentBranch: "branch"},
 				&opcodes.BranchTrackingDelete{Branch: "origin/branch"},
 				&opcodes.BranchTypeOverrideSet{Branch: "branch", BranchType: configdomain.BranchTypeFeatureBranch},
 				&opcodes.BranchTypeOverrideRemove{Branch: "branch"},
@@ -92,7 +80,7 @@ func TestLoadSave(t *testing.T) {
 				&opcodes.ConflictMergePhantomFinalize{},
 				&opcodes.ConflictMergePhantomResolveAll{CurrentBranch: "current", ParentBranch: gitdomain.NewLocalBranchNameOption("parent"), ParentSHA: Some(gitdomain.NewSHA("123456"))},
 				&opcodes.ConflictResolve{FilePath: "file", Resolution: gitdomain.ConflictResolutionOurs},
-				&opcodes.ConnectorProposalMerge{Branch: "branch", CommitMessage: Some(gitdomain.CommitMessage("commit message")), Proposal: forgedomain.Proposal{Data: forgedomain.BitbucketCloudProposalData{ProposalData: forgedomain.ProposalData{Body: Some("body"), MergeWithAPI: true, Number: 123, Source: "source", Target: "target", Title: "title", URL: "url"}}, ForgeType: forgedomain.ForgeTypeBitbucket}},
+				&opcodes.ConnectorProposalMerge{Branch: "branch", CommitMessage: Some(gitdomain.CommitMessage("commit message")), Proposal: forgedomain.Proposal{Data: forgedomain.BitbucketCloudProposalData{ProposalData: forgedomain.ProposalData{Active: true, Body: gitdomain.NewProposalBodyOpt("body"), MergeWithAPI: true, Number: 123, Source: "source", Target: "target", Title: "title", URL: "url"}}, ForgeType: forgedomain.ForgeTypeBitbucket}},
 				&opcodes.ExecuteShellCommand{Args: []string{"arg1", "arg2"}, Executable: "executable"},
 				&opcodes.ExitToShell{},
 				&opcodes.FetchUpstream{Branch: "branch"},
@@ -113,16 +101,15 @@ func TestLoadSave(t *testing.T) {
 				&opcodes.MessageQueue{Message: "message"},
 				&opcodes.ProgramEndOfBranch{},
 				&opcodes.ProposalCreate{Branch: "branch", MainBranch: "main"},
-				&opcodes.ProposalUpdateTarget{Proposal: forgedomain.Proposal{Data: forgedomain.ProposalData{Body: Some("body"), MergeWithAPI: true, Number: 123, Source: "source", Target: "target", Title: "title", URL: "url"}, ForgeType: forgedomain.ForgeTypeGitLab}, NewBranch: "new-target", OldBranch: "old-target"},
-				&opcodes.ProposalUpdateTargetToGrandParent{Branch: "branch", Proposal: forgedomain.Proposal{Data: forgedomain.ProposalData{Body: Some("body"), MergeWithAPI: true, Number: 123, Source: "source", Target: "target", Title: "title", URL: "url"}, ForgeType: forgedomain.ForgeTypeGitea}, OldTarget: "old-target"},
-				&opcodes.ProposalUpdateSource{Proposal: forgedomain.Proposal{Data: forgedomain.ProposalData{Body: None[string](), MergeWithAPI: false, Number: 123, Source: "source", Target: "target", Title: "title", URL: "url"}, ForgeType: forgedomain.ForgeTypeForgejo}, NewBranch: "new-target", OldBranch: "old-target"},
+				&opcodes.ProposalUpdateTarget{Proposal: forgedomain.Proposal{Data: forgedomain.ProposalData{Active: true, Body: gitdomain.NewProposalBodyOpt("body"), MergeWithAPI: true, Number: 123, Source: "source", Target: "target", Title: "title", URL: "url"}, ForgeType: forgedomain.ForgeTypeGitlab}, NewBranch: "new-target", OldBranch: "old-target"},
+				&opcodes.ProposalUpdateTargetToGrandParent{Branch: "branch", Proposal: forgedomain.Proposal{Data: forgedomain.ProposalData{Active: true, Body: gitdomain.NewProposalBodyOpt("body"), MergeWithAPI: true, Number: 123, Source: "source", Target: "target", Title: "title", URL: "url"}, ForgeType: forgedomain.ForgeTypeGitea}, OldTarget: "old-target"},
+				&opcodes.ProposalUpdateSource{Proposal: forgedomain.Proposal{Data: forgedomain.ProposalData{Active: true, Body: None[gitdomain.ProposalBody](), MergeWithAPI: false, Number: 123, Source: "source", Target: "target", Title: "title", URL: "url"}, ForgeType: forgedomain.ForgeTypeForgejo}, NewBranch: "new-target", OldBranch: "old-target"},
 				&opcodes.PullCurrentBranch{},
 				&opcodes.PushCurrentBranch{},
 				&opcodes.PushCurrentBranchForce{ForceIfIncludes: true},
-				&opcodes.PushCurrentBranchForceIfNeeded{CurrentBranch: "branch", ForceIfIncludes: true},
+				&opcodes.PushCurrentBranchForceIfNeeded{CurrentBranch: "branch", ForceIfIncludes: true, TrackingBranch: "origin/branch"},
 				&opcodes.PushCurrentBranchForceIgnoreError{},
-				&opcodes.PushCurrentBranchIfLocal{CurrentBranch: "branch"},
-				&opcodes.PushCurrentBranchIfNeeded{CurrentBranch: "branch"},
+				&opcodes.PushCurrentBranchIfNeeded{CurrentBranch: "branch", TrackingBranch: "origin/branch"},
 				&opcodes.PushTags{},
 				&opcodes.RebaseAbort{},
 				&opcodes.RebaseBranch{Branch: "branch"},
@@ -208,7 +195,7 @@ func TestLoadSave(t *testing.T) {
     },
     {
       "data": {
-        "SetToSHA": "111111"
+        "SHA": "111111"
       },
       "type": "BranchCurrentResetToSHA"
     },
@@ -286,6 +273,12 @@ func TestLoadSave(t *testing.T) {
       },
       "type": "BranchTrackingCreateIfLocalExists"
     },
+    {
+      "data": {
+        "CurrentBranch": "branch"
+      },
+      "type": "BranchTrackingCreateIfNeeded"
+    },
     {
       "data": {
         "Branch": "origin/branch"
@@ -445,6 +438,7 @@ func TestLoadSave(t *testing.T) {
         "CommitMessage": "commit message",
         "Proposal": {
           "data": {
+            "Active": true,
             "Body": "body",
             "MergeWithAPI": true,
             "Number": 123,
@@ -601,6 +595,7 @@ func TestLoadSave(t *testing.T) {
         "OldBranch": "old-target",
         "Proposal": {
           "data": {
+            "Active": true,
             "Body": "body",
             "MergeWithAPI": true,
             "Number": 123,
@@ -620,6 +615,7 @@ func TestLoadSave(t *testing.T) {
         "OldTarget": "old-target",
         "Proposal": {
           "data": {
+            "Active": true,
             "Body": "body",
             "MergeWithAPI": true,
             "Number": 123,
@@ -639,6 +635,7 @@ func TestLoadSave(t *testing.T) {
         "OldBranch": "old-target",
         "Proposal": {
           "data": {
+            "Active": true,
             "Body": null,
             "MergeWithAPI": false,
             "Number": 123,
@@ -669,7 +666,8 @@ func TestLoadSave(t *testing.T) {
     {
       "data": {
         "CurrentBranch": "branch",
-        "ForceIfIncludes": true
+        "ForceIfIncludes": true,
+        "TrackingBranch": "origin/branch"
       },
       "type": "PushCurrentBranchForceIfNeeded"
     },
@@ -679,13 +677,8 @@ func TestLoadSave(t *testing.T) {
     },
     {
       "data": {
-        "CurrentBranch": "branch"
-      },
-      "type": "PushCurrentBranchIfLocal"
-    },
-    {
-      "data": {
-        "CurrentBranch": "branch"
+        "CurrentBranch": "branch",
+        "TrackingBranch": "origin/branch"
       },
       "type": "PushCurrentBranchIfNeeded"
     },
@@ -817,12 +810,11 @@ func TestLoadSave(t *testing.T) {
   }
 }`[1:]
 
-		repoRoot := gitdomain.NewRepoRootDir("/path/to/git-town-unit-tests")
-		err := runstate.Save(runState, repoRoot)
+		tempDir := t.TempDir()
+		runstatePath := runstate.FilePath(filepath.Join(tempDir, "runstate.json"))
+		err := runstate.Save(runState, runstatePath)
 		must.NoError(t, err)
-		filepath, err := state.FilePath(repoRoot, state.FileTypeRunstate)
-		must.NoError(t, err)
-		content, err := os.ReadFile(filepath)
+		content, err := os.ReadFile(runstatePath.String())
 		must.NoError(t, err)
 		must.EqOp(t, wantJSON, string(content))
 		var newState runstate.RunState
