@@ -2,6 +2,7 @@ package subshell
 
 import (
 	"bytes"
+	"context"
 	"fmt"
 	"io"
 	"os"
@@ -67,7 +68,7 @@ func (self *FrontendRunner) RunWithEnv(env []string, cmd string, args ...string)
 }
 
 // runs the given command in this ShellRunner's directory.
-func (self *FrontendRunner) execute(env []string, cmd string, args ...string) (err error) {
+func (self *FrontendRunner) execute(env []string, cmd string, args ...string) error {
 	self.CommandsCounter.Value.Increment()
 	var location gitdomain.Location
 	if self.PrintBranchNames {
@@ -93,8 +94,9 @@ func (self *FrontendRunner) execute(env []string, cmd string, args ...string) (e
 		cmd = "cmd"
 	}
 	concurrentGitRetriesLeft := concurrentGitRetries
+	var err error
 	for {
-		subProcess := exec.Command(cmd, args...)
+		subProcess := exec.CommandContext(context.Background(), cmd, args...)
 		subProcess.Env = append(subProcess.Environ(), env...)
 		var stderrBuffer bytes.Buffer // we only need to look at STDERR since that's where Git will print error messages
 		subProcess.Stderr = io.MultiWriter(os.Stderr, &stderrBuffer)
