@@ -15,12 +15,12 @@ import (
 	"github.com/acarl005/stripansi"
 	"github.com/cucumber/godog"
 	messages "github.com/cucumber/messages/go/v21"
-	"github.com/git-town/git-town/v22/internal/browser"
 	"github.com/git-town/git-town/v22/internal/cli/dialog/dialogcomponents"
 	"github.com/git-town/git-town/v22/internal/cli/format"
 	"github.com/git-town/git-town/v22/internal/cli/print"
 	"github.com/git-town/git-town/v22/internal/config/configdomain"
 	"github.com/git-town/git-town/v22/internal/config/configfile"
+	"github.com/git-town/git-town/v22/internal/config/envconfig"
 	"github.com/git-town/git-town/v22/internal/config/gitconfig"
 	"github.com/git-town/git-town/v22/internal/forge/forgedomain"
 	"github.com/git-town/git-town/v22/internal/git/gitdomain"
@@ -31,6 +31,7 @@ import (
 	"github.com/git-town/git-town/v22/internal/test/fixture"
 	"github.com/git-town/git-town/v22/internal/test/handlebars"
 	"github.com/git-town/git-town/v22/internal/test/helpers"
+	"github.com/git-town/git-town/v22/internal/test/mockproposals"
 	"github.com/git-town/git-town/v22/internal/test/output"
 	"github.com/git-town/git-town/v22/internal/test/subshell"
 	"github.com/git-town/git-town/v22/internal/test/testgit"
@@ -38,11 +39,15 @@ import (
 	. "github.com/git-town/git-town/v22/pkg/prelude"
 	"github.com/google/go-cmp/cmp"
 	"github.com/kballard/go-shellquote"
+	"github.com/sergi/go-diff/diffmatchpatch"
 )
 
 // the global FixtureFactory instance.
 var fixtureFactory *fixture.Factory
 
+// CukeUpdate indicates whether to update .feature files with actual command output when tests fail
+var CukeUpdate bool
+
 // dedicated type for storing data in context.Context
 type key int
 
@@ -51,12 +56,14 @@ const (
 	keyScenarioState key = iota
 	keyScenarioName
 	keyScenarioTags
+	keyScenarioURI
 )
 
 func InitializeScenario(scenarioContext *godog.ScenarioContext) {
 	scenarioContext.Before(func(ctx context.Context, scenario *godog.Scenario) (context.Context, error) {
 		ctx = context.WithValue(ctx, keyScenarioName, scenario.Name)
 		ctx = context.WithValue(ctx, keyScenarioTags, scenario.Tags)
+		ctx = context.WithValue(ctx, keyScenarioURI, scenario.Uri)
 		return ctx, nil
 	})
 
@@ -70,11 +77,15 @@ func InitializeScenario(scenarioContext *godog.ScenarioContext) {
 			fmt.Printf("failed scenario %q in %s - investigate state in %s\n", scenario.Name, scenario.Uri, state.fixture.Dir)
 			return ctx, nil //nolint:nilerr
 		}
-		exitCode := state.runExitCode.GetOrPanic()
+		exitCode := state.runResult.GetOrPanic().ExitCode
 		if exitCode != 0 && !state.runExitCodeChecked {
 			print.Error(fmt.Errorf("%s - scenario %q doesn't document exit code %d", scenario.Uri, scenario.Name, exitCode))
 			os.Exit(1)
 		}
+		if state.initialProposals.IsSome() && !state.proposalsChecked {
+			print.Error(fmt.Errorf("%s - scenario %q doesn't verify proposals", scenario.Uri, scenario.Name))
+			os.Exit(1)
+		}
 		if state != nil {
 			state.fixture.Delete()
 		}
@@ -124,12 +135,13 @@ func defineSteps(sc *godog.ScenarioContext) {
 			initialDevSHAs:       None[gitdomain.Commits](),
 			initialLineage:       None[string](),
 			initialOriginSHAs:    None[gitdomain.Commits](),
+			initialProposals:     None[string](),
 			initialTags:          None[datatable.DataTable](),
 			initialWorktreeSHAs:  None[gitdomain.Commits](),
 			insideGitRepo:        true,
-			runExitCode:          None[int](),
+			proposalsChecked:     false,
 			runExitCodeChecked:   false,
-			runOutput:            None[string](),
+			runResult:            None[subshell.RunResult](),
 			uncommittedContent:   None[string](),
 			uncommittedFileName:  None[string](),
 		}
@@ -167,12 +179,13 @@ func defineSteps(sc *godog.ScenarioContext) {
 			initialDevSHAs:       None[gitdomain.Commits](),
 			initialLineage:       None[string](),
 			initialOriginSHAs:    None[gitdomain.Commits](),
+			initialProposals:     None[string](),
 			initialTags:          None[datatable.DataTable](),
 			initialWorktreeSHAs:  None[gitdomain.Commits](),
 			insideGitRepo:        true,
-			runExitCode:          None[int](),
+			proposalsChecked:     false,
 			runExitCodeChecked:   false,
-			runOutput:            None[string](),
+			runResult:            None[subshell.RunResult](),
 			uncommittedContent:   None[string](),
 			uncommittedFileName:  None[string](),
 		}
@@ -239,18 +252,6 @@ func defineSteps(sc *godog.ScenarioContext) {
 		state.fixture.AddUpstream()
 	})
 
-	sc.Step(`^a proposal for this branch does not exist`, func(ctx context.Context) {
-		state := ctx.Value(keyScenarioState).(*ScenarioState)
-		devRepo := state.fixture.DevRepo.GetOrPanic()
-		devRepo.TestRunner.ProposalOverride = Some(forgedomain.OverrideNoProposal)
-	})
-
-	sc.Step(`^a proposal for this branch exists at "([^"]+)"`, func(ctx context.Context, url string) {
-		state := ctx.Value(keyScenarioState).(*ScenarioState)
-		devRepo := state.fixture.DevRepo.GetOrPanic()
-		devRepo.TestRunner.ProposalOverride = Some(url)
-	})
-
 	sc.Step(`^a rebase is (?:now|still) in progress$`, func(ctx context.Context) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		devRepo := state.fixture.DevRepo.GetOrPanic()
@@ -261,7 +262,7 @@ func defineSteps(sc *godog.ScenarioContext) {
 		return nil
 	})
 
-	sc.Step(`^a remote "([^"]+)" pointing to "([^"]+)"`, func(ctx context.Context, name, url string) {
+	sc.Step(`^a remote "([^"]+)" pointing to "([^"]+)"$`, func(ctx context.Context, name, url string) {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		devRepo := state.fixture.DevRepo.GetOrPanic()
 		devRepo.AddRemote(gitdomain.Remote(name), url)
@@ -272,7 +273,7 @@ func defineSteps(sc *godog.ScenarioContext) {
 		state.fixture.OriginRepo.GetOrPanic().CreateStandaloneTag(name)
 	})
 
-	sc.Step(`^branch "([^"]+)" is active in another worktree`, func(ctx context.Context, branch string) {
+	sc.Step(`^branch "([^"]+)" is active in another worktree$`, func(ctx context.Context, branch string) {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		state.fixture.AddSecondWorktree(gitdomain.NewLocalBranchName(branch))
 	})
@@ -290,12 +291,12 @@ func defineSteps(sc *godog.ScenarioContext) {
 		return nil
 	})
 
-	sc.Step(`^commit "([^"]+)" on branch "([^"]+)" now has this full commit message`, func(ctx context.Context, title, branchText string, expected *godog.DocString) error {
+	sc.Step(`^commit "([^"]+)" on branch "([^"]+)" now has this full commit message$`, func(ctx context.Context, title, branchText string, expected *godog.DocString) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		devRepo := state.fixture.DevRepo.GetOrPanic()
 		branch := gitdomain.NewLocalBranchName(branchText)
 		parent := devRepo.Config.NormalConfig.Lineage.Parent(branch).GetOrPanic()
-		sha := devRepo.CommitSHA(devRepo, title, branch, parent.BranchName())
+		sha := devRepo.CommitSHA(devRepo, gitdomain.CommitTitle(title), branch, parent.BranchName())
 		have := asserts.NoError1(devRepo.Git.CommitMessage(devRepo, sha)).String()
 		want := expected.Content
 		if have != want {
@@ -353,7 +354,7 @@ func defineSteps(sc *godog.ScenarioContext) {
 
 	sc.Step(`^Git Town does not print "([^"]+)"$`, func(ctx context.Context, text string) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
-		if strings.Contains(stripansi.Strip(state.runOutput.GetOrPanic()), text) {
+		if strings.Contains(stripansi.Strip(state.runResult.GetOrPanic().Output), text) {
 			return fmt.Errorf("text found: %q", text)
 		}
 		return nil
@@ -382,10 +383,11 @@ func defineSteps(sc *godog.ScenarioContext) {
 
 	sc.Step(`^Git Town prints:$`, func(ctx context.Context, expected *godog.DocString) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
-		if exitCode := state.runExitCode.GetOrPanic(); exitCode != 0 {
-			return fmt.Errorf("unexpected exit code %d", exitCode)
+		runResult := state.runResult.GetOrPanic()
+		if runResult.ExitCode != 0 {
+			return fmt.Errorf("unexpected exit code %d", runResult.ExitCode)
 		}
-		output := stripansi.Strip(state.runOutput.GetOrPanic())
+		output := stripansi.Strip(runResult.Output)
 		if !strings.Contains(output, strings.TrimRight(expected.Content, "\n")) {
 			fmt.Println("ERROR: text not found:")
 			fmt.Println("==================================================================")
@@ -415,7 +417,7 @@ func defineSteps(sc *godog.ScenarioContext) {
 
 	sc.Step(`^Git Town prints no output$`, func(ctx context.Context) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
-		output := state.runOutput.GetOrPanic()
+		output := state.runResult.GetOrPanic().Output
 		if len(output) > 0 {
 			return fmt.Errorf("expected no output but found %q", output)
 		}
@@ -425,7 +427,7 @@ func defineSteps(sc *godog.ScenarioContext) {
 	sc.Step(`^Git Town prints something like:$`, func(ctx context.Context, expected *godog.DocString) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		regex := regexp.MustCompile(expected.Content)
-		have := stripansi.Strip(state.runOutput.GetOrPanic())
+		have := stripansi.Strip(state.runResult.GetOrPanic().Output)
 		if !regex.MatchString(have) {
 			return fmt.Errorf("EXPECTED: content matching %q\nGOT: %q", expected.Content, have)
 		}
@@ -435,10 +437,11 @@ func defineSteps(sc *godog.ScenarioContext) {
 	sc.Step(`^Git Town prints the error:$`, func(ctx context.Context, expected *godog.DocString) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		state.runExitCodeChecked = true
-		if !strings.Contains(stripansi.Strip(state.runOutput.GetOrPanic()), expected.Content) {
-			return fmt.Errorf("text not found:\n%s\n\nactual text:\n%s", expected.Content, state.runOutput.GetOrZero())
+		runResult := state.runResult.GetOrPanic()
+		if !strings.Contains(stripansi.Strip(runResult.Output), expected.Content) {
+			return fmt.Errorf("text not found:\n%s\n\nactual text:\n%s", expected.Content, runResult.Output)
 		}
-		if exitCode := state.runExitCode.GetOrPanic(); exitCode == 0 {
+		if exitCode := runResult.ExitCode; exitCode == 0 {
 			return fmt.Errorf("unexpected exit code %d", exitCode)
 		}
 		return nil
@@ -446,7 +449,7 @@ func defineSteps(sc *godog.ScenarioContext) {
 
 	sc.Step(`^Git Town runs no commands$`, func(ctx context.Context) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
-		commands := output.GitCommandsInGitTownOutput(state.runOutput.GetOrPanic())
+		commands := output.GitCommandsInGitTownOutput(state.runResult.GetOrPanic().Output)
 		if len(commands) > 0 {
 			fmt.Println("\n\nERROR: Unexpected commands run!")
 			for _, command := range commands {
@@ -462,7 +465,7 @@ func defineSteps(sc *godog.ScenarioContext) {
 	sc.Step(`^Git Town runs the commands$`, func(ctx context.Context, input *godog.Table) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		devRepo := state.fixture.DevRepo.GetOrPanic()
-		commands := output.GitCommandsInGitTownOutput(state.runOutput.GetOrPanic())
+		commands := output.GitCommandsInGitTownOutput(state.runResult.GetOrPanic().Output)
 		table := output.RenderExecutedGitCommands(commands, input)
 		dataTable := datatable.FromGherkin(input)
 		expanded := dataTable.Expand(handlebars.ExpandArgs{
@@ -477,6 +480,10 @@ func defineSteps(sc *godog.ScenarioContext) {
 		})
 		diff, errorCount := table.EqualDataTable(expanded)
 		if errorCount != 0 {
+			if CukeUpdate {
+				scenarioURI := ctx.Value(keyScenarioURI).(string)
+				return ChangeFeatureFile(scenarioURI, expanded.String(), table.String())
+			}
 			fmt.Printf("\nERROR! Found %d differences in the commands run\n\n", errorCount)
 			fmt.Println(diff)
 			return errors.New("mismatching commands run, see diff above")
@@ -484,9 +491,9 @@ func defineSteps(sc *godog.ScenarioContext) {
 		return nil
 	})
 
-	sc.Step(`^Git Town runs without errors`, func(ctx context.Context) error {
+	sc.Step(`^Git Town runs without errors$`, func(ctx context.Context) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
-		exitCode := state.runExitCode.GetOrPanic()
+		exitCode := state.runResult.GetOrPanic().ExitCode
 		if exitCode != 0 {
 			return errors.New("unexpected failure of scenario")
 		}
@@ -575,8 +582,9 @@ func defineSteps(sc *godog.ScenarioContext) {
 	sc.Step(`^I am not prompted for any parent branches$`, func(ctx context.Context) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		notExpected := "Please specify the parent branch of"
-		if strings.Contains(state.runOutput.GetOrPanic(), notExpected) {
-			return fmt.Errorf("text found:\n\nDID NOT EXPECT: %q\n\nACTUAL\n\n%q\n----------------------------", notExpected, state.runOutput)
+		runResult := state.runResult.GetOrPanic()
+		if strings.Contains(runResult.Output, notExpected) {
+			return fmt.Errorf("text found:\n\nDID NOT EXPECT: %q\n\nACTUAL\n\n%q\n----------------------------", notExpected, runResult.Output)
 		}
 		return nil
 	})
@@ -607,12 +615,13 @@ func defineSteps(sc *godog.ScenarioContext) {
 			initialDevSHAs:       None[gitdomain.Commits](),
 			initialLineage:       None[string](),
 			initialOriginSHAs:    None[gitdomain.Commits](),
+			initialProposals:     None[string](),
 			initialTags:          None[datatable.DataTable](),
 			initialWorktreeSHAs:  None[gitdomain.Commits](),
 			insideGitRepo:        true,
-			runExitCode:          None[int](),
+			proposalsChecked:     false,
 			runExitCodeChecked:   false,
-			runOutput:            None[string](),
+			runResult:            None[subshell.RunResult](),
 			uncommittedContent:   None[string](),
 			uncommittedFileName:  None[string](),
 		}
@@ -698,25 +707,24 @@ func defineSteps(sc *godog.ScenarioContext) {
 		updateInitialSHAs(state)
 		env := os.Environ()
 		if browserPath, has := state.browserVariable.Get(); has {
-			env = envvars.Replace(env, browser.EnvVarName, browserPath)
+			env = envvars.Replace(env, envconfig.Browser, browserPath)
 		}
-		output, exitCode := devRepo.MustQueryStringCodeWith(cmd, &subshell.Options{
+		runResult := devRepo.MustQueryStringCodeWith(cmd, &subshell.Options{
 			Env:   env,
 			Input: Some(input.Content),
 		})
-		state.runOutput = Some(output)
-		state.runExitCode = Some(exitCode)
+		state.runResult = Some(runResult)
 		devRepo.Reload()
 	})
 
 	sc.Step(`^I ran "([^"]+)"$`, func(ctx context.Context, command string) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		runCommand(state, command, false)
-		if exitCode, hasExitCode := state.runExitCode.Get(); hasExitCode {
-			if exitCode != 0 {
+		if runResult, hasRunResult := state.runResult.Get(); hasRunResult {
+			if runResult.ExitCode != 0 {
 				fmt.Println("Output from failed command:")
-				fmt.Println(state.runOutput.GetOrZero())
-				return fmt.Errorf("unexpected exit code: %d", exitCode)
+				fmt.Println(runResult.Output)
+				return fmt.Errorf("unexpected exit code: %d", runResult.ExitCode)
 			}
 		}
 		return nil
@@ -725,8 +733,8 @@ func defineSteps(sc *godog.ScenarioContext) {
 	sc.Step(`^I ran "([^"]+)" and ignore the error$`, func(ctx context.Context, command string) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		runCommand(state, command, false)
-		if exitCode, hasExitCode := state.runExitCode.Get(); hasExitCode {
-			if exitCode == 0 {
+		if runResult, hasRunResult := state.runResult.Get(); hasRunResult {
+			if runResult.ExitCode == 0 {
 				return errors.New("this command should fail")
 			}
 		}
@@ -738,11 +746,11 @@ func defineSteps(sc *godog.ScenarioContext) {
 		devRepo := state.fixture.DevRepo.GetOrPanic()
 		devRepo.CheckoutBranch(gitdomain.LocalBranchName(branch))
 		runCommand(state, command, false)
-		if exitCode, hasExitCode := state.runExitCode.Get(); hasExitCode {
-			if exitCode != 0 {
+		if runResult, hasRunResult := state.runResult.Get(); hasRunResult {
+			if runResult.ExitCode != 0 {
 				fmt.Println("Output from failed command:")
-				fmt.Println(state.runOutput.GetOrZero())
-				return fmt.Errorf("unexpected exit code: %d", exitCode)
+				fmt.Println(state.runResult.GetOrZero())
+				return fmt.Errorf("unexpected exit code: %d", runResult.ExitCode)
 			}
 		}
 		return nil
@@ -791,9 +799,8 @@ func defineSteps(sc *godog.ScenarioContext) {
 		state.CaptureState()
 		updateInitialSHAs(state)
 		env := append(os.Environ(), "GIT_EDITOR=true")
-		output, exitCode := devRepo.MustQueryStringCodeWith(cmd, &subshell.Options{Env: env})
-		state.runOutput = Some(output)
-		state.runExitCode = Some(exitCode)
+		runResult := devRepo.MustQueryStringCodeWith(cmd, &subshell.Options{Env: env})
+		state.runResult = Some(runResult)
 		devRepo.Reload()
 	})
 
@@ -803,9 +810,8 @@ func defineSteps(sc *godog.ScenarioContext) {
 		state.CaptureState()
 		updateInitialSHAs(state)
 		devRepo.MockCommitMessage("")
-		output, exitCode := devRepo.MustQueryStringCode(cmd)
-		state.runOutput = Some(output)
-		state.runExitCode = Some(exitCode)
+		runResult := devRepo.MustQueryStringCode(cmd)
+		state.runResult = Some(runResult)
 		devRepo.Reload()
 	})
 
@@ -817,13 +823,12 @@ func defineSteps(sc *godog.ScenarioContext) {
 		devRepo.MockCommitMessage(message)
 		env := os.Environ()
 		if browserPath, has := state.browserVariable.Get(); has {
-			env = envvars.Replace(env, browser.EnvVarName, browserPath)
+			env = envvars.Replace(env, envconfig.Browser, browserPath)
 		}
-		output, exitCode := devRepo.MustQueryStringCodeWith(cmd, &subshell.Options{
+		runResult := devRepo.MustQueryStringCodeWith(cmd, &subshell.Options{
 			Env: env,
 		})
-		state.runOutput = Some(output)
-		state.runExitCode = Some(exitCode)
+		state.runResult = Some(runResult)
 		devRepo.Reload()
 	})
 
@@ -832,9 +837,8 @@ func defineSteps(sc *godog.ScenarioContext) {
 		devRepo := state.fixture.DevRepo.GetOrPanic()
 		state.CaptureState()
 		updateInitialSHAs(state)
-		output, exitCode := devRepo.MustQueryStringCodeWith(cmd, &subshell.Options{Dir: folderName})
-		state.runOutput = Some(output)
-		state.runExitCode = Some(exitCode)
+		runResult := devRepo.MustQueryStringCodeWith(cmd, &subshell.Options{Dir: folderName})
+		state.runResult = Some(runResult)
 		devRepo.Reload()
 	})
 
@@ -843,9 +847,8 @@ func defineSteps(sc *godog.ScenarioContext) {
 		state.CaptureState()
 		updateInitialSHAs(state)
 		secondWorkTree := state.fixture.SecondWorktree.GetOrPanic()
-		output, exitCode := secondWorkTree.MustQueryStringCode(cmd)
-		state.runOutput = Some(output)
-		state.runExitCode = Some(exitCode)
+		runResult := secondWorkTree.MustQueryStringCode(cmd)
+		state.runResult = Some(runResult)
 		secondWorkTree.Reload()
 	})
 
@@ -855,9 +858,8 @@ func defineSteps(sc *godog.ScenarioContext) {
 		updateInitialSHAs(state)
 		secondWorkTree := state.fixture.SecondWorktree.GetOrPanic()
 		secondWorkTree.MockCommitMessage(message)
-		output, exitCode := secondWorkTree.MustQueryStringCode(cmd)
-		state.runOutput = Some(output)
-		state.runExitCode = Some(exitCode)
+		runResult := secondWorkTree.MustQueryStringCode(cmd)
+		state.runResult = Some(runResult)
 		secondWorkTree.Reload()
 	})
 
@@ -868,15 +870,14 @@ func defineSteps(sc *godog.ScenarioContext) {
 		updateInitialSHAs(state)
 		env := os.Environ()
 		if browserPath, has := state.browserVariable.Get(); has {
-			env = envvars.Replace(env, browser.EnvVarName, browserPath)
+			env = envvars.Replace(env, envconfig.Browser, browserPath)
 		}
 		env = append(env, envVar1, envVar2, envVar3, envVar4)
 		for a, answer := range helpers.TableToInputEnv(input) {
 			env = append(env, fmt.Sprintf("%s_%02d=%s", dialogcomponents.InputKey, a, answer))
 		}
-		output, exitCode := devRepo.MustQueryStringCodeWith(cmd, &subshell.Options{Env: env})
-		state.runOutput = Some(output)
-		state.runExitCode = Some(exitCode)
+		runResult := devRepo.MustQueryStringCodeWith(cmd, &subshell.Options{Env: env})
+		state.runResult = Some(runResult)
 		devRepo.Reload()
 	})
 
@@ -889,9 +890,8 @@ func defineSteps(sc *godog.ScenarioContext) {
 		for _, row := range envVars.Rows {
 			env = append(env, fmt.Sprintf("%s=%s", row.Cells[0].Value, row.Cells[1].Value))
 		}
-		output, exitCode := devRepo.MustQueryStringCodeWith(command, &subshell.Options{Env: env})
-		state.runOutput = Some(output)
-		state.runExitCode = Some(exitCode)
+		runResult := devRepo.MustQueryStringCodeWith(command, &subshell.Options{Env: env})
+		state.runResult = Some(runResult)
 		devRepo.Reload()
 	})
 
@@ -902,14 +902,13 @@ func defineSteps(sc *godog.ScenarioContext) {
 		updateInitialSHAs(state)
 		env := os.Environ()
 		if browserPath, has := state.browserVariable.Get(); has {
-			env = envvars.Replace(env, browser.EnvVarName, browserPath)
+			env = envvars.Replace(env, envconfig.Browser, browserPath)
 		}
 		for a, answer := range helpers.TableToInputEnv(input) {
 			env = append(env, fmt.Sprintf("%s_%02d=%s", dialogcomponents.InputKey, a, answer))
 		}
-		output, exitCode := devRepo.MustQueryStringCodeWith(cmd, &subshell.Options{Env: env})
-		state.runOutput = Some(output)
-		state.runExitCode = Some(exitCode)
+		runResult := devRepo.MustQueryStringCodeWith(cmd, &subshell.Options{Env: env})
+		state.runResult = Some(runResult)
 		devRepo.Reload()
 	})
 
@@ -972,7 +971,7 @@ func defineSteps(sc *godog.ScenarioContext) {
 
 	sc.Step(`^no tool to open browsers is installed$`, func(ctx context.Context) {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
-		state.browserVariable = Some(string(browser.EnvVarNone))
+		state.browserVariable = Some(string(configdomain.NoBrowser))
 	})
 
 	sc.Step(`^no uncommitted files exist now$`, func(ctx context.Context) error {
@@ -991,6 +990,14 @@ func defineSteps(sc *godog.ScenarioContext) {
 		return gitconfig.SetOffline(devRepo.TestRunner, true)
 	})
 
+	sc.Step(`^origin closes proposal #(\d+)$`, func(ctx context.Context, proposalNumber int) {
+		state := ctx.Value(keyScenarioState).(*ScenarioState)
+		proposalFilePath := mockproposals.NewMockProposalPath(state.fixture.RepoConfigDir())
+		proposals := mockproposals.Load(proposalFilePath)
+		proposals.DeleteByID(forgedomain.ProposalNumber(proposalNumber))
+		mockproposals.Save(proposalFilePath, proposals)
+	})
+
 	sc.Step(`^origin deletes the "([^"]*)" branch$`, func(ctx context.Context, branch string) {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		state.fixture.OriginRepo.GetOrPanic().RemoveBranch(gitdomain.NewLocalBranchName(branch))
@@ -1061,10 +1068,10 @@ func defineSteps(sc *godog.ScenarioContext) {
 	sc.Step(`^the branches contain these files:$`, func(ctx context.Context, godogTable *godog.Table) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		repo := state.fixture.DevRepo.GetOrPanic()
-		branches, _ := asserts.NoError2(repo.LocalBranches())
+		branches := asserts.NoError1(repo.LocalBranches())
 		haveTable := datatable.DataTable{}
 		haveTable.AddRow("BRANCH", "NAME")
-		for _, branch := range branches {
+		for _, branch := range branches.AllBranches {
 			repo.CheckoutBranch(branch)
 			firstFileInBranch := true
 			for _, file := range repo.FilesInWorkspace() {
@@ -1194,18 +1201,16 @@ func defineSteps(sc *godog.ScenarioContext) {
 
 	sc.Step(`^the coworker runs "([^"]+)"$`, func(ctx context.Context, command string) {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
-		output, exitCode := state.fixture.CoworkerRepo.GetOrPanic().MustQueryStringCode(command)
-		state.runOutput = Some(output)
-		state.runExitCode = Some(exitCode)
+		runResult := state.fixture.CoworkerRepo.GetOrPanic().MustQueryStringCode(command)
+		state.runResult = Some(runResult)
 	})
 
 	sc.Step(`^the coworker runs "([^"]*)" and closes the editor$`, func(ctx context.Context, cmd string) {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		env := append(os.Environ(), "GIT_EDITOR=true")
 		coworkerRepo := state.fixture.CoworkerRepo.GetOrPanic()
-		output, exitCode := coworkerRepo.MustQueryStringCodeWith(cmd, &subshell.Options{Env: env})
-		state.runOutput = Some(output)
-		state.runExitCode = Some(exitCode)
+		runResult := coworkerRepo.MustQueryStringCodeWith(cmd, &subshell.Options{Env: env})
+		state.runResult = Some(runResult)
 	})
 
 	sc.Step(`^the coworker sets the parent branch of "([^"]*)" as "([^"]*)"$`, func(ctx context.Context, childBranch, parentBranch string) {
@@ -1353,6 +1358,28 @@ func defineSteps(sc *godog.ScenarioContext) {
 		return nil
 	})
 
+	sc.Step(`^the initial proposals exist now$`, func(ctx context.Context) error {
+		state := ctx.Value(keyScenarioState).(*ScenarioState)
+		state.proposalsChecked = true
+		proposalsPath := mockproposals.NewMockProposalPath(state.fixture.RepoConfigDir())
+		have, has := mockproposals.LoadBytes(proposalsPath).Get()
+		if !has {
+			return errors.New("no mock proposals file")
+		}
+		want, hasInitialProposals := state.initialProposals.Get()
+		if !hasInitialProposals {
+			return errors.New("no initial proposals defined")
+		}
+		dmp := diffmatchpatch.New()
+		diffs := dmp.DiffMain(want, string(have), false)
+		if len(diffs) == 1 && diffs[0].Type == 0 {
+			return nil
+		}
+		fmt.Printf("\nERROR! Found %d differences to the initial proposals\n\n", len(diffs))
+		fmt.Println(dmp.DiffPrettyText(diffs))
+		return errors.New("mismatching proposals found, see diff above")
+	})
+
 	sc.Step(`^the initial tags exist now$`, func(ctx context.Context) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		currentTags := state.fixture.TagTable()
@@ -1427,6 +1454,38 @@ func defineSteps(sc *godog.ScenarioContext) {
 		return nil
 	})
 
+	sc.Step(`^the proposals$`, func(ctx context.Context, table *godog.Table) {
+		state := ctx.Value(keyScenarioState).(*ScenarioState)
+		devRepo := state.fixture.DevRepo.GetOrPanic()
+		proposals := mockproposals.FromGherkinTable(table, devRepo.Config.NormalConfig.Lineage)
+		proposalFilePath := mockproposals.NewMockProposalPath(state.fixture.RepoConfigDir())
+		initialProposals := mockproposals.Save(proposalFilePath, proposals)
+		state.initialProposals = Some(initialProposals)
+	})
+
+	sc.Step(`^the proposals are now$`, func(ctx context.Context, want *godog.DocString) error {
+		state := ctx.Value(keyScenarioState).(*ScenarioState)
+		state.proposalsChecked = true
+		proposalFilePath := mockproposals.NewMockProposalPath(state.fixture.RepoConfigDir())
+		haveData := mockproposals.Load(proposalFilePath)
+		haveString := mockproposals.ToDocString(haveData)
+		wantString := strings.TrimSpace(want.Content)
+		dmp := diffmatchpatch.New()
+		diffs := dmp.DiffMain(wantString, haveString, false)
+		if len(diffs) == 1 && diffs[0].Type == 0 {
+			return nil
+		}
+		if CukeUpdate {
+			scenarioURI := ctx.Value(keyScenarioURI).(string)
+			return ChangeFeatureFile(scenarioURI, wantString, haveString)
+		}
+		diffText := dmp.DiffPrettyText(diffs)
+		diffText += fmt.Sprintf("\n\nHAVE:\n%q\n\n", haveString)
+		diffText += fmt.Sprintf("\n\nWANT:\n%q\n\n", wantString)
+		fmt.Println(diffText)
+		return errors.New("mismatching proposals found, see diff above")
+	})
+
 	sc.Step(`^there are (?:now|still) no perennial branches$`, func(ctx context.Context) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		devRepo := state.fixture.DevRepo.GetOrPanic()
@@ -1457,7 +1516,8 @@ func defineSteps(sc *godog.ScenarioContext) {
 				return errors.New(`please use the step "the initial commits exist now" instead`)
 			}
 		}
-		return state.compareGherkinTable(table)
+		scenarioURI := ctx.Value(keyScenarioURI).(string)
+		return state.compareGherkinTable(table, scenarioURI)
 	})
 
 	sc.Step(`^these committed files exist now$`, func(ctx context.Context, table *godog.Table) error {
@@ -1466,6 +1526,11 @@ func defineSteps(sc *godog.ScenarioContext) {
 		fileTable := devRepo.FilesInBranches("main")
 		diff, errorCount := fileTable.EqualGherkin(table)
 		if errorCount != 0 {
+			if CukeUpdate {
+				scenarioURI := ctx.Value(keyScenarioURI).(string)
+				expectedTable := datatable.FromGherkin(table)
+				return ChangeFeatureFile(scenarioURI, expectedTable.String(), fileTable.String())
+			}
 			fmt.Printf("\nERROR! Found %d differences in the existing files\n\n", errorCount)
 			fmt.Println(diff)
 			return errors.New("mismatching files found, see diff above")
@@ -1544,7 +1609,7 @@ func defineSteps(sc *godog.ScenarioContext) {
 
 	// This step exists to avoid re-creating commits with the same SHA as existing commits
 	// because that can cause flaky tests.
-	sc.Step(`wait 1 second to ensure new Git timestamps`, func() {
+	sc.Step(`^wait 1 second to ensure new Git timestamps$`, func() {
 		time.Sleep(1 * time.Second)
 	})
 }
@@ -1555,28 +1620,28 @@ func runCommand(state *ScenarioState, command string, captureState bool) {
 		state.CaptureState()
 		updateInitialSHAs(state)
 	}
-	var exitCode int
-	var runOutput string
+	var runResult subshell.RunResult
 	env := os.Environ()
 	if browserVariable, hasBrowserOverride := state.browserVariable.Get(); hasBrowserOverride {
-		env = envvars.Replace(env, browser.EnvVarName, browserVariable)
+		env = envvars.Replace(env, envconfig.Browser, browserVariable)
 	}
 	if hasDevRepo {
-		runOutput, exitCode = devRepo.MustQueryStringCodeWith(command, &subshell.Options{
+		runResult = devRepo.MustQueryStringCodeWith(command, &subshell.Options{
 			Env: env,
 		})
 		devRepo.Reload()
 	} else {
 		parts := asserts.NoError1(shellquote.Split(command))
 		cmd, args := parts[0], parts[1:]
-		subProcess := exec.Command(cmd, args...) // #nosec
+		subProcess := exec.CommandContext(context.Background(), cmd, args...) // #nosec
 		subProcess.Dir = state.fixture.Dir
 		outputBytes, _ := subProcess.CombinedOutput()
-		runOutput = string(outputBytes)
-		exitCode = subProcess.ProcessState.ExitCode()
+		runResult = subshell.RunResult{
+			Output:   string(outputBytes),
+			ExitCode: subProcess.ProcessState.ExitCode(),
+		}
 	}
-	state.runOutput = Some(runOutput)
-	state.runExitCode = Some(exitCode)
+	state.runResult = Some(runResult)
 }
 
 func updateInitialSHAs(state *ScenarioState) {
