@@ -2,16 +2,17 @@ package undo
 
 import (
 	"fmt"
+	"os"
 
 	"github.com/git-town/git-town/v22/internal/cli/print"
 	"github.com/git-town/git-town/v22/internal/config"
+	"github.com/git-town/git-town/v22/internal/config/configdomain"
 	"github.com/git-town/git-town/v22/internal/forge/forgedomain"
 	"github.com/git-town/git-town/v22/internal/git"
 	"github.com/git-town/git-town/v22/internal/git/gitdomain"
 	"github.com/git-town/git-town/v22/internal/gohacks"
 	"github.com/git-town/git-town/v22/internal/gohacks/stringslice"
 	"github.com/git-town/git-town/v22/internal/messages"
-	"github.com/git-town/git-town/v22/internal/state"
 	"github.com/git-town/git-town/v22/internal/state/runstate"
 	"github.com/git-town/git-town/v22/internal/subshell/subshelldomain"
 	"github.com/git-town/git-town/v22/internal/vm/interpreter/lightinterpreter"
@@ -22,13 +23,13 @@ type ExecuteArgs struct {
 	Backend          subshelldomain.RunnerQuerier
 	CommandsCounter  Mutable[gohacks.Counter]
 	Config           config.ValidatedConfig
+	ConfigDir        configdomain.RepoConfigDir
 	Connector        Option[forgedomain.Connector]
 	FinalMessages    stringslice.Collector
 	Frontend         subshelldomain.Runner
 	Git              git.Commands
 	HasOpenChanges   bool
 	InitialStashSize gitdomain.StashSize
-	RootDir          gitdomain.RepoRootDir
 	RunState         runstate.RunState
 }
 
@@ -49,6 +50,7 @@ func Execute(args ExecuteArgs) error {
 	})
 	lightinterpreter.Execute(lightinterpreter.ExecuteArgs{
 		Backend:       args.Backend,
+		BranchInfos:   args.RunState.BeginBranchesSnapshot.Branches,
 		Config:        args.Config,
 		Connector:     args.Connector,
 		FinalMessages: args.FinalMessages,
@@ -56,8 +58,9 @@ func Execute(args ExecuteArgs) error {
 		Git:           args.Git,
 		Prog:          program,
 	})
-	_, err := state.Delete(args.RootDir, state.FileTypeRunstate)
-	if err != nil {
+	runstatePath := runstate.NewRunstatePath(args.ConfigDir)
+	err := os.Remove(runstatePath.String())
+	if err != nil && !os.IsNotExist(err) {
 		return fmt.Errorf(messages.RunstateDeleteProblem, err)
 	}
 	print.Footer(args.Config.NormalConfig.Verbose, args.CommandsCounter.Immutable(), args.FinalMessages.Result())
