@@ -1,7 +1,6 @@
 package undobranches
 
 import (
-	"fmt"
 	"slices"
 
 	"github.com/git-town/git-town/v22/internal/config"
@@ -60,26 +59,35 @@ type BranchChanges struct {
 // UndoProgram provides the steps to undo the changes described by this BranchChanges instance.
 func (self BranchChanges) UndoProgram(args BranchChangesUndoProgramArgs) program.Program {
 	result := program.Program{}
-	omniChangedPerennials, omniChangedFeatures := CategorizeLocalBranchChange(self.OmniChanged, args.Config)
+
+	omniChanges := CategorizeLocalBranchChange(self.OmniChanged, args.Config)
 
 	// revert omni-changed perennial branches
-	for _, branch := range omniChangedPerennials.BranchNames() {
-		change := omniChangedPerennials[branch]
+	for _, branch := range omniChanges.Perennials.BranchNames() {
+		change := omniChanges.Perennials[branch]
 		if slices.Contains(args.UndoablePerennialCommits, change.After) {
 			result.Add(&opcodes.CheckoutIfNeeded{Branch: branch})
 			result.Add(&opcodes.CommitRevertIfNeeded{SHA: change.After})
-			result.Add(&opcodes.PushCurrentBranchIfNeeded{CurrentBranch: branch})
+			if branchInfo, hasBranchInfo := args.BranchInfos.FindByLocalName(branch).Get(); hasBranchInfo {
+				if tracking, hasTracking := branchInfo.RemoteName.Get(); hasTracking {
+					result.Add(&opcodes.PushCurrentBranchIfNeeded{CurrentBranch: branch, TrackingBranch: tracking})
+				}
+			}
 		} else {
-			args.FinalMessages.Add(fmt.Sprintf(messages.UndoCannotRevertCommitOnPerennialBranch, change.After))
+			args.FinalMessages.Addf(messages.UndoCannotRevertCommitOnPerennialBranch, change.After)
 		}
 	}
 
 	// reset omni-changed feature branches
-	for _, branch := range omniChangedFeatures.BranchNames() {
-		change := omniChangedFeatures[branch]
+	for _, branch := range omniChanges.Features.BranchNames() {
+		change := omniChanges.Features[branch]
 		result.Add(&opcodes.CheckoutIfNeeded{Branch: branch})
 		result.Add(&opcodes.BranchCurrentResetToSHAIfNeeded{MustHaveSHA: change.After, SetToSHA: change.Before})
-		result.Add(&opcodes.PushCurrentBranchForceIfNeeded{CurrentBranch: branch, ForceIfIncludes: true})
+		if branchInfo, hasBranchInfo := args.BranchInfos.FindByLocalName(branch).Get(); hasBranchInfo {
+			if tracking, hasTracking := branchInfo.RemoteName.Get(); hasTracking {
+				result.Add(&opcodes.PushCurrentBranchForceIfNeeded{CurrentBranch: branch, ForceIfIncludes: true, TrackingBranch: tracking})
+			}
+		}
 	}
 
 	// re-create removed omni-branches
@@ -89,44 +97,48 @@ func (self BranchChanges) UndoProgram(args BranchChangesUndoProgramArgs) program
 		result.Add(&opcodes.BranchTrackingCreate{Branch: branch})
 	}
 
-	inconsistentlyChangedPerennials, inconsistentChangedFeatures := CategorizeInconsistentChanges(self.InconsistentlyChanged, args.Config)
+	inconsistentChanges := CategorizeInconsistentChanges(self.InconsistentlyChanged, args.Config)
 
 	// reset inconsistently changed perennial branches
-	for _, inconsistentlyChangedPerennial := range inconsistentlyChangedPerennials {
-		if isOmni, branchName, afterSHA := inconsistentlyChangedPerennial.After.IsOmniBranch(); isOmni {
-			if slices.Contains(args.UndoablePerennialCommits, afterSHA) {
-				result.Add(&opcodes.CheckoutIfNeeded{Branch: branchName})
-				result.Add(&opcodes.CommitRevertIfNeeded{SHA: afterSHA})
-				result.Add(&opcodes.PushCurrentBranchIfNeeded{CurrentBranch: branchName})
+	for _, inconsistentlyChangedPerennial := range inconsistentChanges.Perennials {
+		if omni, isOmni := inconsistentlyChangedPerennial.After.OmniBranch().Get(); isOmni {
+			if slices.Contains(args.UndoablePerennialCommits, omni.SHA) {
+				result.Add(&opcodes.CheckoutIfNeeded{Branch: omni.Name})
+				result.Add(&opcodes.CommitRevertIfNeeded{SHA: omni.SHA})
+				if branchInfo, hasBranchInfo := args.BranchInfos.FindByLocalName(omni.Name).Get(); hasBranchInfo {
+					if tracking, hasTracking := branchInfo.RemoteName.Get(); hasTracking {
+						result.Add(&opcodes.PushCurrentBranchIfNeeded{CurrentBranch: omni.Name, TrackingBranch: tracking})
+					}
+				}
 			}
 		} else {
-			args.FinalMessages.Add(fmt.Sprintf(messages.UndoCannotRevertCommitOnPerennialBranch, afterSHA))
+			args.FinalMessages.Addf(messages.UndoCannotRevertCommitOnPerennialBranch, inconsistentlyChangedPerennial.After)
 		}
 	}
 
 	// reset inconsistently changed feature branches
-	for _, inconsistentChange := range inconsistentChangedFeatures {
-		hasBeforeLocal, beforeLocalName, beforeLocalSHA := inconsistentChange.Before.GetLocal()
-		hasBeforeRemote, beforeRemoteName, beforeRemoteSHA := inconsistentChange.Before.GetRemoteBranch()
-		hasAfterSHAs, afterLocalSHA, afterRemoteSHA := inconsistentChange.After.GetSHAs()
-		if hasBeforeLocal && hasBeforeRemote && hasAfterSHAs {
-			result.Add(&opcodes.CheckoutIfNeeded{Branch: beforeLocalName})
+	for _, inconsistentChange := range inconsistentChanges.Features {
+		local, hasLocal := inconsistentChange.Before.Local.Get()
+		hasBeforeRemote, beforeRemoteName, beforeRemoteSHA := inconsistentChange.Before.GetRemote()
+		AfterSHAs := inconsistentChange.After.GetSHAs()
+		if hasLocal && hasBeforeRemote && AfterSHAs.HasBothSHA {
+			result.Add(&opcodes.CheckoutIfNeeded{Branch: local.Name})
 			result.Add(&opcodes.BranchCurrentResetToSHAIfNeeded{
-				MustHaveSHA: afterLocalSHA,
-				SetToSHA:    beforeLocalSHA,
+				MustHaveSHA: AfterSHAs.LocalSHA,
+				SetToSHA:    local.SHA,
 			})
 			result.Add(&opcodes.BranchRemoteSetToSHAIfNeeded{
 				Branch:      beforeRemoteName,
-				MustHaveSHA: afterRemoteSHA,
+				MustHaveSHA: AfterSHAs.RemoteSHA,
 				SetToSHA:    beforeRemoteSHA,
 			})
 		}
 	}
 
 	// re-create remotely removed feature branches
-	_, removedFeatureTrackingBranches := CategorizeRemoteBranchesSHAs(self.RemoteRemoved, args.Config)
-	for _, branch := range removedFeatureTrackingBranches.BranchNames() {
-		sha := removedFeatureTrackingBranches[branch]
+	removedTrackingBranches := CategorizeRemoteBranchesSHAs(self.RemoteRemoved, args.Config)
+	for _, branch := range removedTrackingBranches.Features.BranchNames() {
+		sha := removedTrackingBranches.Features[branch]
 		result.Add(&opcodes.BranchRemoteCreate{
 			Branch: branch.LocalBranchName(),
 			SHA:    sha,
@@ -169,9 +181,9 @@ func (self BranchChanges) UndoProgram(args BranchChangesUndoProgramArgs) program
 	// and we would need the local branch to revert commits on them, but we can't change the local branch.
 
 	// reset remotely changed feature branches
-	_, remoteFeatureChanges := CategorizeRemoteBranchChange(self.RemoteChanged, args.Config)
-	for _, remoteChangedFeatureBranch := range remoteFeatureChanges.BranchNames() {
-		change := remoteFeatureChanges[remoteChangedFeatureBranch]
+	remoteChanges := CategorizeRemoteBranchChange(self.RemoteChanged, args.Config)
+	for _, remoteChangedFeatureBranch := range remoteChanges.Features.BranchNames() {
+		change := remoteChanges.Features[remoteChangedFeatureBranch]
 		result.Add(&opcodes.BranchRemoteSetToSHAIfNeeded{
 			Branch:      remoteChangedFeatureBranch,
 			MustHaveSHA: change.After,
@@ -199,6 +211,7 @@ func (self BranchChanges) UndoProgram(args BranchChangesUndoProgramArgs) program
 
 type BranchChangesUndoProgramArgs struct {
 	BeginBranch              gitdomain.LocalBranchName
+	BranchInfos              gitdomain.BranchInfos
 	Config                   config.ValidatedConfig
 	EndBranch                gitdomain.LocalBranchName
 	FinalMessages            stringslice.Collector
