@@ -8,9 +8,9 @@ import (
 // BranchCurrentResetToSHA undoes all commits on the current branch
 // all the way until the given SHA.
 type BranchCurrentResetToSHA struct {
-	SetToSHA gitdomain.SHA
+	SHA gitdomain.SHA
 }
 
 func (self *BranchCurrentResetToSHA) Run(args shared.RunArgs) error {
-	return args.Git.ResetCurrentBranchToSHA(args.Frontend, self.SetToSHA)
+	return args.Git.ResetCurrentBranchToSHA(args.Frontend, self.SHA)
 }
