@@ -1,16 +1,15 @@
 package opcodes
 
 import (
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	"github.com/git-town/git-town/v18/internal/vm/shared"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
+	"github.com/git-town/git-town/v22/internal/vm/shared"
 )
 
-// CheckoutIfExists does the same as Checkout
+// CheckoutFirstExisting checks out the first existing branch,
 // but only if that branch actually exists.
 type CheckoutFirstExisting struct {
-	Branches                gitdomain.LocalBranchNames
-	MainBranch              gitdomain.LocalBranchName
-	undeclaredOpcodeMethods `exhaustruct:"optional"`
+	Branches   gitdomain.LocalBranchNames
+	MainBranch gitdomain.LocalBranchName
 }
 
 func (self *CheckoutFirstExisting) Run(args shared.RunArgs) error {
