@@ -3,17 +3,16 @@ package opcodes
 import (
 	"errors"
 
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	"github.com/git-town/git-town/v18/internal/messages"
-	"github.com/git-town/git-town/v18/internal/vm/shared"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
+	"github.com/git-town/git-town/v22/internal/messages"
+	"github.com/git-town/git-town/v22/internal/vm/shared"
 )
 
 type MergeSquashAutoUndo struct {
-	Branch                  gitdomain.LocalBranchName
-	undeclaredOpcodeMethods `exhaustruct:"optional"`
+	Branch gitdomain.LocalBranchName
 }
 
-func (self *MergeSquashAutoUndo) AbortProgram() []shared.Opcode {
+func (self *MergeSquashAutoUndo) Abort() []shared.Opcode {
 	result := []shared.Opcode{
 		&ChangesDiscard{},
 	}
@@ -21,7 +20,7 @@ func (self *MergeSquashAutoUndo) AbortProgram() []shared.Opcode {
 }
 
 func (self *MergeSquashAutoUndo) AutomaticUndoError() error {
-	return errors.New(messages.ShipAbortedMergeError)
+	return errors.New(messages.ShipExitMergeError)
 }
 
 func (self *MergeSquashAutoUndo) Run(args shared.RunArgs) error {
