@@ -3,16 +3,16 @@ package opcodes
 import (
 	"fmt"
 
-	"github.com/git-town/git-town/v18/internal/git/gitdomain"
-	"github.com/git-town/git-town/v18/internal/vm/shared"
+	"github.com/git-town/git-town/v22/internal/forge/forgedomain"
+	"github.com/git-town/git-town/v22/internal/git/gitdomain"
+	"github.com/git-town/git-town/v22/internal/vm/shared"
 )
 
 // ProposalUpdateTargetToGrandParent updates the target of the proposal with the given number to the parent of the given branch.
 type ProposalUpdateTargetToGrandParent struct {
-	Branch                  gitdomain.LocalBranchName
-	OldTarget               gitdomain.LocalBranchName
-	ProposalNumber          int
-	undeclaredOpcodeMethods `exhaustruct:"optional"`
+	Branch    gitdomain.LocalBranchName
+	OldTarget gitdomain.LocalBranchName
+	Proposal  forgedomain.Proposal
 }
 
 func (self *ProposalUpdateTargetToGrandParent) Run(args shared.RunArgs) error {
@@ -21,9 +21,9 @@ func (self *ProposalUpdateTargetToGrandParent) Run(args shared.RunArgs) error {
 		return fmt.Errorf("branch %q has no parent", self.Branch)
 	}
 	args.PrependOpcodes(&ProposalUpdateTarget{
-		NewBranch:      parent,
-		OldBranch:      self.OldTarget,
-		ProposalNumber: self.ProposalNumber,
+		NewBranch: parent,
+		OldBranch: self.OldTarget,
+		Proposal:  self.Proposal,
 	})
 	return nil
 }
