@@ -9,10 +9,11 @@ import (
 type PushCurrentBranchForceIfNeeded struct {
 	CurrentBranch   gitdomain.LocalBranchName
 	ForceIfIncludes bool
+	TrackingBranch  gitdomain.RemoteBranchName
 }
 
 func (self *PushCurrentBranchForceIfNeeded) Run(args shared.RunArgs) error {
-	inSync, err := args.Git.BranchInSyncWithTracking(args.Backend, self.CurrentBranch, args.Config.Value.NormalConfig.DevRemote)
+	inSync, err := args.Git.BranchInSyncWithTracking(args.Backend, self.CurrentBranch, self.TrackingBranch)
 	if err != nil {
 		return err
 	}
