@@ -1,12 +1,10 @@
 package opcodes
 
-import "github.com/git-town/git-town/v18/internal/vm/shared"
+import "github.com/git-town/git-town/v22/internal/vm/shared"
 
 // RebaseContinueIfNeeded finishes an ongoing rebase operation
 // assuming all conflicts have been resolved by the user.
-type RebaseContinueIfNeeded struct {
-	undeclaredOpcodeMethods `exhaustruct:"optional"`
-}
+type RebaseContinueIfNeeded struct{}
 
 func (self *RebaseContinueIfNeeded) Run(args shared.RunArgs) error {
 	repoStatus, err := args.Git.RepoStatus(args.Backend)
