@@ -3,8 +3,8 @@ package prelude_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v18/internal/gohacks"
-	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"github.com/git-town/git-town/v22/internal/gohacks"
+	. "github.com/git-town/git-town/v22/pkg/prelude"
 	"github.com/shoenig/test/must"
 )
 
@@ -21,5 +21,5 @@ func TestMutable(t *testing.T) {
 }
 
 func modify(byValue Mutable[gohacks.Counter]) {
-	byValue.Value.Inc()
+	byValue.Value.Increment()
 }
