@@ -6,12 +6,13 @@ import (
 	"regexp"
 	"slices"
 	"strings"
+	"sync"
 
-	"github.com/git-town/git-town/v18/pkg/set"
-	"github.com/git-town/git-town/v18/test/asserts"
+	"github.com/git-town/git-town/v22/pkg/asserts"
+	"github.com/git-town/git-town/v22/pkg/set"
 )
 
-var unusedWhitelist = []string{ //nolint:gochecknoglobals
+var unusedWhitelist = []string{
 	`^display "([^"]+)"$`,
 	`^inspect the commits$`,
 	`^inspect the repo$`,
@@ -57,12 +58,12 @@ type StepRE struct {
 
 // provides all usages of Cucumber steps in the given file content
 func FindUsedStepsIn(fileContent string) []string {
-	if stepUsageRE == nil {
-		stepUsageRE = regexp.MustCompile(`^\s*(?:Given|When|Then|And) (.*)$`)
-	}
+	findUsedStepsOnce.Do(func() {
+		findUsedStepsRegex = regexp.MustCompile(`^\s*(?:Given|When|Then|And) (.*)$`)
+	})
 	var result []string
-	for _, line := range strings.Split(fileContent, "\n") {
-		matches := stepUsageRE.FindAllStringSubmatch(line, -1)
+	for line := range strings.SplitSeq(fileContent, "\n") {
+		matches := findUsedStepsRegex.FindAllStringSubmatch(line, -1)
 		if len(matches) > 0 {
 			result = append(result, strings.TrimSpace(matches[0][1]))
 		}
@@ -70,14 +71,14 @@ func FindUsedStepsIn(fileContent string) []string {
 	return result
 }
 
+var (
+	findUsedStepsOnce  sync.Once
+	findUsedStepsRegex *regexp.Regexp
+)
+
 // indicates whether the given step definition is used anywhere in the given list of executed steps
 func IsStepDefUsed(definedStep StepRE, usedSteps []string) bool {
-	for _, usedStep := range usedSteps {
-		if definedStep.regex.MatchString(usedStep) {
-			return true
-		}
-	}
-	return false
+	return slices.ContainsFunc(usedSteps, definedStep.regex.MatchString)
 }
 
 // provides all steps that are executed in .feature files
