@@ -9,7 +9,7 @@ import (
 )
 
 func (gh Connector) IssueReactions(issue *github.Issue, issueType string, current, total int) []*github.Reaction {
-	result := []*github.Reaction{}
+	var result []*github.Reaction
 	fmt.Printf("loading reactions to %s %d/%d (#%d) ", issueType, current, total, issue.GetNumber())
 	for page := 1; ; page++ {
 		reactions, response, err := gh.client.Reactions.ListIssueReactions(gh.context, org, repo, *issue.Number, &github.ListOptions{
